import React, { Component, PureComponent, cloneElement, Fragment, createRef } from 'react';
import classNames from 'classnames';
import bind from 'memoize-bind';
import posed, { PoseGroup } from 'react-pose';
import { interpolate as interpolate$1 } from 'd3-interpolate';
import { memoize, isFunction, isEqual, isDate, isNumber, isString } from 'lodash-es';
import { curveMonotoneX, curveStep, curveLinear, area, stack, stackOffsetExpand, line as line$1, arc, pie } from 'd3-shape';
import { median, histogram, min, max, bisector, range } from 'd3-array';
import bigInt from 'big-integer';
import humanFormat from 'human-format';
import { ConnectedOverlay } from 'rdk';
import { scaleOrdinal, scaleTime, scaleLinear, scaleBand, scalePoint } from 'd3-scale';
import sizeMe from 'react-sizeme';
import chroma from 'chroma-js';
import { geoMercator, geoPath } from 'd3-geo';
import { feature } from 'topojson-client';
import { sankey, sankeyJustify, sankeyCenter, sankeyLeft, sankeyRight } from 'd3-sankey';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
}

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

var __assign$1 = function() {
    __assign$1 = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign$1.apply(this, arguments);
};

var clamp = function (min, max) { return function (v) {
    return Math.max(Math.min(v, max), min);
}; };
var isFirstChars = function (term) { return function (v) {
    return typeof v === 'string' && v.indexOf(term) === 0;
}; };
var getValueFromFunctionString = function (value) {
    return value.substring(value.indexOf('(') + 1, value.lastIndexOf(')'));
};
var splitCommaDelimited = function (value) {
    return typeof value === 'string' ? value.split(/,\s*/) : [value];
};
var sanitize = function (v) { return (v % 1 ? Number(v.toFixed(5)) : v); };

var number = {
    test: function (v) { return typeof v === 'number'; },
    parse: parseFloat,
    transform: function (v) { return v; }
};
var alpha = __assign$1({}, number, { transform: clamp(0, 1) });
var scale = __assign$1({}, number, { default: 1 });

var createUnitType = function (unit) { return ({
    test: function (v) {
        return typeof v === 'string' && v.endsWith(unit) && v.split(' ').length === 1;
    },
    parse: parseFloat,
    transform: function (v) { return "" + v + unit; }
}); };
var degrees = createUnitType('deg');
var percent = createUnitType('%');
var px = createUnitType('px');
var vh = createUnitType('vh');
var vw = createUnitType('vw');

var clampRgbUnit = clamp(0, 255);
var onlyColorRegex = /^(#[0-9a-f]{3}|#(?:[0-9a-f]{2}){2,4}|(rgb|hsl)a?\((-?\d+%?[,\s]+){2,3}\s*[\d\.]+%?\))$/i;
var isRgba = function (v) { return v.red !== undefined; };
var isHsla = function (v) { return v.hue !== undefined; };
var splitColorValues = function (terms) {
    var numTerms = terms.length;
    return function (v) {
        if (typeof v !== 'string')
            return v;
        var values = {};
        var valuesArray = splitCommaDelimited(getValueFromFunctionString(v));
        for (var i = 0; i < numTerms; i++) {
            values[terms[i]] =
                valuesArray[i] !== undefined ? parseFloat(valuesArray[i]) : 1;
        }
        return values;
    };
};
var rgbaTemplate = function (_a) {
    var red = _a.red, green = _a.green, blue = _a.blue, _b = _a.alpha, alpha$$1 = _b === void 0 ? 1 : _b;
    return "rgba(" + red + ", " + green + ", " + blue + ", " + alpha$$1 + ")";
};
var hslaTemplate = function (_a) {
    var hue = _a.hue, saturation = _a.saturation, lightness = _a.lightness, _b = _a.alpha, alpha$$1 = _b === void 0 ? 1 : _b;
    return "hsla(" + hue + ", " + saturation + ", " + lightness + ", " + alpha$$1 + ")";
};
var rgbUnit = __assign$1({}, number, { transform: function (v) { return Math.round(clampRgbUnit(v)); } });
var testRgbaString = isFirstChars('rgb');
var rgba = {
    test: function (v) { return (typeof v === 'string' ? testRgbaString(v) : isRgba(v)); },
    parse: splitColorValues(['red', 'green', 'blue', 'alpha']),
    transform: function (_a) {
        var red = _a.red, green = _a.green, blue = _a.blue, alpha$$1 = _a.alpha;
        return rgbaTemplate({
            red: rgbUnit.transform(red),
            green: rgbUnit.transform(green),
            blue: rgbUnit.transform(blue),
            alpha: sanitize(alpha$$1)
        });
    }
};
var testHslaString = isFirstChars('hsl');
var hsla = {
    test: function (v) { return (typeof v === 'string' ? testHslaString(v) : isHsla(v)); },
    parse: splitColorValues(['hue', 'saturation', 'lightness', 'alpha']),
    transform: function (_a) {
        var hue = _a.hue, saturation = _a.saturation, lightness = _a.lightness, alpha$$1 = _a.alpha;
        return hslaTemplate({
            hue: Math.round(hue),
            saturation: percent.transform(sanitize(saturation)),
            lightness: percent.transform(sanitize(lightness)),
            alpha: sanitize(alpha$$1)
        });
    }
};
var hex = __assign$1({}, rgba, { test: isFirstChars('#'), parse: function (v) {
        var r = '';
        var g = '';
        var b = '';
        if (v.length > 4) {
            r = v.substr(1, 2);
            g = v.substr(3, 2);
            b = v.substr(5, 2);
        }
        else {
            r = v.substr(1, 1);
            g = v.substr(2, 1);
            b = v.substr(3, 1);
            r += r;
            g += g;
            b += b;
        }
        return {
            red: parseInt(r, 16),
            green: parseInt(g, 16),
            blue: parseInt(b, 16),
            alpha: 1
        };
    } });
var color = {
    test: function (v) {
        return (typeof v === 'string' && onlyColorRegex.test(v)) ||
            rgba.test(v) ||
            hsla.test(v) ||
            hex.test(v);
    },
    parse: function (v) {
        if (rgba.test(v)) {
            return rgba.parse(v);
        }
        else if (hsla.test(v)) {
            return hsla.parse(v);
        }
        else if (hex.test(v)) {
            return hex.parse(v);
        }
        return v;
    },
    transform: function (v) {
        if (isRgba(v)) {
            return rgba.transform(v);
        }
        else if (isHsla(v)) {
            return hsla.transform(v);
        }
        return v;
    }
};

var floatRegex = /(-)?(\d[\d\.]*)/g;
var colorRegex = /(#[0-9a-f]{6}|#[0-9a-f]{3}|#(?:[0-9a-f]{2}){2,4}|(rgb|hsl)a?\((-?\d+%?[,\s]+){2,3}\s*[\d\.]+%?\))/gi;
var COLOR_TOKEN = '${c}';
var NUMBER_TOKEN = '${n}';
var complex = {
    test: function (v) {
        if (typeof v !== 'string' || !isNaN(v))
            return false;
        var numValues = 0;
        var foundNumbers = v.match(floatRegex);
        var foundColors = v.match(colorRegex);
        if (foundNumbers)
            numValues += foundNumbers.length;
        if (foundColors)
            numValues += foundColors.length;
        return numValues > 0;
    },
    parse: function (v) {
        var input = v;
        var parsed = [];
        var foundColors = input.match(colorRegex);
        if (foundColors) {
            input = input.replace(colorRegex, COLOR_TOKEN);
            parsed.push.apply(parsed, foundColors.map(color.parse));
        }
        var foundNumbers = input.match(floatRegex);
        if (foundNumbers) {
            parsed.push.apply(parsed, foundNumbers.map(number.parse));
        }
        return parsed;
    },
    createTransformer: function (prop) {
        var template = prop;
        var token = 0;
        var foundColors = prop.match(colorRegex);
        var numColors = foundColors ? foundColors.length : 0;
        if (foundColors) {
            for (var i = 0; i < numColors; i++) {
                template = template.replace(foundColors[i], COLOR_TOKEN);
                token++;
            }
        }
        var foundNumbers = template.match(floatRegex);
        var numNumbers = foundNumbers ? foundNumbers.length : 0;
        if (foundNumbers) {
            for (var i = 0; i < numNumbers; i++) {
                template = template.replace(foundNumbers[i], NUMBER_TOKEN);
                token++;
            }
        }
        return function (v) {
            var output = template;
            for (var i = 0; i < token; i++) {
                output = output.replace(i < numColors ? COLOR_TOKEN : NUMBER_TOKEN, i < numColors ? color.transform(v[i]) : sanitize(v[i]));
            }
            return output;
        };
    }
};

var HEY_LISTEN = 'Hey, listen! ';
var invariant = function () { };
if (process.env.NODE_ENV !== 'production') {
    invariant = function (check, message) {
        if (!check) {
            throw new Error(HEY_LISTEN.toUpperCase() + message);
        }
    };
}

var prevTime = 0;
var onNextFrame = typeof window !== 'undefined' && window.requestAnimationFrame !== undefined
    ? function (callback) { return window.requestAnimationFrame(callback); }
    : function (callback) {
        var timestamp = Date.now();
        var timeToCall = Math.max(0, 16.7 - (timestamp - prevTime));
        prevTime = timestamp + timeToCall;
        setTimeout(function () { return callback(prevTime); }, timeToCall);
    };

var createStep = (function (setRunNextFrame) {
    var processToRun = [];
    var processToRunNextFrame = [];
    var numThisFrame = 0;
    var isProcessing = false;
    var i = 0;
    var cancelled = new WeakSet();
    var toKeepAlive = new WeakSet();
    var renderStep = {
        cancel: function (process) {
            var indexOfCallback = processToRunNextFrame.indexOf(process);
            cancelled.add(process);
            if (indexOfCallback !== -1) {
                processToRunNextFrame.splice(indexOfCallback, 1);
            }
        },
        process: function (frame) {
            var _a;
            isProcessing = true;
            _a = [
                processToRunNextFrame,
                processToRun
            ], processToRun = _a[0], processToRunNextFrame = _a[1];
            processToRunNextFrame.length = 0;
            numThisFrame = processToRun.length;
            if (numThisFrame) {
                var process_1;
                for (i = 0; i < numThisFrame; i++) {
                    process_1 = processToRun[i];
                    process_1(frame);
                    if (toKeepAlive.has(process_1) === true && !cancelled.has(process_1)) {
                        renderStep.schedule(process_1);
                        setRunNextFrame(true);
                    }
                }
            }
            isProcessing = false;
        },
        schedule: function (process, keepAlive, immediate) {
            if (keepAlive === void 0) { keepAlive = false; }
            if (immediate === void 0) { immediate = false; }
            invariant(typeof process === 'function', 'Argument must be a function');
            var addToCurrentBuffer = immediate && isProcessing;
            var buffer = addToCurrentBuffer ? processToRun : processToRunNextFrame;
            cancelled.delete(process);
            if (keepAlive)
                toKeepAlive.add(process);
            if (buffer.indexOf(process) === -1) {
                buffer.push(process);
                if (addToCurrentBuffer)
                    numThisFrame = processToRun.length;
            }
        }
    };
    return renderStep;
});

var StepId;
(function (StepId) {
    StepId["Read"] = "read";
    StepId["Update"] = "update";
    StepId["Render"] = "render";
    StepId["PostRender"] = "postRender";
    StepId["FixedUpdate"] = "fixedUpdate";
})(StepId || (StepId = {}));

var maxElapsed = 40;
var defaultElapsed = (1 / 60) * 1000;
var useDefaultElapsed = true;
var willRunNextFrame = false;
var isProcessing = false;
var frame = {
    delta: 0,
    timestamp: 0
};
var stepsOrder = [
    StepId.Read,
    StepId.Update,
    StepId.Render,
    StepId.PostRender
];
var setWillRunNextFrame = function (willRun) { return (willRunNextFrame = willRun); };
var _a = stepsOrder.reduce(function (acc, key) {
    var step = createStep(setWillRunNextFrame);
    acc.sync[key] = function (process, keepAlive, immediate) {
        if (keepAlive === void 0) { keepAlive = false; }
        if (immediate === void 0) { immediate = false; }
        if (!willRunNextFrame)
            startLoop();
        step.schedule(process, keepAlive, immediate);
        return process;
    };
    acc.cancelSync[key] = function (process) { return step.cancel(process); };
    acc.steps[key] = step;
    return acc;
}, {
    steps: {},
    sync: {},
    cancelSync: {}
}), steps = _a.steps, sync = _a.sync, cancelSync = _a.cancelSync;
var processStep = function (stepId) { return steps[stepId].process(frame); };
var processFrame = function (timestamp) {
    willRunNextFrame = false;
    frame.delta = useDefaultElapsed
        ? defaultElapsed
        : Math.max(Math.min(timestamp - frame.timestamp, maxElapsed), 1);
    if (!useDefaultElapsed)
        defaultElapsed = frame.delta;
    frame.timestamp = timestamp;
    isProcessing = true;
    stepsOrder.forEach(processStep);
    isProcessing = false;
    if (willRunNextFrame) {
        useDefaultElapsed = false;
        onNextFrame(processFrame);
    }
};
var startLoop = function () {
    willRunNextFrame = true;
    useDefaultElapsed = true;
    if (!isProcessing)
        onNextFrame(processFrame);
};
var getFrameData = function () { return frame; };

var isNum = function (v) { return typeof v === 'number'; };

var curryRange = (function (func) { return function (min, max, v) { return (v !== undefined ? func(min, max, v) : function (cv) { return func(min, max, cv); }); }; });

var clamp$1 = function (min, max, v) {
    return Math.min(Math.max(v, min), max);
};
var clamp$1$1 = curryRange(clamp$1);

var mix = (function (from, to, progress) {
    return -progress * from + progress * to + from;
});

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

var __assign$2 = function() {
    __assign$2 = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign$2.apply(this, arguments);
};

var mixLinearColor = function (from, to, v) {
    var fromExpo = from * from;
    var toExpo = to * to;
    return Math.sqrt(v * (toExpo - fromExpo) + fromExpo);
};
var colorTypes = [hex, rgba, hsla];
var getColorType = function (v) {
    return colorTypes.find(function (type) { return type.test(v); });
};
var mixColor = (function (from, to) {
    var fromColorType = getColorType(from);
    var toColorType = getColorType(to);
    invariant(fromColorType.transform === toColorType.transform, 'Both colors must be Hex and/or RGBA, or both must be HSLA');
    var fromColor = fromColorType.parse(from);
    var toColor = toColorType.parse(to);
    var blended = __assign$2({}, fromColor);
    var mixFunc = fromColorType === hsla ? mix : mixLinearColor;
    return function (v) {
        for (var key in blended) {
            if (key !== 'alpha') {
                blended[key] = mixFunc(fromColor[key], toColor[key], v);
            }
        }
        blended.alpha = mix(fromColor.alpha, toColor.alpha, v);
        return fromColorType.transform(blended);
    };
});

var combineFunctions = function (a, b) { return function (v) { return b(a(v)); }; };
var pipe = (function () {
    var transformers = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        transformers[_i] = arguments[_i];
    }
    return transformers.reduce(combineFunctions);
});

var mixArray = function (from, to) {
    var output = from.slice();
    var numValues = output.length;
    var blendValue = from.map(function (fromThis, i) {
        var toThis = to[i];
        if (isNum(fromThis)) {
            return function (v) { return mix(fromThis, toThis, v); };
        }
        else if (color.test(fromThis)) {
            return mixColor(fromThis, toThis);
        }
        else {
            return mixComplex(fromThis, toThis);
        }
    });
    return function (v) {
        for (var i = 0; i < numValues; i++) {
            output[i] = blendValue[i](v);
        }
        return output;
    };
};
var mixComplex = function (from, to) {
    var valueTemplate = complex.createTransformer(from);
    invariant(valueTemplate(from) === complex.createTransformer(to)(from), "Values '" + from + "' and '" + to + "' are of different format, or a value might have changed value type.");
    return pipe(mixArray(complex.parse(from), complex.parse(to)), valueTemplate);
};

var velocityPerSecond = (function (velocity, frameDuration) {
    return frameDuration ? velocity * (1000 / frameDuration) : 0;
});

var clampProgress = clamp$1$1(0, 1);

var Chainable = /*#__PURE__*/function () {
    function Chainable(props) {
        if (props === void 0) {
            props = {};
        }
        this.props = props;
    }
    Chainable.prototype.applyMiddleware = function (middleware) {
        return this.create(__assign({}, this.props, { middleware: this.props.middleware ? [middleware].concat(this.props.middleware) : [middleware] }));
    };
    Chainable.prototype.pipe = function () {
        var funcs = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            funcs[_i] = arguments[_i];
        }
        var pipedUpdate = funcs.length === 1 ? funcs[0] : pipe.apply(void 0, funcs);
        return this.applyMiddleware(function (update) {
            return function (v) {
                return update(pipedUpdate(v));
            };
        });
    };
    Chainable.prototype.while = function (predicate) {
        return this.applyMiddleware(function (update, complete) {
            return function (v) {
                return predicate(v) ? update(v) : complete();
            };
        });
    };
    Chainable.prototype.filter = function (predicate) {
        return this.applyMiddleware(function (update) {
            return function (v) {
                return predicate(v) && update(v);
            };
        });
    };
    return Chainable;
}();

var Observer = /*#__PURE__*/function () {
    function Observer(_a, observer) {
        var middleware = _a.middleware,
            onComplete = _a.onComplete;
        var _this = this;
        this.isActive = true;
        this.update = function (v) {
            if (_this.observer.update) _this.updateObserver(v);
        };
        this.complete = function () {
            if (_this.observer.complete && _this.isActive) _this.observer.complete();
            if (_this.onComplete) _this.onComplete();
            _this.isActive = false;
        };
        this.error = function (err) {
            if (_this.observer.error && _this.isActive) _this.observer.error(err);
            _this.isActive = false;
        };
        this.observer = observer;
        this.updateObserver = function (v) {
            return observer.update(v);
        };
        this.onComplete = onComplete;
        if (observer.update && middleware && middleware.length) {
            middleware.forEach(function (m) {
                return _this.updateObserver = m(_this.updateObserver, _this.complete);
            });
        }
    }
    return Observer;
}();
var createObserver = function (observerCandidate, _a, onComplete) {
    var middleware = _a.middleware;
    if (typeof observerCandidate === 'function') {
        return new Observer({ middleware: middleware, onComplete: onComplete }, { update: observerCandidate });
    } else {
        return new Observer({ middleware: middleware, onComplete: onComplete }, observerCandidate);
    }
};

var Action = /*#__PURE__*/function (_super) {
    __extends(Action, _super);
    function Action() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Action.prototype.create = function (props) {
        return new Action(props);
    };
    Action.prototype.start = function (observerCandidate) {
        if (observerCandidate === void 0) {
            observerCandidate = {};
        }
        var isComplete = false;
        var subscription = {
            stop: function () {
                return undefined;
            }
        };
        var _a = this.props,
            init = _a.init,
            observerProps = __rest(_a, ["init"]);
        var observer = createObserver(observerCandidate, observerProps, function () {
            isComplete = true;
            subscription.stop();
        });
        var api = init(observer);
        subscription = api ? __assign({}, subscription, api) : subscription;
        if (observerCandidate.registerParent) {
            observerCandidate.registerParent(subscription);
        }
        if (isComplete) subscription.stop();
        return subscription;
    };
    return Action;
}(Chainable);
var action = function (init) {
    return new Action({ init: init });
};

var BaseMulticast = /*#__PURE__*/function (_super) {
    __extends(BaseMulticast, _super);
    function BaseMulticast() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.subscribers = [];
        return _this;
    }
    BaseMulticast.prototype.complete = function () {
        this.subscribers.forEach(function (subscriber) {
            return subscriber.complete();
        });
    };
    BaseMulticast.prototype.error = function (err) {
        this.subscribers.forEach(function (subscriber) {
            return subscriber.error(err);
        });
    };
    BaseMulticast.prototype.update = function (v) {
        for (var i = 0; i < this.subscribers.length; i++) {
            this.subscribers[i].update(v);
        }
    };
    BaseMulticast.prototype.subscribe = function (observerCandidate) {
        var _this = this;
        var observer = createObserver(observerCandidate, this.props);
        this.subscribers.push(observer);
        var subscription = {
            unsubscribe: function () {
                var index = _this.subscribers.indexOf(observer);
                if (index !== -1) _this.subscribers.splice(index, 1);
            }
        };
        return subscription;
    };
    BaseMulticast.prototype.stop = function () {
        if (this.parent) this.parent.stop();
    };
    BaseMulticast.prototype.registerParent = function (subscription) {
        this.stop();
        this.parent = subscription;
    };
    return BaseMulticast;
}(Chainable);

var isValueList = function (v) {
    return Array.isArray(v);
};
var isSingleValue = function (v) {
    var typeOfV = typeof v;
    return typeOfV === 'string' || typeOfV === 'number';
};
var ValueReaction = /*#__PURE__*/function (_super) {
    __extends(ValueReaction, _super);
    function ValueReaction(props) {
        var _this = _super.call(this, props) || this;
        _this.scheduleVelocityCheck = function () {
            return sync.postRender(_this.velocityCheck);
        };
        _this.velocityCheck = function (_a) {
            var timestamp = _a.timestamp;
            if (timestamp !== _this.lastUpdated) {
                _this.prev = _this.current;
            }
        };
        _this.prev = _this.current = props.value || 0;
        if (isSingleValue(_this.current)) {
            _this.updateCurrent = function (v) {
                return _this.current = v;
            };
            _this.getVelocityOfCurrent = function () {
                return _this.getSingleVelocity(_this.current, _this.prev);
            };
        } else if (isValueList(_this.current)) {
            _this.updateCurrent = function (v) {
                return _this.current = v.slice();
            };
            _this.getVelocityOfCurrent = function () {
                return _this.getListVelocity();
            };
        } else {
            _this.updateCurrent = function (v) {
                _this.current = {};
                for (var key in v) {
                    if (v.hasOwnProperty(key)) {
                        _this.current[key] = v[key];
                    }
                }
            };
            _this.getVelocityOfCurrent = function () {
                return _this.getMapVelocity();
            };
        }
        if (props.initialSubscription) _this.subscribe(props.initialSubscription);
        return _this;
    }
    ValueReaction.prototype.create = function (props) {
        return new ValueReaction(props);
    };
    ValueReaction.prototype.get = function () {
        return this.current;
    };
    ValueReaction.prototype.getVelocity = function () {
        return this.getVelocityOfCurrent();
    };
    ValueReaction.prototype.update = function (v) {
        _super.prototype.update.call(this, v);
        this.prev = this.current;
        this.updateCurrent(v);
        var _a = getFrameData(),
            delta = _a.delta,
            timestamp = _a.timestamp;
        this.timeDelta = delta;
        this.lastUpdated = timestamp;
        sync.postRender(this.scheduleVelocityCheck);
    };
    ValueReaction.prototype.subscribe = function (observerCandidate) {
        var sub = _super.prototype.subscribe.call(this, observerCandidate);
        this.subscribers[this.subscribers.length - 1].update(this.current);
        return sub;
    };
    ValueReaction.prototype.getSingleVelocity = function (current, prev) {
        return typeof current === 'number' && typeof prev === 'number' ? velocityPerSecond(current - prev, this.timeDelta) : velocityPerSecond(parseFloat(current) - parseFloat(prev), this.timeDelta) || 0;
    };
    ValueReaction.prototype.getListVelocity = function () {
        var _this = this;
        return this.current.map(function (c, i) {
            return _this.getSingleVelocity(c, _this.prev[i]);
        });
    };
    ValueReaction.prototype.getMapVelocity = function () {
        var velocity = {};
        for (var key in this.current) {
            if (this.current.hasOwnProperty(key)) {
                velocity[key] = this.getSingleVelocity(this.current[key], this.prev[key]);
            }
        }
        return velocity;
    };
    return ValueReaction;
}(BaseMulticast);
var value = function (value, initialSubscription) {
    return new ValueReaction({ value: value, initialSubscription: initialSubscription });
};

var multi = function (_a) {
    var getCount = _a.getCount,
        getFirst = _a.getFirst,
        getOutput = _a.getOutput,
        mapApi = _a.mapApi,
        setProp = _a.setProp,
        startActions = _a.startActions;
    return function (actions) {
        return action(function (_a) {
            var update = _a.update,
                complete = _a.complete,
                error = _a.error;
            var numActions = getCount(actions);
            var output = getOutput();
            var updateOutput = function () {
                return update(output);
            };
            var numCompletedActions = 0;
            var subs = startActions(actions, function (a, name) {
                var hasCompleted = false;
                return a.start({
                    complete: function () {
                        if (!hasCompleted) {
                            hasCompleted = true;
                            numCompletedActions++;
                            if (numCompletedActions === numActions) sync.update(complete);
                        }
                    },
                    error: error,
                    update: function (v) {
                        setProp(output, name, v);
                        sync.update(updateOutput, false, true);
                    }
                });
            });
            return Object.keys(getFirst(subs)).reduce(function (api, methodName) {
                api[methodName] = mapApi(subs, methodName);
                return api;
            }, {});
        });
    };
};

var composite = /*#__PURE__*/multi({
    getOutput: function () {
        return {};
    },
    getCount: function (subs) {
        return Object.keys(subs).length;
    },
    getFirst: function (subs) {
        return subs[Object.keys(subs)[0]];
    },
    mapApi: function (subs, methodName) {
        return function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return Object.keys(subs).reduce(function (output, propKey) {
                var _a;
                if (subs[propKey][methodName]) {
                    args[0] && args[0][propKey] !== undefined ? output[propKey] = subs[propKey][methodName](args[0][propKey]) : output[propKey] = (_a = subs[propKey])[methodName].apply(_a, args);
                }
                return output;
            }, {});
        };
    },
    setProp: function (output, name, v) {
        return output[name] = v;
    },
    startActions: function (actions, starter) {
        return Object.keys(actions).reduce(function (subs, key) {
            subs[key] = starter(actions[key], key);
            return subs;
        }, {});
    }
});

var parallel = /*#__PURE__*/multi({
    getOutput: function () {
        return [];
    },
    getCount: function (subs) {
        return subs.length;
    },
    getFirst: function (subs) {
        return subs[0];
    },
    mapApi: function (subs, methodName) {
        return function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return subs.map(function (sub, i) {
                if (sub[methodName]) {
                    return Array.isArray(args[0]) ? sub[methodName](args[0][i]) : sub[methodName].apply(sub, args);
                }
            });
        };
    },
    setProp: function (output, name, v) {
        return output[name] = v;
    },
    startActions: function (actions, starter) {
        return actions.map(function (action, i) {
            return starter(action, i);
        });
    }
});
var parallel$1 = function () {
    var actions = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        actions[_i] = arguments[_i];
    }
    return parallel(actions);
};

var createVectorTests = function (typeTests) {
    var testNames = Object.keys(typeTests);
    var isVectorProp = function (prop, key) {
        return prop !== undefined && !typeTests[key](prop);
    };
    var getVectorKeys = function (props) {
        return testNames.reduce(function (vectorKeys, key) {
            if (isVectorProp(props[key], key)) vectorKeys.push(key);
            return vectorKeys;
        }, []);
    };
    var testVectorProps = function (props) {
        return props && testNames.some(function (key) {
            return isVectorProp(props[key], key);
        });
    };
    return { getVectorKeys: getVectorKeys, testVectorProps: testVectorProps };
};
var unitTypes = [px, percent, degrees, vh, vw];
var findUnitType = function (prop) {
    return unitTypes.find(function (type) {
        return type.test(prop);
    });
};
var isUnitProp = function (prop) {
    return Boolean(findUnitType(prop));
};
var createAction = function (action, props) {
    return action(props);
};
var reduceArrayValue = function (i) {
    return function (props, key) {
        props[key] = props[key][i];
        return props;
    };
};
var createArrayAction = function (action, props, vectorKeys) {
    var firstVectorKey = vectorKeys[0];
    var actionList = props[firstVectorKey].map(function (v, i) {
        var childActionProps = vectorKeys.reduce(reduceArrayValue(i), __assign({}, props));
        return getActionCreator(v)(action, childActionProps);
    });
    return parallel$1.apply(void 0, actionList);
};
var reduceObjectValue = function (key) {
    return function (props, propKey) {
        props[propKey] = props[propKey][key];
        return props;
    };
};
var createObjectAction = function (action, props, vectorKeys) {
    var firstVectorKey = vectorKeys[0];
    var actionMap = Object.keys(props[firstVectorKey]).reduce(function (map, key) {
        var childActionProps = vectorKeys.reduce(reduceObjectValue(key), __assign({}, props));
        map[key] = getActionCreator(props[firstVectorKey][key])(action, childActionProps);
        return map;
    }, {});
    return composite(actionMap);
};
var createUnitAction = function (action, _a) {
    var from = _a.from,
        to = _a.to,
        props = __rest(_a, ["from", "to"]);
    var unitType = findUnitType(from) || findUnitType(to);
    var transform = unitType.transform,
        parse = unitType.parse;
    return action(__assign({}, props, { from: typeof from === 'string' ? parse(from) : from, to: typeof to === 'string' ? parse(to) : to })).pipe(transform);
};
var createColorAction = function (action, _a) {
    var from = _a.from,
        to = _a.to,
        props = __rest(_a, ["from", "to"]);
    return action(__assign({}, props, { from: 0, to: 1 })).pipe(mixColor(from, to), color.transform);
};
var createComplexAction = function (action, _a) {
    var from = _a.from,
        to = _a.to,
        props = __rest(_a, ["from", "to"]);
    var valueTemplate = complex.createTransformer(from);
    invariant(valueTemplate(from) === complex.createTransformer(to)(from), "Values '" + from + "' and '" + to + "' are of different format, or a value might have changed value type.");
    return action(__assign({}, props, { from: 0, to: 1 })).pipe(mixArray(complex.parse(from), complex.parse(to)), valueTemplate);
};
var createVectorAction = function (action, typeTests) {
    var _a = createVectorTests(typeTests),
        testVectorProps = _a.testVectorProps,
        getVectorKeys = _a.getVectorKeys;
    var vectorAction = function (props) {
        var isVector = testVectorProps(props);
        if (!isVector) return action(props);
        var vectorKeys = getVectorKeys(props);
        var testKey = vectorKeys[0];
        var testProp = props[testKey];
        return getActionCreator(testProp)(action, props, vectorKeys);
    };
    return vectorAction;
};
var getActionCreator = function (prop) {
    var actionCreator = createAction;
    if (typeof prop === 'number') {
        actionCreator = createAction;
    } else if (Array.isArray(prop)) {
        actionCreator = createArrayAction;
    } else if (isUnitProp(prop)) {
        actionCreator = createUnitAction;
    } else if (color.test(prop)) {
        actionCreator = createColorAction;
    } else if (complex.test(prop)) {
        actionCreator = createComplexAction;
    } else if (typeof prop === 'object') {
        actionCreator = createObjectAction;
    }
    return actionCreator;
};

var decay = function (props) {
    if (props === void 0) {
        props = {};
    }
    return action(function (_a) {
        var complete = _a.complete,
            update = _a.update;
        var _b = props.velocity,
            velocity = _b === void 0 ? 0 : _b,
            _c = props.from,
            from = _c === void 0 ? 0 : _c,
            _d = props.power,
            power = _d === void 0 ? 0.8 : _d,
            _e = props.timeConstant,
            timeConstant = _e === void 0 ? 350 : _e,
            _f = props.restDelta,
            restDelta = _f === void 0 ? 0.5 : _f,
            modifyTarget = props.modifyTarget;
        var elapsed = 0;
        var amplitude = power * velocity;
        var idealTarget = Math.round(from + amplitude);
        var target = typeof modifyTarget === 'undefined' ? idealTarget : modifyTarget(idealTarget);
        var process = sync.update(function (_a) {
            var frameDelta = _a.delta;
            elapsed += frameDelta;
            var delta = -amplitude * Math.exp(-elapsed / timeConstant);
            var isMoving = delta > restDelta || delta < -restDelta;
            var current = isMoving ? target + delta : target;
            update(current);
            if (!isMoving) {
                cancelSync.update(process);
                complete();
            }
        }, true);
        return {
            stop: function () {
                return cancelSync.update(process);
            }
        };
    });
};
var vectorDecay = /*#__PURE__*/createVectorAction(decay, {
    from: number.test,
    modifyTarget: function (func) {
        return typeof func === 'function';
    },
    velocity: number.test
});

var spring = function (props) {
    if (props === void 0) {
        props = {};
    }
    return action(function (_a) {
        var update = _a.update,
            complete = _a.complete;
        var _b = props.velocity,
            velocity = _b === void 0 ? 0.0 : _b;
        var _c = props.from,
            from = _c === void 0 ? 0.0 : _c,
            _d = props.to,
            to = _d === void 0 ? 0.0 : _d,
            _e = props.stiffness,
            stiffness = _e === void 0 ? 100 : _e,
            _f = props.damping,
            damping = _f === void 0 ? 10 : _f,
            _g = props.mass,
            mass = _g === void 0 ? 1.0 : _g,
            _h = props.restSpeed,
            restSpeed = _h === void 0 ? 0.01 : _h,
            _j = props.restDelta,
            restDelta = _j === void 0 ? 0.01 : _j;
        var initialVelocity = velocity ? -(velocity / 1000) : 0.0;
        var t = 0;
        var delta = to - from;
        var position = from;
        var prevPosition = position;
        var process = sync.update(function (_a) {
            var timeDelta = _a.delta;
            t += timeDelta;
            var dampingRatio = damping / (2 * Math.sqrt(stiffness * mass));
            var angularFreq = Math.sqrt(stiffness / mass) / 1000;
            prevPosition = position;
            if (dampingRatio < 1) {
                var envelope = Math.exp(-dampingRatio * angularFreq * t);
                var expoDecay = angularFreq * Math.sqrt(1.0 - dampingRatio * dampingRatio);
                position = to - envelope * ((initialVelocity + dampingRatio * angularFreq * delta) / expoDecay * Math.sin(expoDecay * t) + delta * Math.cos(expoDecay * t));
            } else {
                var envelope = Math.exp(-angularFreq * t);
                position = to - envelope * (delta + (initialVelocity + angularFreq * delta) * t);
            }
            velocity = velocityPerSecond(position - prevPosition, timeDelta);
            var isBelowVelocityThreshold = Math.abs(velocity) <= restSpeed;
            var isBelowDisplacementThreshold = Math.abs(to - position) <= restDelta;
            if (isBelowVelocityThreshold && isBelowDisplacementThreshold) {
                position = to;
                update(position);
                cancelSync.update(process);
                complete();
            } else {
                update(position);
            }
        }, true);
        return {
            stop: function () {
                return cancelSync.update(process);
            }
        };
    });
};
var vectorSpring = /*#__PURE__*/createVectorAction(spring, {
    from: number.test,
    to: number.test,
    stiffness: number.test,
    damping: number.test,
    mass: number.test,
    velocity: number.test
});

var listen = function (element, events, options) {
    return action(function (_a) {
        var update = _a.update;
        var eventNames = events.split(' ').map(function (eventName) {
            element.addEventListener(eventName, update, options);
            return eventName;
        });
        return {
            stop: function () {
                return eventNames.forEach(function (eventName) {
                    return element.removeEventListener(eventName, update, options);
                });
            }
        };
    });
};

var defaultPointerPos = function () {
    return {
        clientX: 0,
        clientY: 0,
        pageX: 0,
        pageY: 0,
        x: 0,
        y: 0
    };
};
var eventToPoint = function (e, point) {
    if (point === void 0) {
        point = defaultPointerPos();
    }
    point.clientX = point.x = e.clientX;
    point.clientY = point.y = e.clientY;
    point.pageX = e.pageX;
    point.pageY = e.pageY;
    return point;
};

var points = [/*#__PURE__*/defaultPointerPos()];
if (typeof document !== 'undefined') {
    var updatePointsLocation = function (_a) {
        var touches = _a.touches;
        var numTouches = touches.length;
        points.length = 0;
        for (var i = 0; i < numTouches; i++) {
            var thisTouch = touches[i];
            points.push(eventToPoint(thisTouch));
        }
    };
    listen(document, 'touchstart touchmove', {
        passive: true,
        capture: true
    }).start(updatePointsLocation);
}

var point = /*#__PURE__*/defaultPointerPos();
if (typeof document !== 'undefined') {
    var updatePointLocation = function (e) {
        eventToPoint(e, point);
    };
    listen(document, 'mousedown mousemove', true).start(updatePointLocation);
}

const VELOCITY = 10;
const DAMPING = 100;
// https://github.com/Popmotion/popmotion/issues/645
const pathTransition = ({ from, to }) => vectorSpring({
    from: 0,
    to: 1,
    velocity: VELOCITY,
    damping: DAMPING
}).pipe(interpolate$1(from, to));
const transition = {
    opacity: {
        type: 'tween',
        ease: 'linear',
        duration: 1000
    },
    strokeDasharray: {
        type: 'tween',
        duration: 500
    },
    d: pathTransition,
    default: {
        type: 'spring',
        velocity: VELOCITY,
        damping: DAMPING
    }
};
const PoseSVGGElement = posed.g({});

const PosedCircle = posed.circle({
    enter: {
        cx: ({ enterProps }) => enterProps.cx,
        cy: ({ enterProps }) => enterProps.cy,
        r: ({ size }) => size,
        delay: ({ animated, index }) => (animated ? index * 10 : 0),
        transition: Object.assign({}, transition, { 
            // Circles need same easing as area/line
            cx: pathTransition, cy: pathTransition })
        // https://github.com/Popmotion/popmotion/issues/646
        // transition: ({ animated }) => (animated ? transition : { duration: 0 })
    },
    exit: {
        cx: ({ exitProps }) => exitProps.cx,
        cy: ({ exitProps }) => exitProps.cy,
        r: 0
    }
});

class Circle extends Component {
    onClick(event) {
        const { onClick, point } = this.props;
        onClick({
            value: point,
            nativeEvent: event
        });
    }
    onMouseEnter(event) {
        const { onMouseEnter, point } = this.props;
        onMouseEnter({
            value: point,
            nativeEvent: event
        });
    }
    onMouseLeave(event) {
        const { onMouseLeave, point } = this.props;
        onMouseLeave({
            value: point,
            nativeEvent: event
        });
    }
    getCircleEnter() {
        const { yScale, xScale, size, point } = this.props;
        return {
            cy: yScale(point.y1),
            cx: xScale(point.x),
            r: size
        };
    }
    getCircleExit() {
        const { yScale, xScale, point, animated } = this.props;
        let cy;
        if (animated) {
            cy = Math.max(...yScale.range());
        }
        else {
            cy = yScale(point.y1);
        }
        return {
            cy,
            cx: xScale(point.x)
        };
    }
    render() {
        const { fill, cursor, visible, animated, size } = this.props;
        const opacity = visible ? 1 : 0;
        const enterProps = this.getCircleEnter();
        const exitProps = this.getCircleExit();
        return (React.createElement(PosedCircle, { className: "symbol", pose: "enter", poseKey: `${enterProps.cy}-${enterProps.cx}`, enterProps: enterProps, exitProps: exitProps, animated: animated, onClick: bind(this.onClick, this), onMouseEnter: bind(this.onMouseEnter, this), onMouseLeave: bind(this.onMouseLeave, this), cursor: cursor, size: size, style: { opacity }, pointerEvents: "auto", fill: fill }));
    }
}
Circle.defaultProps = {
    size: 4,
    cursor: 'auto',
    onClick: () => undefined,
    onMouseEnter: () => undefined,
    onMouseLeave: () => undefined
};

/**
 * CloneElement is a wrapper component for createElement function.
 * This allows you to describe your cloning element declaratively
 * which is a more natural API for React.
 */
class CloneElement extends PureComponent {
    constructor() {
        super(...arguments);
        this.getProjectedProps = memoize(props => {
            const childProps = this.props.element.props;
            return Object.keys(props).reduce((acc, key) => {
                const prop = props[key];
                const childProp = childProps[key];
                if (isFunction(prop) && childProp) {
                    acc[key] = args => {
                        prop(args);
                        childProp(args);
                    };
                }
                else {
                    acc[key] = prop;
                }
                return acc;
            }, {});
        });
    }
    render() {
        const _a = this.props, { element, children } = _a, rest = __rest(_a, ["element", "children"]);
        if (element === null) {
            return children;
        }
        const newProps = this.getProjectedProps(rest);
        return cloneElement(element, Object.assign({}, element.props, newProps, { children }));
    }
}

class CircleSeries extends React.Component {
    constructor() {
        super(...arguments);
        this.renderCircle = (point, index) => {
            const visible = this.isVisible(point, index);
            if (!visible) {
                return null;
            }
            const { color, yScale, xScale, animated, circle } = this.props;
            const fill = color(point, index);
            return (React.createElement(CloneElement, { element: circle, key: `circle-${index}`, fill: fill, visible: visible, point: point, yScale: yScale, xScale: xScale, animated: animated }));
        };
    }
    isVisible(point, index) {
        const { show, activeValues, data } = this.props;
        const isActive = activeValues && point && isEqual(activeValues.x, point.x);
        if (show === 'hover') {
            return isActive;
        }
        else if (show === 'first') {
            if (activeValues) {
                return isActive;
            }
            else {
                return index === 0;
            }
        }
        else if (show === 'last') {
            if (activeValues) {
                return isActive;
            }
            else {
                return index === data.length - 1;
            }
        }
        return show;
    }
    render() {
        return React.createElement(Fragment, null, this.props.data.map(this.renderCircle));
    }
}
CircleSeries.defaultProps = {
    circle: React.createElement(Circle, null),
    show: 'hover'
};

class Gradient extends React.Component {
    render() {
        const { id, color, offsets } = this.props;
        return (React.createElement("linearGradient", { spreadMethod: "pad", id: id, x1: "10%", x2: "10%", y1: "100%", y2: "0%" }, offsets.map((offset, index) => (React.createElement("stop", { key: `gradient-${index}`, offset: offset.offset, stopColor: offset.color || color, stopOpacity: offset.stopOpacity })))));
    }
}
Gradient.defaultProps = {
    offsets: [
        { offset: '0%', stopOpacity: 0.3 },
        { offset: '80%', stopOpacity: 1 }
    ]
};

class Stripes extends React.Component {
    render() {
        const { id, fill } = this.props;
        return (React.createElement("pattern", { id: id, width: "4", height: "4", patternUnits: "userSpaceOnUse", patternTransform: "rotate(45)" },
            React.createElement("rect", { className: "area-stripe", width: "1", height: "4", fill: fill })));
    }
}

class Mask extends React.Component {
    render() {
        const { id, fill } = this.props;
        return (React.createElement("mask", { id: id },
            React.createElement("rect", { x: "0", y: "0", width: "100%", height: "100%", fill: fill })));
    }
}

/**
 * Helper function for interpolation.
 */
function interpolate(type) {
    if (type === 'smooth') {
        return curveMonotoneX;
    }
    else if (type === 'step') {
        return curveStep;
    }
    else {
        return curveLinear;
    }
}

const PosedArea = posed.path({
    enter: {
        d: ({ enterProps }) => enterProps.d,
        delay: ({ animated, index }) => (animated ? index * 10 : 0),
        transition: ({ animated }) => (animated ? transition : { duration: 0 })
    },
    exit: {
        d: ({ exitProps }) => exitProps.d
    }
});

class Area extends Component {
    getAreaPath(data) {
        const { interpolation } = this.props;
        const fn = area()
            .x((d) => d.x)
            .y0((d) => d.y0)
            .y1((d) => d.y1)
            .curve(interpolate(interpolation));
        return fn(data);
    }
    getCoords() {
        const { data, xScale, yScale } = this.props;
        return data.map((item) => ({
            x: xScale(item.x),
            x1: xScale(item.x) - xScale(item.x1),
            y: yScale(item.y),
            y0: yScale(item.y0),
            y1: yScale(item.y1)
        }));
    }
    getAreaEnter(coords) {
        const areaPath = this.getAreaPath(coords);
        return {
            d: areaPath === null ? undefined : areaPath
        };
    }
    getAreaExit() {
        const { yScale, data, xScale } = this.props;
        const maxY = Math.max(...yScale.range());
        const coords = data.map((item) => ({
            x: xScale(item.x),
            x1: 0,
            y: 0,
            y1: maxY,
            y0: maxY
        }));
        const areaPath = this.getAreaPath(coords);
        return {
            d: areaPath === null ? undefined : areaPath
        };
    }
    getGradientOffsets() {
        const { gradient } = this.props;
        return Array.isArray(gradient) ? gradient : undefined;
    }
    getFill() {
        const { pattern, id, gradient } = this.props;
        if (pattern) {
            return `url(#stripes-${id})`;
        }
        else {
            if (gradient) {
                return `url(#gradient-${id})`;
            }
            return '';
        }
    }
    renderArea(coords) {
        const { pattern, index, id, animated } = this.props;
        const fill = this.getFill();
        const mask = pattern ? `url(#mask-${id})` : '';
        const enterProps = this.getAreaEnter(coords);
        const exitProps = this.getAreaExit();
        return (React.createElement(PosedArea, { pose: "enter", poseKey: enterProps.d, animated: animated, pointerEvents: "none", mask: mask, index: index, fill: fill, enterProps: enterProps, exitProps: exitProps }));
    }
    render() {
        const { id, gradient, pattern, data, color, index } = this.props;
        const gradientOffsets = this.getGradientOffsets();
        const coords = this.getCoords();
        const stroke = color(data, index);
        return (React.createElement(Fragment, null,
            this.renderArea(coords),
            gradient && !pattern && (React.createElement(Gradient, { id: `gradient-${id}`, color: stroke, offsets: gradientOffsets })),
            pattern && (React.createElement(Fragment, null,
                React.createElement(Mask, { id: `mask-${id}`, fill: `url(#gradient-${id})` }),
                React.createElement(Gradient, { id: `gradient-${id}`, color: stroke, offsets: gradientOffsets }),
                React.createElement(Stripes, { id: `stripes-${id}`, fill: stroke })))));
    }
}
Area.defaultProps = {
    gradient: true,
    pattern: false,
    interpolation: 'linear'
};

var markLine = "MarkLine-module_markLine__Uilm3";

class MarkLine extends Component {
    render() {
        const { pointX, height, strokeColor, strokeWidth } = this.props;
        return (React.createElement("line", { stroke: strokeColor, strokeWidth: strokeWidth, y1: "0", vectorEffect: "non-scaling-stroke", y2: height, x1: pointX, x2: pointX, className: markLine }));
    }
}
MarkLine.defaultProps = {
    strokeWidth: 1,
    strokeColor: '#eee'
};

const humanFormatScale = new humanFormat.Scale({
    k: 1000,
    M: 1000000,
    B: 1000000000
});
const humanFormatMillionScale = new humanFormat.Scale({
    M: 1,
    B: 1000,
    T: 1000000
});
const ONE_MILLION = 1000000;
const ONE_BILLION = 1000000000;
const humanFormatBigInteger = bigInteger => {
    if (bigInteger.greater(ONE_BILLION)) {
        return humanFormat(bigInteger.divide(ONE_MILLION).toJSNumber(), {
            scale: humanFormatMillionScale
        });
    }
    return humanFormat(bigInteger.toJSNumber(), { scale: humanFormatScale });
};
const bigIntegerToLocaleString = bigInteger => {
    let i = 0;
    let formattedString = '';
    for (const c of bigInteger
        .toString()
        .split('')
        .reverse()) {
        if (i > 0 && i % 3 === 0) {
            formattedString = ',' + formattedString;
        }
        formattedString = c + formattedString;
        i++;
    }
    return formattedString;
};

/**
 * Returns if the data shape is a multi-series format.
 */
function isMultiSeries(data) {
    const series = data;
    return series && series.length && Array.isArray(series[0].data);
}

function normalizeValue(value, maxBigInt) {
    if (bigInt.isInstance(value)) {
        if (maxBigInt.greater(1000000)) {
            const divideBy = maxBigInt.divide(1000000);
            return value.divide(divideBy).toJSNumber();
        }
        else {
            return value.toJSNumber();
        }
    }
    else {
        return value;
    }
}
function normalizeValueForFormatting(value) {
    if (bigInt.isInstance(value)) {
        return bigIntegerToLocaleString(value);
    }
    return value;
}
function getMaxBigInteger(series) {
    if (isMultiSeries(series)) {
        return getMaxBigIntegerForNested(series);
    }
    else {
        return getMaxBigIntegerForShallow(series);
    }
}
function getMaxBigIntegerForNested(series) {
    let maxBigInteger = bigInt.one;
    for (const group of series) {
        const maxBigIntegerForGroup = getMaxBigIntegerForShallow(group.data);
        if (maxBigIntegerForGroup.greater(maxBigInteger)) {
            maxBigInteger = maxBigIntegerForGroup;
        }
    }
    return maxBigInteger;
}
function getMaxBigIntegerForShallow(series) {
    let maxBigInteger = bigInt.one;
    for (const point of series) {
        if (bigInt.isInstance(point.data)) {
            const bigInteger = point.data;
            if (bigInteger.greater(maxBigInteger)) {
                maxBigInteger = bigInteger;
            }
        }
    }
    return maxBigInteger;
}

/**
 * Discriminator for ChartInternalDataShape
 */
const isNested = (t) => t.data !== undefined;
/**
 * Transforms the data from a chart shape to internally readable format.
 */
function buildChartData(series, sort = false, direction = 'horizontal') {
    if (isMultiSeries(series)) {
        return buildNestedChartData(series, sort, direction);
    }
    else {
        return buildShallowChartData(series, direction);
    }
}
/**
 * Accepts a `ChartDataShape` and transforms it to a chart readable data shape.
 *
 * Example:
 *
 *   [{
 *    key: 'Threat Intel',
 *    data: [{ key:'2011', data: 25 }]
 *   }]
 *
 * will be transformed to:
 *
 *  [{
 *    key: 'Threat Intel',
 *    data: [
 *      key: 'Threat Intel',
 *      x: '2011',
 *      y: 25
 *    ]
 *  }]
 */
function buildNestedChartData(series, sort = false, direction = 'horizontal') {
    let result = [];
    const maxBigInteger = getMaxBigInteger(series);
    for (const point of series) {
        for (const nestedPoint of point.data) {
            const key = normalizeValueForFormatting(point.key);
            let idx = result.findIndex(r => {
                const left = r.key;
                if (left instanceof Date && key instanceof Date) {
                    return left.getTime() === key.getTime();
                }
                return left === key;
            });
            if (idx === -1) {
                result.push({
                    key,
                    data: []
                });
                idx = result.length - 1;
            }
            const x = normalizeValue(direction === 'horizontal' ? nestedPoint.key : nestedPoint.data, maxBigInteger);
            const y = normalizeValue(direction === 'horizontal' ? nestedPoint.data : nestedPoint.key, maxBigInteger);
            result[idx].data.push({
                key,
                value: normalizeValueForFormatting(nestedPoint.data),
                meta: point.meta,
                id: point.id,
                x,
                x0: x,
                x1: x,
                y,
                y0: 0,
                y1: y
            });
        }
    }
    // Sort the series data based on the median value
    if (sort) {
        result = result.sort((a, b) => {
            const aMax = median(a.data, (d) => d.y);
            const bMax = median(b.data, (d) => d.y);
            return aMax < bMax ? 1 : -1;
        });
    }
    return result;
}
/**
 * Accepts a shallow shape and normalizes it to a chart readable format.
 */
function buildShallowChartData(series, direction = 'horizontal') {
    const result = [];
    const maxBigInteger = getMaxBigInteger(series);
    for (const point of series) {
        const x = normalizeValue(direction === 'horizontal' ? point.key : point.data, maxBigInteger);
        const y = normalizeValue(direction === 'horizontal' ? point.data : point.key, maxBigInteger);
        result.push({
            key: normalizeValueForFormatting(point.key),
            value: normalizeValueForFormatting(point.data),
            meta: point.meta,
            id: point.id,
            x,
            x0: x,
            x1: x,
            y,
            y0: 0,
            y1: y
        });
    }
    return result;
}

/**
 * Build a histogram given data set.
 */
function buildBins(xScale, thresholds, data) {
    const layout = histogram()
        .value((d) => d.x)
        .domain(xScale.domain())
        .thresholds(xScale.ticks(thresholds));
    const bins = layout(data);
    return bins.map(bin => ({
        x0: bin.x0,
        x1: bin.x1,
        y: bin.length,
        y0: 0,
        y1: bin.length
    }));
}

/**
 * Gets the min/max values handling nested arrays.
 */
function extent(data, attr) {
    const accessor = (val, fn) => {
        if (Array.isArray(val.data)) {
            return fn(val.data, vv => vv[attr]);
        }
        return val[attr];
    };
    const minVal = min(data, d => accessor(d, min));
    const maxVal = max(data, d => accessor(d, max));
    return [minVal, maxVal];
}
/**
 * Get the domain for the Y Axis.
 */
function getYDomain({ scaled, data }) {
    const minMax = extent(data, 'y1');
    return scaled ? minMax : [0, minMax[1]];
}
/**
 * Get the domain for the X Axis.
 */
function getXDomain({ data }) {
    return extent(data, 'x');
}
/**
 * Returns a unique group domain.
 */
function getGroupDomain(data, attr) {
    return data.reduce((acc, cur) => {
        const val = cur[attr];
        if (acc.indexOf(val) === -1) {
            acc.push(val);
        }
        return acc;
    }, []);
}
/**
 * Get a deeply nested group domain.
 */
function getDeepGroupDomain(data, attr) {
    return data.reduce((acc, cur) => {
        const filtered = getGroupDomain(cur.data, attr).filter(d => acc.indexOf(d) === -1);
        acc.push(...filtered);
        return acc;
    }, []);
}

/**
 * Given a dataset like:
 *
 *   [{
 *    key: 'Threat Intel',
 *    data: [{ key:'2011', data: 25 }]
 *   }]
 *
 * it will transform it to:
 *
 *  [
 *    { x: 'Theat Intel', '2011': 25 }
 *  ]
 */
function transformDataToStack(data) {
    const result = [];
    const maxBigInteger = getMaxBigInteger(data);
    for (const category of data) {
        for (const value of category.data) {
            let idx = result.findIndex(r => {
                if (r.x instanceof Date && category.key instanceof Date) {
                    return r.x.getTime() === category.key.getTime();
                }
                return r.x === category.key;
            });
            if (idx === -1) {
                result.push({
                    x: category.key,
                    formattedValues: {}
                });
                idx = result.length - 1;
            }
            result[idx][value.key] = normalizeValue(value.data, maxBigInteger);
            result[idx].formattedValues[value.key] = normalizeValueForFormatting(value.data);
        }
    }
    return result;
}
/**
 * Translates the stack data to a chart standard dataset.
 */
function transformStackToData(stackData) {
    const result = [];
    // Transform the data from the d3 stack format to our internal format
    for (const category of stackData) {
        for (const point of category) {
            const key = point.data.x;
            let idx = result.findIndex(r => {
                if (r.key instanceof Date && key instanceof Date) {
                    return r.key.getTime() === key.getTime();
                }
                return r.key === key;
            });
            if (idx === -1) {
                result.push({
                    key,
                    data: []
                });
                idx = result.length - 1;
            }
            const [y0, y1] = point;
            result[idx].data.push({
                key,
                x: category.key,
                x0: category.key,
                x1: category.key,
                y: point.data[category.key],
                y0,
                y1,
                value: point.data.formattedValues[category.key]
            });
        }
    }
    return result;
}
/**
 * Builds a stack dataset from the standard data format.
 */
function buildBarStackData(data, normalized = false) {
    const keys = getDeepGroupDomain(data, 'key');
    const stackData = transformDataToStack(data);
    const stackFn = !normalized ? stack() : stack().offset(stackOffsetExpand);
    const result = stackFn.keys(keys)(stackData);
    return transformStackToData(result);
}

/**
 * Builds a stack dataset from the standard data format.
 */
function buildMarimekkoData(data) {
    const result = buildBarStackData(data, true);
    const sums = {};
    // Calculate the sum for each series and the total sum
    let totalSum = 0;
    for (const series of result) {
        const sum = series.data.reduce((acc, cur) => acc + cur.y, 0);
        sums[series.key] = sum;
        totalSum += sum;
    }
    // Calculate the x0/x1 for each series
    let prev = 0;
    for (const series of result) {
        const x0 = prev;
        const x1 = prev + sums[series.key] / totalSum;
        prev = x1;
        for (const point of series.data) {
            point.x0 = x0;
            point.x1 = x1;
        }
    }
    return result;
}

/**
 * Given a dataset like:
 *
 *   [{
 *    key: 'Threat Intel',
 *    data: [{ key:'2011', data: 25 }]
 *   }]
 *
 * it will transform it to:
 *
 *  [
 *    { x: '2011', 'Theat Intel': 25 }
 *  ]
 */
function transformDataToStack$1(data) {
    const result = [];
    const maxBigInteger = getMaxBigInteger(data);
    for (const category of data) {
        for (const value of category.data) {
            let idx = result.findIndex(r => {
                if (r.x instanceof Date && value.key instanceof Date) {
                    return r.x.getTime() === value.key.getTime();
                }
                return r.x === value.key;
            });
            if (idx === -1) {
                result.push({
                    x: value.key,
                    formattedValues: {}
                });
                idx = result.length - 1;
            }
            result[idx][category.key] = normalizeValue(value.data, maxBigInteger);
            result[idx].formattedValues[category.key] = normalizeValueForFormatting(value.data);
        }
    }
    return result;
}
/**
 * Translates the stack data to a chart standard dataset.
 */
function transformStackToData$1(stackData) {
    const result = [];
    for (const category of stackData) {
        const series = [];
        for (const point of category) {
            const [y0, y1] = point;
            const x = point.data.x;
            series.push({
                key: category.key,
                x,
                x0: x,
                x1: x,
                y: y1 - y0,
                y0,
                y1,
                value: point.data.formattedValues[category.key]
            });
        }
        result.push({
            key: category.key,
            data: series
        });
    }
    return result;
}
/**
 * Builds a stack dataset from the standard data format.
 */
function buildStackData(data, normalized = false) {
    const keys = getGroupDomain(data, 'key');
    const stackData = transformDataToStack$1(data);
    const stackFn = !normalized ? stack() : stack().offset(stackOffsetExpand);
    const result = stackFn.keys(keys)(stackData);
    return transformStackToData$1(result);
}

/**
 * Given an event, get the relative X/Y position for a target.
 */
function getPositionForTarget({ target, clientX, clientY }) {
    const { top, left } = target.getBoundingClientRect();
    return {
        x: clientX - left - target.clientLeft,
        y: clientY - top - target.clientTop
    };
}
/**
 * Get the point from a touch event.
 */
function getPointFromTouch(touch, target) {
    const { top, left } = target.getBoundingClientRect();
    return {
        x: touch.clientX - left - target.clientLeft,
        y: touch.clientY - top - target.clientTop
    };
}
/**
 * Given a point position, get the closes data point in the dataset.
 */
function getClosestPoint(pos, scale, data, attr = 'x') {
    const domain = scale.invert(pos);
    // Select the index
    const bisect = bisector((d) => d[attr]).right;
    const index = bisect(data, domain);
    // Determine min index
    const minIndex = Math.max(0, index - 1);
    const before = data[minIndex];
    // Determine max index
    const maxIndex = Math.min(data.length - 1, index);
    const after = data[maxIndex];
    // Determine which is closest to the point
    let beforeVal = before[attr];
    let afterVal = after[attr];
    beforeVal = domain - beforeVal;
    afterVal = afterVal - domain;
    return beforeVal < afterVal ? before : after;
}

var tooltip = "Tooltip-module_tooltip__2tEjE";
var inactive = "Tooltip-module_inactive__3oIrU";
var active = "Tooltip-module_active__lW8Kn";

const tooltips = [];
class Tooltip extends React.Component {
    constructor(props) {
        super(props);
        this.renderContent = (animationState) => {
            const { content } = this.props;
            const className = classNames(tooltip, {
                [active]: animationState === 'entered',
                [inactive]: animationState === 'entering' || animationState === 'exiting'
            });
            return (React.createElement("div", { className: className }, isFunction(content) ? content() : content));
        };
        this.state = {
            visible: props.visible
        };
    }
    componentDidUpdate(prevProps) {
        const { visible } = this.props;
        if (visible !== prevProps.visible && visible !== this.state.visible) {
            if (visible) {
                this.activate();
            }
            else {
                this.deactivate();
            }
        }
    }
    componentWillUnmount() {
        this.deactivate();
    }
    onActivate() {
        if (!this.state.visible) {
            this.deactivateAll();
            clearTimeout(this.timeout);
            this.timeout = setTimeout(() => this.activate(), this.props.enterDelay);
        }
    }
    onDeactivate() {
        clearTimeout(this.timeout);
        this.timeout = setTimeout(() => this.deactivate(), this.props.leaveDelay);
    }
    activate() {
        if (!this.props.disabled) {
            this.setState({ visible: true });
            tooltips.push(this);
        }
    }
    deactivate() {
        const idx = tooltips.indexOf(this);
        if (idx > -1) {
            this.setState({ visible: false });
            tooltips.splice(idx, 1);
        }
    }
    deactivateAll() {
        tooltips.forEach(t => t.deactivate());
    }
    render() {
        const _a = this.props, { children, content, className, visible } = _a, rest = __rest(_a, ["children", "content", "className", "visible"]);
        return (React.createElement(ConnectedOverlay, Object.assign({}, rest, { visible: this.state.visible, content: this.renderContent, closeOnBodyClick: true, closeOnEscape: true, onActivate: bind(this.onActivate, this), onDeactivate: bind(this.onDeactivate, this) }), children));
    }
}
Tooltip.defaultProps = {
    enterDelay: 0,
    leaveDelay: 200,
    placement: 'top',
    trigger: 'hover',
    visible: false,
    followCursor: false
};

/**
 * Format a value based on type.
 */
function formatValue(value) {
    if (value !== undefined) {
        if (isDate(value) || isNumber(value)) {
            return value.toLocaleString();
        }
        return value;
    }
    return 'No value';
}

var label = "TooltipTemplate-module_label__xKMIu";
var value$1 = "TooltipTemplate-module_value__YOgUI";
var subValue = "TooltipTemplate-module_subValue__3-eKL";
var subValueColor = "TooltipTemplate-module_subValueColor__-ByGT";
var subValueName = "TooltipTemplate-module_subValueName__2p6wW";

class TooltipTemplate extends Component {
    renderValues(data, index) {
        const { color } = this.props;
        const fill = color(data, index);
        return (React.createElement("span", { className: subValue },
            React.createElement("span", { className: subValueColor, style: { backgroundColor: fill } }),
            React.createElement("span", { className: subValueName },
                formatValue(data.key || data.x),
                ":"),
            React.createElement("span", null, formatValue(data.value || data.y))));
    }
    render() {
        const { value, className } = this.props;
        if (!value) {
            return null;
        }
        const isMultiple = Array.isArray(value.data);
        return (React.createElement("div", { className: className },
            React.createElement("div", { className: label }, formatValue(value.x)),
            React.createElement("div", { className: value$1 },
                isMultiple &&
                    value.data.map((point, i) => (React.createElement(Fragment, { key: i }, this.renderValues(point, i)))),
                !isMultiple && (React.createElement(Fragment, null, formatValue(value.value ||
                    value.y))))));
    }
}

class ChartTooltip extends Component {
    renderContent() {
        const { content, value, metadata, color } = this.props;
        if (!value && !metadata) {
            return null;
        }
        return isFunction(content)
            ? content(metadata || value, color)
            : cloneElement(content, Object.assign({}, content.props, { value,
                color }));
    }
    render() {
        const _a = this.props, rest = __rest(_a, ["content", "value", "metadata", "color"]);
        return React.createElement(Tooltip, Object.assign({}, rest, { content: this.renderContent.bind(this) }));
    }
}
ChartTooltip.defaultProps = {
    content: React.createElement(TooltipTemplate, null)
};

class TooltipArea extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            data: this.transformData(props.data)
        };
    }
    componentDidUpdate(prevProps) {
        const { data } = this.props;
        if (data !== prevProps.data) {
            this.setState({
                data: this.transformData(data)
            });
        }
    }
    onMouseMove(event) {
        const { value, data } = this.state;
        const { xScale, yScale, onValueEnter, height } = this.props;
        let { placement } = this.props;
        const { x } = getPositionForTarget(event);
        const newValue = getClosestPoint(x, xScale, data);
        if (!isEqual(newValue, value)) {
            const pointX = xScale(newValue.x);
            let pointY = yScale(newValue.y);
            let marginX = 0;
            let marginY = 0;
            if (isNaN(pointY)) {
                pointY = height / 2;
                marginX = 10;
                placement = 'right';
            }
            else {
                marginY = -10;
            }
            // If the points didn't change, don't trigger an update
            if (pointX === this.prevX && pointY === this.prevY) {
                return;
            }
            this.prevY = pointY;
            this.prevX = pointX;
            const target = event.target;
            const { top, left } = target.getBoundingClientRect();
            const offsetX = pointX + left + marginX;
            const offsetY = pointY + top + marginY;
            this.setState({
                placement,
                visible: true,
                value: newValue,
                offsetX,
                offsetY
            });
            onValueEnter({
                visible: true,
                value: newValue,
                pointY,
                pointX,
                offsetX,
                offsetY,
                nativeEvent: event
            });
        }
    }
    onMouseLeave() {
        this.prevX = undefined;
        this.prevY = undefined;
        this.setState({
            value: undefined,
            visible: false
        });
        this.props.onValueLeave();
    }
    getTooltipReference() {
        const { offsetX, offsetY } = this.state;
        return {
            width: 4,
            height: 4,
            top: offsetY,
            left: offsetX
        };
    }
    transformData(series) {
        const result = [];
        for (const point of series) {
            if (isNested(point)) {
                for (const nestedPoint of point.data) {
                    const right = nestedPoint.x;
                    let idx = result.findIndex(r => {
                        const left = r.x;
                        if (left instanceof Date && right instanceof Date) {
                            return left.getTime() === right.getTime();
                        }
                        return left === right;
                    });
                    if (idx === -1) {
                        result.push({
                            x: nestedPoint.x,
                            data: []
                        });
                        idx = result.length - 1;
                    }
                    const data = result[idx].data;
                    if (Array.isArray(data)) {
                        data.push(nestedPoint);
                    }
                }
            }
            else {
                result.push(point);
            }
        }
        return result;
    }
    render() {
        const { height, width, children, tooltip, disabled, color } = this.props;
        const { visible, placement, value } = this.state;
        return (React.createElement(Fragment, null,
            disabled && children,
            !disabled && (React.createElement("g", { onMouseLeave: bind(this.onMouseLeave, this) },
                React.createElement("rect", { height: height, width: width, opacity: 0, cursor: "auto", onMouseMove: bind(this.onMouseMove, this) }),
                React.createElement(CloneElement, { element: tooltip, visible: visible, placement: placement, reference: this.getTooltipReference(), color: color, value: value }),
                children))));
    }
}
TooltipArea.defaultProps = {
    placement: 'top',
    tooltip: React.createElement(ChartTooltip, null),
    onValueEnter: () => undefined,
    onValueLeave: () => undefined
};

/**
 * Calculates whether the stroke should be shown.
 */
function calculateShowStroke(current, data) {
    const i = data.indexOf(current);
    let showLine = false;
    const prev = data[i - 1];
    if (i > 0 && prev.y) {
        showLine = true;
    }
    const cur = data[i];
    if (cur.y) {
        showLine = true;
    }
    const next = data[i + 1];
    if (i < data.length - 1 && next.y) {
        showLine = true;
    }
    return showLine;
}

const PosedLine = posed.path({
    enter: {
        strokeDashoffset: 0,
        strokeDasharray: ({ ghostPathRef, areaShown }) => {
            if (!areaShown) {
                const len = ghostPathRef.current.getTotalLength();
                return `${len} ${len}`;
            }
            return '';
        },
        d: ({ enterProps }) => enterProps.d,
        delay: ({ animated, index }) => (animated ? index * 10 : 0),
        transition: ({ animated }) => (animated ? transition : { duration: 0 })
    },
    exit: {
        d: ({ exitProps }) => exitProps.d,
        strokeDasharray: ({ ghostPathRef, areaShown }) => {
            if (!areaShown) {
                const len = ghostPathRef.current.getTotalLength();
                return `${len} ${len}`;
            }
            return '';
        },
        strokeDashoffset: ({ ghostPathRef, areaShown }) => {
            if (!areaShown) {
                return ghostPathRef.current.getTotalLength();
            }
            return '';
        }
    }
});

class Line extends React.Component {
    constructor() {
        super(...arguments);
        this.ghostPathRef = createRef();
    }
    getLinePath(data) {
        const { showZeroStroke, interpolation } = this.props;
        const fn = line$1()
            .x((d) => d.x)
            .y((d) => d.y1)
            .defined((d) => showZeroStroke || calculateShowStroke(d, data))
            .curve(interpolate(interpolation));
        return fn(data);
    }
    getCoords() {
        const { data, xScale, yScale } = this.props;
        return data.map((item) => ({
            x: xScale(item.x),
            x1: xScale(item.x) - xScale(item.x1),
            y: yScale(item.y),
            y0: yScale(item.y0),
            y1: yScale(item.y1)
        }));
    }
    getLineEnter(coords) {
        const linePath = this.getLinePath(coords);
        return {
            d: linePath === null ? undefined : linePath
        };
    }
    getLineExit() {
        const { hasArea, yScale, xScale, data } = this.props;
        let coords;
        if (hasArea) {
            const maxY = Math.max(...yScale.range());
            coords = data.map((item) => ({
                x: xScale(item.x),
                x1: 0,
                y: maxY,
                y1: maxY,
                y0: maxY
            }));
        }
        else {
            coords = this.getCoords();
        }
        const linePath = this.getLinePath(coords);
        return {
            d: linePath === null ? undefined : linePath
        };
    }
    render() {
        const { data, color, index, animated, strokeWidth, hasArea } = this.props;
        const coords = this.getCoords();
        const stroke = color(data, index);
        const enterProps = this.getLineEnter(coords);
        const exitProps = this.getLineExit();
        return (React.createElement(Fragment, null,
            React.createElement(PosedLine, { pose: "enter", poseKey: enterProps.d, pointerEvents: "none", stroke: stroke, strokeWidth: strokeWidth, fill: "none", enterProps: enterProps, exitProps: exitProps, index: index, areaShown: hasArea, ghostPathRef: this.ghostPathRef, animated: animated }),
            React.createElement("path", { opacity: "0", d: enterProps.d, ref: this.ghostPathRef, pointerEvents: "none" })));
    }
}
Line.defaultProps = {
    showZeroStroke: true,
    strokeWidth: 0
};

const sequentialScheme = ['#3ec4e8'];
/**
 * Get a color given a range.
 */
function getColor(colorScheme, data) {
    const dataRange = range(data.length).map(r => r.toString());
    return scaleOrdinal(colorScheme).domain(dataRange);
}

// For area charts, often symbols exceed the area
// and we want to add a little bit of padding to prevent clipping
const PADDING = 25;
const HALF_PADDING = PADDING / 2;
class AreaSeries extends Component {
    constructor() {
        super(...arguments);
        this.state = {};
    }
    getColor(point, index) {
        const { colorScheme, data } = this.props;
        const { activeValues } = this.state;
        return Array.isArray(colorScheme)
            ? getColor(colorScheme, data)(index)
            : colorScheme(point, index, activeValues);
    }
    onValueEnter(event) {
        this.setState({
            activePoint: event.pointX,
            activeValues: event.value
        });
    }
    onValueLeave() {
        this.setState({
            activePoint: undefined,
            activeValues: undefined
        });
    }
    renderArea(data, index = 0) {
        const { id, width, xScale, yScale, area, line, interpolation, animated } = this.props;
        return (React.createElement(Fragment, null,
            line && (React.createElement(CloneElement, { element: line, xScale: xScale, yScale: yScale, data: data, width: width, index: index, hasArea: area !== null, animated: animated, interpolation: interpolation, color: this.getColor.bind(this) })),
            area && (React.createElement(CloneElement, { element: area, id: `${id}-area-${index}`, xScale: xScale, yScale: yScale, data: data, width: width, index: index, animated: animated, interpolation: interpolation, color: this.getColor.bind(this) }))));
    }
    renderSymbols(data, index = 0) {
        const { xScale, yScale, animated, area, symbols } = this.props;
        const { activeValues } = this.state;
        // Animations are only valid for Area
        const isAnimated = area !== undefined && animated;
        const visible = symbols !== null;
        const activeSymbols = (symbols && symbols.props.activeValues) || activeValues;
        return (React.createElement(Fragment, null, visible && (React.createElement(CloneElement, { element: symbols, activeValues: activeSymbols, xScale: xScale, yScale: yScale, index: index, data: data, animated: isAnimated, color: this.getColor.bind(this) }))));
    }
    renderMarkLine() {
        const { height, markLine } = this.props;
        const { activePoint, activeValues } = this.state;
        return (React.createElement(Fragment, null, activeValues && markLine && (React.createElement(CloneElement, { element: markLine, height: height, pointX: activePoint }))));
    }
    renderSingleSeries(data) {
        const { animated } = this.props;
        return (React.createElement(PoseGroup, { animateOnMount: animated },
            React.createElement(PoseSVGGElement, { key: "group" },
                this.renderArea(data),
                this.renderMarkLine(),
                this.renderSymbols(data))));
    }
    renderMultiSeries(data) {
        const { animated } = this.props;
        return (React.createElement(Fragment, null,
            React.createElement(PoseGroup, { animateOnMount: animated }, data
                .map((point, index) => (React.createElement(PoseSVGGElement, { key: `${point.key.toString()}` }, this.renderArea(point.data, index))))
                .reverse()),
            this.renderMarkLine(),
            React.createElement(PoseGroup, { animateOnMount: animated }, data
                .map((point, index) => (React.createElement(PoseSVGGElement, { key: `${point.key.toString()}` }, this.renderSymbols(point.data, index))))
                .reverse())));
    }
    render() {
        const { data, height, id, width, isZoomed, tooltip, xScale, yScale } = this.props;
        const isMulti = isMultiSeries(data);
        return (React.createElement(Fragment, null,
            React.createElement("defs", null,
                React.createElement("clipPath", { id: `${id}-path` },
                    React.createElement("rect", { width: isZoomed ? width : width + PADDING, height: height + PADDING, x: isZoomed ? 0 : -HALF_PADDING, y: -HALF_PADDING }))),
            React.createElement(CloneElement, { element: tooltip, xScale: xScale, yScale: yScale, data: data, height: height, width: width, color: this.getColor.bind(this), onValueEnter: bind(this.onValueEnter, this), onValueLeave: bind(this.onValueLeave, this) },
                React.createElement("g", { clipPath: `url(#${id}-path)` },
                    isMulti &&
                        this.renderMultiSeries(data),
                    !isMulti &&
                        this.renderSingleSeries(data)))));
    }
}
AreaSeries.defaultProps = {
    colorScheme: [...sequentialScheme],
    animated: true,
    interpolation: 'linear',
    type: 'standard',
    line: React.createElement(Line, null),
    area: React.createElement(Area, null),
    markLine: React.createElement(MarkLine, null),
    tooltip: React.createElement(TooltipArea, null),
    symbols: React.createElement(CircleSeries, null)
};

class StackedNormalizedAreaSeries extends Component {
    render() {
        const _a = this.props, rest = __rest(_a, ["type"]);
        return React.createElement(AreaSeries, Object.assign({ type: "stackedNormalized" }, rest));
    }
}
StackedNormalizedAreaSeries.defaultProps = {
    type: 'stackedNormalized',
    tooltip: (React.createElement(TooltipArea, { tooltip: React.createElement(ChartTooltip, { content: (series, color) => {
                if (!series) {
                    return null;
                }
                const value = Object.assign({}, series, { data: series.data.map(d => (Object.assign({}, d, { value: `${formatValue(d.value)} ∙ ${formatValue(Math.floor((d.y1 - d.y0) * 100))}%` }))) });
                return React.createElement(TooltipTemplate, { color: color, value: value });
            } }) }))
};

class StackedAreaSeries extends Component {
    render() {
        const _a = this.props, rest = __rest(_a, ["type"]);
        return React.createElement(AreaSeries, Object.assign({ type: "stacked" }, rest));
    }
}
StackedAreaSeries.defaultProps = Object.assign({}, AreaSeries.defaultProps, { type: 'stacked' });

class LinearAxisTickLabel extends Component {
    getAlign() {
        const { align, half } = this.props;
        if ((align === 'inside' || align === 'outside') && half === 'center') {
            return 'center';
        }
        if (align === 'inside') {
            return half === 'start' ? 'end' : 'start';
        }
        if (align === 'outside') {
            return half === 'start' ? 'start' : 'end';
        }
        return align;
    }
    getTickLineSpacing() {
        const { line } = this.props;
        if (!line) {
            return [0, 0];
        }
        const size = line.props.size;
        const position = line.props.position;
        if (position === 'start') {
            return [size * -1, 0];
        }
        else if (position === 'end') {
            return [0, size];
        }
        else {
            return [size * -0.5, size * 0.5];
        }
    }
    getOffset() {
        const { padding, position, rotation, orientation } = this.props;
        const adjustedPadding = isNumber(padding)
            ? {
                fromAxis: padding,
                alongAxis: padding
            }
            : padding;
        const spacing = this.getTickLineSpacing();
        const offset1 = position === 'start'
            ? spacing[0] - adjustedPadding.fromAxis
            : position === 'end'
                ? spacing[1] + adjustedPadding.fromAxis
                : 0;
        const align = this.getAlign();
        let offset2 = rotation === true ? -5 : 0;
        offset2 +=
            align === 'center'
                ? 0
                : align === 'start'
                    ? -adjustedPadding.alongAxis
                    : adjustedPadding.alongAxis;
        const horz = orientation === 'horizontal';
        return {
            [horz ? 'x' : 'y']: offset2,
            [horz ? 'y' : 'x']: offset1
        };
    }
    getTextPosition() {
        const { angle, orientation, position } = this.props;
        let transform = '';
        let textAnchor = '';
        let alignmentBaseline = 'middle';
        if (angle !== 0) {
            transform = `rotate(${angle})`;
            textAnchor = 'end';
        }
        else {
            const align = this.getAlign();
            if (orientation === 'horizontal') {
                textAnchor =
                    align === 'center' ? 'middle' : align === 'start' ? 'end' : 'start';
                if (position === 'start') {
                    alignmentBaseline = 'baseline';
                }
                else if (position === 'end') {
                    alignmentBaseline = 'hanging';
                }
            }
            else {
                alignmentBaseline =
                    align === 'center'
                        ? 'middle'
                        : align === 'start'
                            ? 'baseline'
                            : 'hanging';
                if (position === 'start') {
                    textAnchor = 'end';
                }
                else if (position === 'end') {
                    textAnchor = 'start';
                }
                else {
                    textAnchor = 'middle';
                }
            }
        }
        return {
            transform,
            textAnchor: this.props.textAnchor || textAnchor,
            alignmentBaseline
        };
    }
    render() {
        const { fill, text, fullText, fontSize, fontFamily } = this.props;
        const { x, y } = this.getOffset();
        const textPosition = this.getTextPosition();
        return (React.createElement("g", { transform: `translate(${x}, ${y})`, fontSize: fontSize, fontFamily: fontFamily },
            React.createElement("title", null, fullText),
            React.createElement("text", Object.assign({}, textPosition, { fill: fill }), text)));
    }
}
LinearAxisTickLabel.defaultProps = {
    fill: '#8F979F',
    fontSize: 11,
    fontFamily: 'sans-serif',
    rotation: true,
    padding: 0,
    align: 'center'
};

class LinearAxisTickLine extends Component {
    positionTick() {
        const { size, position, orientation } = this.props;
        const isVertical = orientation === 'vertical';
        const tickSize = size || 0;
        const start = position === 'start'
            ? tickSize * -1
            : position === 'center'
                ? tickSize * -0.5
                : 0;
        const end = start + tickSize;
        return {
            x1: isVertical ? end : 0,
            x2: isVertical ? start : 0,
            y1: isVertical ? 0 : start,
            y2: isVertical ? 0 : end
        };
    }
    render() {
        const { strokeColor, strokeWidth } = this.props;
        const path = this.positionTick();
        return React.createElement("line", Object.assign({ strokeWidth: strokeWidth, stroke: strokeColor }, path));
    }
}
LinearAxisTickLine.defaultProps = {
    strokeColor: '#8F979F',
    strokeWidth: 1,
    size: 5
};

const canvas = document.createElement('canvas');
/**
 * Measures the width of text.
 * Credit: https://stackoverflow.com/questions/118241/calculate-text-width-with-javascript
 */
function getTextWidth(text, font) {
    const context = canvas.getContext('2d');
    // XXX assumed: getting null canvas is catastrophic
    context.font = font;
    const metrics = context.measureText(text);
    return metrics.width;
}

/**
 * Reduce the ticks to the max number of ticks.
 */
function reduceTicks(ticks, maxTicks) {
    if (ticks.length > maxTicks) {
        const reduced = [];
        const modulus = Math.floor(ticks.length / maxTicks);
        for (let i = 0; i < ticks.length; i++) {
            if (i % modulus === 0) {
                reduced.push(ticks[i]);
            }
        }
        ticks = reduced;
    }
    return ticks;
}
/**
 * Determine the max ticks for the available width.
 */
function getMaxTicks(size, dimension) {
    const tickWidth = Math.max(size, 0);
    return Math.floor(dimension / tickWidth);
}
/**
 * Get the tick values from the scale.
 */
function getTicks(scale, tickSize, tickValues, dimension, interval) {
    let result;
    if (tickValues) {
        result = tickValues;
    }
    else {
        const maxTicks = getMaxTicks(tickSize, dimension);
        if (scale.ticks) {
            if (interval) {
                result = scale.ticks(interval);
            }
            else {
                result = scale.ticks.apply(scale, [maxTicks]);
            }
        }
        else {
            tickValues = scale.domain();
            result = reduceTicks(tickValues, maxTicks);
        }
    }
    return result;
}

class LinearAxisTickSeries extends Component {
    /**
     * Gets the adjusted scale given offsets.
     */
    getAdjustedScale() {
        const { scale } = this.props;
        if (scale.bandwidth) {
            let offset = scale.bandwidth() / 2;
            if (scale.round()) {
                offset = Math.round(offset);
            }
            return d => +scale(d) + offset;
        }
        else {
            return d => +scale(d);
        }
    }
    /**
     * Gets the x/y position for a given tick.
     */
    getPosition(scaledTick) {
        const { orientation } = this.props;
        if (orientation === 'horizontal') {
            return [scaledTick, 0];
        }
        else {
            return [0, scaledTick];
        }
    }
    /**
     * Gets the dimension (height/width) this axis is calculating on.
     */
    getDimension() {
        const { height, width, orientation } = this.props;
        return orientation === 'vertical' ? height : width;
    }
    /**
     * Calculates the rotation angle that the ticks need to be shifted to.
     * This equation will measure the length of the text in a external canvas
     * object and determine what the longest label is and rotate until they fit.
     */
    getRotationAngle(ticks) {
        if (!this.props.label) {
            return { angle: 0 };
        }
        const label = this.props.label.props;
        const dimension = this.getDimension();
        let angle = 0;
        let maxTicksLength = 0;
        const textLengths = {};
        for (const tick of ticks) {
            const textLen = getTextWidth(tick.text, `${label.fontSize} ${label.fontFamily}`);
            // cache the length of the text for overlap
            // detection later when post-processing
            textLengths[tick.text] = textLen;
            // Determine the max length for rotation measuring
            maxTicksLength = textLen > maxTicksLength ? textLen : maxTicksLength;
        }
        if (label.rotation) {
            if (label.rotation === true) {
                const maxAllowedLength = getTextWidth('1234567890123456', `${label.fontSize} ${label.fontFamily}`);
                const wordWidth = Math.min(maxTicksLength, maxAllowedLength);
                let baseWidth = wordWidth;
                const maxBaseWidth = Math.floor(dimension / ticks.length);
                while (baseWidth > maxBaseWidth && angle > -90) {
                    angle -= 30;
                    baseWidth = Math.cos(angle * (Math.PI / 180)) * wordWidth;
                }
            }
            else if (label.rotation) {
                angle = label.rotation;
            }
        }
        return { angle, textLengths };
    }
    /**
     * Gets the formatted label of the tick.
     */
    getLabelFormat() {
        const { label, scale } = this.props;
        if (label && label.props.format) {
            return label.props.format;
        }
        else if (scale.tickFormat) {
            return scale.tickFormat.apply(scale, [5]);
        }
        else {
            return v => formatValue(v);
        }
    }
    /**
     * Gets the ticks given the dimensions and scales and returns
     * the text and position.
     */
    getTicks() {
        const { scale, tickSize, tickValues, interval } = this.props;
        const dimension = this.getDimension();
        const ticks = getTicks(scale, tickSize, tickValues, dimension, interval);
        const adjustedScale = this.getAdjustedScale();
        const format = this.getLabelFormat();
        const result = [];
        const midpoint = dimension / 2;
        for (const tick of ticks) {
            const text = format(tick);
            const scaledTick = adjustedScale(tick);
            result.push({
                text,
                fullText: text,
                position: this.getPosition(scaledTick),
                half: scaledTick === midpoint
                    ? 'center'
                    : scaledTick < midpoint
                        ? 'start'
                        : 'end'
            });
        }
        return result;
    }
    /**
     * Post processes the ticks to:
     *
     * - Ellipsis the labels if they are exceed a given length
     * - Filter out any ticks that might overlap each other.
     *
     */
    postProcessTicks(ticks, angle, textLengths) {
        const result = [];
        let i = 0;
        for (const tick of ticks) {
            const prevTick = result[result.length - 1];
            const overlaps = this.getTickOverlap(i, ticks, angle, textLengths, prevTick);
            if (!overlaps) {
                if (angle && tick.text.length > 16) {
                    tick.text = tick.text.substring(0, 16) + '...';
                }
                result.push(tick);
            }
            i++;
        }
        return result;
    }
    /**
     * Calculates whether the current tick will overlap with
     * the next tick.
     */
    getTickOverlap(index, ticks, angle, textLengths, prevTick) {
        if (index === 0) {
            return false;
        }
        const { orientation } = this.props;
        const current = ticks[index];
        const [curX, curY] = current.position;
        const [prevX, prevY] = prevTick.position;
        const padding = 10;
        // Determine whether the previous item and the next one will overlap
        let curLength = 10;
        let prevLength = 10;
        if (!angle && textLengths && textLengths[current.text]) {
            curLength = textLengths[current.text];
            prevLength = textLengths[prevTick.text];
        }
        if (orientation === 'vertical') {
            return curY - curLength / 2 - padding > prevY + prevLength / 2;
        }
        else {
            return curX - curLength / 2 - padding < prevX + prevLength / 2;
        }
    }
    render() {
        const { label, line, height, width, orientation } = this.props;
        const ticks = this.getTicks();
        const { angle, textLengths } = this.getRotationAngle(ticks);
        const formattedTicks = this.postProcessTicks(ticks, angle, textLengths);
        return (React.createElement(Fragment, null, formattedTicks.map((tick, i) => (React.createElement("g", { key: i, transform: `translate(${tick.position[0]}, ${tick.position[1]})` },
            line && (React.createElement(CloneElement, { element: line, height: height, width: width, orientation: orientation })),
            label && (React.createElement(CloneElement, { element: label, text: tick.text, fullText: tick.fullText, half: tick.half, angle: angle, orientation: orientation, line: line })))))));
    }
}
LinearAxisTickSeries.defaultProps = {
    line: React.createElement(LinearAxisTickLine, null),
    label: React.createElement(LinearAxisTickLabel, null),
    tickSize: 30
};

let axisLineId = 0;
class LinearAxisLine extends Component {
    constructor() {
        super(...arguments);
        this.state = {
            id: (axisLineId++).toString()
        };
    }
    render() {
        const { strokeColor, strokeGradient, scale, orientation } = this.props;
        const { id } = this.state;
        const [range0, range1] = scale.range();
        return (React.createElement(Fragment, null,
            React.createElement("line", { x1: orientation === 'vertical' ? 0 : range0, 
                // Workaround for a Chrome bug where it won't render gradients for straight lines
                x2: orientation === 'vertical' ? 0.000001 : range1, y1: orientation === 'vertical' ? range0 : 0, y2: orientation === 'vertical' ? range1 : 0.000001, strokeWidth: 1, stroke: strokeGradient ? `url(#axis-gradient-${id})` : strokeColor }),
            strokeGradient && (React.createElement(Gradient, { id: `axis-gradient-${id}`, offsets: strokeGradient }))));
    }
}
LinearAxisLine.defaultProps = {
    strokeColor: '#8F979F',
    strokeWidth: 1
};

class LinearAxis extends Component {
    constructor(props) {
        super(props);
        this.ref = createRef();
        this.state = {
            height: props.height,
            width: props.width
        };
    }
    componentDidMount() {
        this.updateDimensions();
    }
    componentDidUpdate(prevProps) {
        const { height, width, scale } = this.props;
        if (width !== prevProps.width ||
            height !== prevProps.height ||
            scale !== prevProps.scale) {
            this.updateDimensions();
        }
    }
    updateDimensions() {
        const { onDimensionsChange, orientation, position } = this.props;
        const shouldOffset = position !== 'center';
        let height;
        let width;
        if (shouldOffset) {
            const dims = this.ref.current.getBoundingClientRect();
            width = Math.floor(dims.width);
            height = Math.floor(dims.height);
        }
        if (orientation === 'vertical') {
            if (this.state.width !== width) {
                this.setState({ width });
                onDimensionsChange({ width });
            }
        }
        else {
            if (this.state.height !== height) {
                this.setState({ height });
                onDimensionsChange({ height });
            }
        }
    }
    getPosition() {
        const { position, width, height, orientation } = this.props;
        let translateY = 0;
        let translateX = 0;
        if (position === 'end' && orientation === 'horizontal') {
            translateY = height;
        }
        else if (position === 'center' && orientation === 'horizontal') {
            translateY = height / 2;
        }
        else if (position === 'end' && orientation === 'vertical') {
            translateX = width;
        }
        else if (position === 'center' && orientation === 'vertical') {
            translateX = width / 2;
        }
        return { translateX, translateY };
    }
    render() {
        const { scale, height, width, orientation, axisLine, tickSeries } = this.props;
        const { translateX, translateY } = this.getPosition();
        return (React.createElement("g", { transform: `translate(${translateX}, ${translateY})`, ref: this.ref },
            axisLine && (React.createElement(CloneElement, { element: axisLine, height: height, width: width, scale: scale, orientation: orientation })),
            (tickSeries.props.line || tickSeries.props.label) && (React.createElement(CloneElement, { element: tickSeries, height: height, width: width, scale: scale, orientation: orientation }))));
    }
}
LinearAxis.defaultProps = {
    axisLine: React.createElement(LinearAxisLine, null),
    tickSeries: React.createElement(LinearAxisTickSeries, null),
    scaled: false,
    roundDomains: false,
    onDimensionsChange: () => undefined
};

class LinearXAxisTickLabel extends Component {
    render() {
        return React.createElement(LinearAxisTickLabel, Object.assign({}, this.props));
    }
}
LinearXAxisTickLabel.defaultProps = Object.assign({}, LinearAxisTickLabel.defaultProps, { rotation: true, position: 'end', align: 'center' });
class LinearXAxisTickLine extends Component {
    render() {
        return React.createElement(LinearAxisTickLine, Object.assign({}, this.props));
    }
}
LinearXAxisTickLine.defaultProps = Object.assign({}, LinearAxisTickLine.defaultProps, { position: 'end' });
class LinearXAxisTickSeries extends Component {
    render() {
        return React.createElement(LinearAxisTickSeries, Object.assign({}, this.props));
    }
}
LinearXAxisTickSeries.defaultProps = Object.assign({}, LinearAxisTickSeries.defaultProps, { tickSize: 75, line: React.createElement(LinearXAxisTickLine, null), label: React.createElement(LinearXAxisTickLabel, null) });
class LinearXAxis extends Component {
    render() {
        return React.createElement(LinearAxis, Object.assign({}, this.props));
    }
}
LinearXAxis.defaultProps = Object.assign({}, LinearAxis.defaultProps, { position: 'end', roundDomains: false, scaled: false, type: 'value', orientation: 'horizontal', tickSeries: React.createElement(LinearXAxisTickSeries, null) });

class LinearYAxisTickLabel extends Component {
    render() {
        return React.createElement(LinearAxisTickLabel, Object.assign({}, this.props));
    }
}
LinearYAxisTickLabel.defaultProps = Object.assign({}, LinearAxisTickLabel.defaultProps, { rotation: true, position: 'start', align: 'center' });
class LinearYAxisTickLine extends Component {
    render() {
        return React.createElement(LinearAxisTickLine, Object.assign({}, this.props));
    }
}
LinearYAxisTickLine.defaultProps = Object.assign({}, LinearAxisTickLine.defaultProps, { position: 'start' });
class LinearYAxisTickSeries extends Component {
    render() {
        return React.createElement(LinearAxisTickSeries, Object.assign({}, this.props));
    }
}
LinearYAxisTickSeries.defaultProps = Object.assign({}, LinearAxisTickSeries.defaultProps, { tickSize: 30, line: React.createElement(LinearYAxisTickLine, null), label: React.createElement(LinearYAxisTickLabel, null) });
class LinearYAxis extends Component {
    render() {
        return React.createElement(LinearAxis, Object.assign({}, this.props));
    }
}
LinearYAxis.defaultProps = Object.assign({}, LinearAxis.defaultProps, { orientation: 'vertical', scaled: false, roundDomains: false, type: 'value', position: 'start', tickSeries: React.createElement(LinearYAxisTickSeries, null) });

/**
 * Returns whether the axis has a visual element or not.
 */
const isAxisVisible = (axis) => axis.tickSeries.props.label || axis.tickSeries.props.line;

/**
 * Gets the X Scale function.
 */
function getXScale({ type, roundDomains, data, width, domain, padding }) {
    let scale;
    if (type === 'time' || type === 'value') {
        if (type === 'time') {
            scale = scaleTime().rangeRound([0, width]);
        }
        else {
            scale = scaleLinear().rangeRound([0, width]);
        }
        domain = domain || getXDomain({ data });
        scale = scale.domain(domain);
    }
    else if (type === 'category') {
        scale = scaleBand()
            .rangeRound([0, width])
            .padding(padding || 0);
        if (!domain) {
            const isMulti = isMultiSeries(data);
            if (isMulti) {
                domain = getGroupDomain(data, 'key');
            }
            else {
                domain = getGroupDomain(data, 'x');
            }
        }
        scale = scale.domain(domain);
    }
    return roundDomains ? scale.nice() : scale;
}
/**
 * Gets the Y Scale function.
 */
function getYScale({ type, roundDomains, height, data, domain, scaled }) {
    let scale;
    if (type === 'time' || type === 'value') {
        scale = scaleLinear()
            .range([height, 0])
            .domain(domain || getYDomain({ scaled, data }));
    }
    else {
        domain =
            domain || getGroupDomain(data, 'y');
        scale = scaleBand()
            .rangeRound([height, 0])
            .domain(domain);
    }
    return roundDomains ? scale.nice() : scale;
}

/**
 * Get a linear scale for the mariemko chart.
 */
function getMarimekkoScale(width, roundDomains) {
    const scale = scaleLinear().rangeRound([0, width]);
    return roundDomains ? scale.nice() : scale;
}
/**
 * Builds a fake scale function to get a group scale for a marimekko value scale.
 */
function getMarimekkoGroupScale({ data, width, valueScale, padding }) {
    const domain = getGroupDomain(data, 'key');
    const barCount = data.length;
    const widthMinusPadding = width - padding * (barCount - 1);
    const xMultiplier = widthMinusPadding / width;
    const scale = arg => {
        let result = 0;
        const index = data.findIndex(d => d.key === arg);
        const series = data[index];
        if (series && series.data && series.data.length) {
            const [val] = series.data;
            const x0 = valueScale(val.x0);
            const x1 = valueScale(val.x1);
            result = (x1 - x0) / 2 + x0;
            if (padding) {
                result = result * xMultiplier + index * padding;
            }
        }
        return result;
    };
    scale.range = () => [0, width];
    scale.domain = () => domain;
    return scale;
}

/**
 * Get the group scale aka x0.
 */
function getGroupScale({ height, width, padding, data }) {
    const domain = getGroupDomain(data, 'key');
    const spacing = domain.length / (height / padding + 1);
    return scaleBand()
        .rangeRound([0, width])
        .paddingInner(spacing)
        .paddingOuter(spacing / 2)
        .domain(domain);
}
/**
 * Get the inner scale aka x1.
 */
function getInnerScale({ groupScale, padding, data }) {
    const width = groupScale.bandwidth();
    const domain = getDeepGroupDomain(data, 'x');
    const spacing = domain.length / (width / padding + 1);
    return scaleBand()
        .rangeRound([0, width])
        .paddingInner(spacing)
        .domain(domain);
}

var gridLine = "Gridline-module_gridLine__3cVfZ";

class Gridline extends Component {
    getCoords() {
        const { direction, data, height, width, scale, strokeWidth, strokeColor } = this.props;
        const pos = scale(data);
        if (direction === 'x') {
            return {
                x1: pos,
                x2: pos,
                y1: 0,
                y2: height,
                fill: 'none',
                stroke: strokeColor,
                strokeWidth
            };
        }
        else {
            return {
                y1: pos,
                y2: pos,
                x1: 0,
                x2: width,
                fill: 'none',
                stroke: strokeColor,
                strokeWidth
            };
        }
    }
    render() {
        const coords = this.getCoords();
        return React.createElement("line", Object.assign({ className: gridLine }, coords));
    }
}
Gridline.defaultProps = {
    strokeWidth: 1,
    direction: 'all',
    strokeColor: 'rgba(153, 153, 153, 0.5)'
};

class GridlineSeries extends Component {
    getGridlines() {
        const { yScale, xScale, yAxis, xAxis, height, width } = this.props;
        return {
            yAxisGrid: getTicks(yScale, yAxis.tickSeries.props.tickSize, yAxis.tickSeries.props.tickValues, height, yAxis.tickSeries.props.interval),
            xAxisGrid: getTicks(xScale, xAxis.tickSeries.props.tickSize, xAxis.tickSeries.props.tickValues, width, xAxis.tickSeries.props.interval)
        };
    }
    renderSeries(yAxisGrid, xAxisGrid, element, type) {
        const { xScale, yScale } = this.props;
        return (React.createElement(Fragment, null,
            this.shouldRenderY(element.props.direction) &&
                this.renderGroup(element, yAxisGrid, yScale, 'y', type),
            this.shouldRenderX(element.props.direction) &&
                this.renderGroup(element, xAxisGrid, xScale, 'x', type)));
    }
    shouldRenderY(direction) {
        return direction === 'all' || direction === 'y';
    }
    shouldRenderX(direction) {
        return direction === 'all' || direction === 'x';
    }
    renderGroup(element, grid, scale, direction, type) {
        const { height, width } = this.props;
        return grid.map((point, index) => (React.createElement(CloneElement, { element: element, index: index, key: `${type}-${direction}-${index}`, scale: scale, data: point, height: height, width: width, direction: direction })));
    }
    render() {
        const { line, stripe } = this.props;
        const { yAxisGrid, xAxisGrid } = this.getGridlines();
        return (React.createElement("g", { style: { pointerEvents: 'none' } },
            line && this.renderSeries(yAxisGrid, xAxisGrid, line, 'line'),
            stripe && this.renderSeries(yAxisGrid, xAxisGrid, stripe, 'stripe')));
    }
}
GridlineSeries.defaultProps = {
    line: React.createElement(Gridline, null),
    stripe: null
};

var gridStripe = "GridStripe-module_gridStripe__1UlRd";

class GridStripe extends Component {
    getCoords() {
        const { position, data, height, width, scale, fill, index } = this.props;
        const pos = scale(data);
        const stripeFill = index % 2 ? 'none' : fill;
        const dim = scale.bandwidth();
        if (position === 'vertical') {
            return {
                y: 0,
                x: pos,
                height: height,
                width: dim,
                fill: stripeFill
            };
        }
        else {
            return {
                y: pos,
                x: 0,
                height: dim,
                width,
                fill: stripeFill
            };
        }
    }
    render() {
        const coords = this.getCoords();
        return React.createElement("rect", Object.assign({ className: gridStripe }, coords));
    }
}
GridStripe.defaultProps = {
    fill: '#2a3138'
};

var areaChart = "AreaChart-module_areaChart__3MZH6";

const parseMargins = (margins) => {
    let top = 0;
    let right = 0;
    let bottom = 0;
    let left = 0;
    if (Array.isArray(margins)) {
        if (margins.length === 2) {
            top = margins[0];
            bottom = margins[0];
            left = margins[1];
            right = margins[1];
        }
        else if (margins.length === 4) {
            top = margins[0];
            right = margins[1];
            bottom = margins[2];
            left = margins[3];
        }
    }
    else if (margins !== undefined) {
        top = margins;
        right = margins;
        bottom = margins;
        left = margins;
    }
    return {
        top,
        right,
        bottom,
        left
    };
};
/**
 * Calculates the margins for the chart.
 */
function calculateMarginOffsets(height, width, margins) {
    const { left, right, bottom, top } = margins;
    const newHeight = height - top - bottom;
    const newWidth = width - left - right;
    return {
        height: newHeight,
        width: newWidth
    };
}
/**
 * Calculates the dimensions for the chart.
 */
function getDimension({ xOffset, yOffset, height, width, margins }) {
    const parsedMargins = parseMargins(margins);
    const marginDims = calculateMarginOffsets(height, width, parsedMargins);
    const chartWidth = marginDims.width - xOffset;
    const chartHeight = marginDims.height - yOffset;
    return {
        xOffset,
        yOffset,
        height,
        width,
        chartWidth,
        chartHeight,
        xMargin: xOffset + parsedMargins.left,
        yMargin: parsedMargins.top
    };
}

const ResizeInner = props => React.createElement(Fragment, null, props.children);
class ResizeContainer extends PureComponent {
    constructor(props) {
        super(props);
        if (this.shouldAutosize()) {
            this.SizeMe = sizeMe({
                monitorHeight: !props.height,
                monitorWidth: !props.width,
                refreshMode: 'debounce'
            })(ResizeInner);
        }
    }
    shouldAutosize() {
        return !this.props.height || !this.props.width;
    }
    render() {
        const { SizeMe } = this;
        const { children, onSize } = this.props;
        const shouldAutosize = this.shouldAutosize();
        return (React.createElement(Fragment, null,
            shouldAutosize && (React.createElement(SizeMe, { onSize: onSize },
                React.createElement("div", { style: { height: '100%', width: '100%' } }, children))),
            !shouldAutosize && children));
    }
}

let chartId = 0;
class ChartContainer extends React.Component {
    constructor(props) {
        super(props);
        const { margins, height, width } = props;
        this.state = Object.assign({ id: (chartId++).toString() }, getDimension({
            margins,
            height,
            width,
            yOffset: 0,
            xOffset: 0
        }));
    }
    componentDidUpdate(nextProps) {
        const { height, width } = this.props;
        if (width !== nextProps.width || height !== nextProps.height) {
            this.updateSize({
                height: nextProps.height,
                width: nextProps.width
            });
        }
    }
    onResize(event) {
        this.updateSize(Object.assign({}, event, { chartSized: true }));
    }
    updateAxes(orientation, event) {
        const propToken = orientation === 'horizontal' ? 'xAxisSized' : 'yAxisSized';
        this.updateSize({
            yOffset: event.height,
            xOffset: event.width,
            [propToken]: true
        });
    }
    updateSize(props) {
        this.setState(prev => (Object.assign({ chartSized: props.chartSized || prev.chartSized, 
            // TODO: @amcdnl refactor this be x0Offset/x1Offset/etc
            xAxisSized: props.xAxisSized || prev.xAxisSized, yAxisSized: props.yAxisSized || prev.yAxisSized }, getDimension({
            margins: this.props.margins,
            height: props.height || prev.height,
            width: props.width || prev.width,
            yOffset: props.yOffset || prev.yOffset,
            xOffset: props.xOffset || prev.xOffset
        }))));
    }
    getChartSized() {
        const { height, width, xAxisVisible, yAxisVisible } = this.props;
        const { xAxisSized, yAxisSized, chartSized } = this.state;
        if ((!height || !width) && !chartSized) {
            return false;
        }
        // TODO: @amcdnl refactor this to account for 0-2 axises on x/y
        if (xAxisVisible && !xAxisSized) {
            return false;
        }
        if (yAxisVisible && !yAxisSized) {
            return false;
        }
        return true;
    }
    render() {
        const { className, children, center } = this.props;
        const { xMargin, yMargin, width, height } = this.state;
        const id = this.props.id || this.state.id;
        const chartSized = this.getChartSized();
        const childProps = Object.assign({}, this.state, { chartSized,
            id, updateAxes: bind(this.updateAxes, this) });
        const transform = center
            ? `translate(${width / 2}, ${height / 2})`
            : `translate(${xMargin}, ${yMargin})`;
        return (React.createElement(ResizeContainer, { onSize: bind(this.onResize, this), height: this.props.height, width: this.props.width }, height && width && (React.createElement("svg", { width: width, height: height, className: className },
            React.createElement("g", { transform: transform }, children(childProps))))));
    }
}
ChartContainer.defaultProps = {
    margins: 10
};

class AreaChart extends React.Component {
    constructor(props) {
        super(props);
        this.getData = memoize((data, type) => {
            if (type === 'stacked' || type === 'stackedNormalized') {
                return buildStackData(data, type === 'stackedNormalized');
            }
            else {
                return buildChartData(data, true);
            }
        });
        const zoom = props.zoomPan ? props.zoomPan.props : {};
        const zoomControlled = !zoom.hasOwnProperty('domain');
        this.state = {
            zoomDomain: zoom.domain,
            isZoomed: !!zoom.domain,
            zoomControlled
        };
    }
    static getDerivedStateFromProps(props, state) {
        if (props.zoomPan) {
            const zoom = props.zoomPan.props;
            if (!state.zoomControlled && zoom.domain !== state.zoomDomain) {
                return {
                    zoomDomain: zoom.domain,
                    isZoomed: !!zoom.domain
                };
            }
        }
        return null;
    }
    getScales(data, chartWidth, chartHeight) {
        const { zoomDomain } = this.state;
        const { yAxis, xAxis } = this.props;
        const xScale = getXScale({
            width: chartWidth,
            type: xAxis.props.type,
            roundDomains: xAxis.props.roundDomains,
            data,
            domain: zoomDomain || xAxis.props.domain
        });
        const yScale = getYScale({
            roundDomains: yAxis.props.roundDomains,
            type: yAxis.props.type,
            height: chartHeight,
            data,
            domain: yAxis.props.domain
        });
        return { xScale, yScale };
    }
    onZoomPan(event) {
        if (this.state.zoomControlled) {
            this.setState({
                zoomDomain: event.domain,
                isZoomed: event.isZoomed,
                preventAnimation: true
            });
            clearTimeout(this.timeout);
            this.timeout = setTimeout(() => this.setState({ preventAnimation: false }), 500);
        }
    }
    renderChart(containerProps) {
        const { chartHeight, chartWidth, id, updateAxes } = containerProps;
        const { series, yAxis, xAxis, gridlines, brush, zoomPan } = this.props;
        const { zoomDomain, preventAnimation, isZoomed } = this.state;
        const data = this.getData(this.props.data, series.props.type);
        const { xScale, yScale } = this.getScales(data, chartWidth, chartHeight);
        const animated = preventAnimation === true ? false : series.props.animated;
        return (React.createElement(Fragment, null,
            containerProps.chartSized && gridlines && (React.createElement(CloneElement, { element: gridlines, height: chartHeight, width: chartWidth, yScale: yScale, xScale: xScale, yAxis: yAxis.props, xAxis: xAxis.props })),
            React.createElement(CloneElement, { element: xAxis, height: chartHeight, width: chartWidth, scale: xScale, onDimensionsChange: bind(updateAxes, this, 'horizontal') }),
            React.createElement(CloneElement, { element: yAxis, height: chartHeight, width: chartWidth, scale: yScale, onDimensionsChange: bind(updateAxes, this, 'vertical') }),
            containerProps.chartSized && (React.createElement(CloneElement, { element: brush, height: chartHeight, width: chartWidth, scale: xScale },
                React.createElement(CloneElement, { element: zoomPan, onZoomPan: bind(this.onZoomPan, this), height: chartHeight, width: chartWidth, axisType: xAxis.props.type, roundDomains: xAxis.props.roundDomains, data: data, domain: zoomDomain },
                    React.createElement(CloneElement, { element: series, id: `area-series-${id}`, data: data, height: chartHeight, width: chartWidth, yScale: yScale, xScale: xScale, isZoomed: isZoomed, animated: animated }))))));
    }
    render() {
        const { xAxis, yAxis, id, width, height, margins, className, series } = this.props;
        return (React.createElement(ChartContainer, { id: id, width: width, height: height, margins: margins, xAxisVisible: isAxisVisible(xAxis.props), yAxisVisible: isAxisVisible(yAxis.props), className: classNames(areaChart, className, series.type) }, props => this.renderChart(props)));
    }
}
AreaChart.defaultProps = {
    data: [],
    xAxis: React.createElement(LinearXAxis, { type: "time" }),
    yAxis: React.createElement(LinearYAxis, { type: "value" }),
    series: React.createElement(AreaSeries, null),
    gridlines: React.createElement(GridlineSeries, null),
    brush: null,
    zoomPan: null
};

class StackedAreaChart extends Component {
    render() {
        return React.createElement(AreaChart, Object.assign({}, this.props));
    }
}
StackedAreaChart.defaultProps = {
    series: React.createElement(StackedAreaSeries, null)
};

class StackedNormalizedAreaChart extends Component {
    render() {
        return React.createElement(AreaChart, Object.assign({}, this.props));
    }
}
StackedNormalizedAreaChart.defaultProps = {
    series: React.createElement(StackedNormalizedAreaSeries, null),
    yAxis: (React.createElement(LinearYAxis, { type: "value", tickSeries: React.createElement(LinearYAxisTickSeries, { label: React.createElement(LinearYAxisTickLabel, { rotation: false, format: data => `${data * 100}%` }) }) }))
};

const degrees$1 = (radians) => (radians / Math.PI) * 180 - 90;
class RadialAxisLine extends Component {
    render() {
        const { index, angle, radius, stroke } = this.props;
        const strokeColor = typeof stroke === 'string' ? stroke : stroke(index);
        const rotation = degrees$1(angle(index));
        const [x1, x2] = radius.range();
        return (React.createElement("line", { stroke: strokeColor, transform: `rotate(${rotation})`, x1: x1, x2: x2 }));
    }
}
RadialAxisLine.defaultProps = {
    style: () => { }
};

class RadialAxisLineSeries extends Component {
    getInnerArcRadius(arcWidth) {
        const { minRadius, count, padding } = this.props;
        return minRadius + (count - (count - 3)) * (arcWidth + padding);
    }
    render() {
        const { count, stroke, height, arcWidth } = this.props;
        const outerRadius = height / 2;
        const lines = range(count);
        const innerRadius = this.getInnerArcRadius(arcWidth);
        const radius = scaleLinear().range([innerRadius, outerRadius]);
        const angle = scalePoint()
            .domain(range(count + 1))
            .range([0.75, 2.25 * Math.PI]);
        return (React.createElement("g", null, lines.map((_, i) => (React.createElement(RadialAxisLine, { key: i, radius: radius, index: i, angle: angle, stroke: stroke })))));
    }
}

class RadialAxisTickLine extends Component {
    render() {
        const { stroke, size } = this.props;
        return React.createElement("line", { x2: 0, x1: size, stroke: stroke });
    }
}

class RadialAxisTickLabel extends Component {
    render() {
        const { tick, fill, fontFamily, fontSize, format, lineSize, rotation, index } = this.props;
        const text = format ? format(tick, index) : formatValue(tick);
        const shouldRotate = rotation > 100 && rotation;
        const rotate = shouldRotate ? 180 : 0;
        const translate = shouldRotate ? -30 : 0;
        const textAnchor = shouldRotate ? 'end' : 'start';
        return (React.createElement("g", { transform: `rotate(${rotate}) translate(${translate})` },
            React.createElement("title", null, text),
            React.createElement("text", { dy: "0.35em", x: lineSize + 5, textAnchor: textAnchor, fill: fill, fontFamily: fontFamily, fontSize: fontSize }, text)));
    }
}

class RadialAxisTick extends Component {
    render() {
        const { line, label, scale, outerRadius, tick, index } = this.props;
        const rotation = (scale(tick) * 180) / Math.PI - 90;
        const transform = `rotate(${rotation}) translate(${outerRadius + 25},0)`;
        return (React.createElement("g", { transform: transform },
            line.show && (React.createElement(RadialAxisTickLine, { size: line.size, stroke: line.stroke })),
            label.show && (React.createElement(RadialAxisTickLabel, Object.assign({}, label, { index: index, rotation: rotation, lineSize: line.size, tick: tick })))));
    }
}

class RadialAxisTickSeries extends Component {
    render() {
        const { scale, count, outerRadius, line, label } = this.props;
        const ticks = scale.ticks(count);
        return (React.createElement("g", null, ticks.map((tick, i) => (React.createElement(RadialAxisTick, { key: i, index: i, scale: scale, tick: tick, line: line, label: label, outerRadius: outerRadius })))));
    }
}

class RadialAxisArc extends Component {
    getInnerRadius(index) {
        const { minRadius, count, padding, width } = this.props;
        return minRadius + (count - (index + 1)) * (width + padding);
    }
    getOuterRadius(index) {
        const { width } = this.props;
        return this.getInnerRadius(index) + width;
    }
    render() {
        const { padding, index, stroke, strokeDasharray } = this.props;
        const r = this.getOuterRadius(index) + padding;
        const strokeColor = typeof stroke === 'string' ? stroke : stroke(index);
        const strokeDash = typeof strokeDasharray === 'string'
            ? strokeDasharray
            : strokeDasharray(index);
        return (React.createElement("circle", { fill: "none", strokeDasharray: strokeDash, stroke: strokeColor, cx: "0", cy: "0", r: r }));
    }
}

class RadialAxisArcSeries extends Component {
    render() {
        const { count, padding, minRadius, stroke, strokeDasharray, arcWidth } = this.props;
        const arcs = range(count);
        return (React.createElement("g", null, arcs.map(i => (React.createElement(RadialAxisArc, { key: i, index: i, minRadius: minRadius, count: count, width: arcWidth, padding: padding, stroke: stroke, strokeDasharray: strokeDasharray })))));
    }
}

class RadialAxis extends Component {
    getArcWidth(chartRadius) {
        const { arc: { minRadius, count, padding } } = this.props;
        return (chartRadius - minRadius - count * padding) / count;
    }
    render() {
        const { arc, line, ticks, xScale, height } = this.props;
        const chartRadius = height / 2 - 40;
        const arcWidth = this.getArcWidth(chartRadius);
        const outerRadius = chartRadius + arcWidth;
        return (React.createElement(Fragment, null,
            line.show && (React.createElement(RadialAxisLineSeries, Object.assign({}, line, { height: height, arcWidth: arcWidth, minRadius: arc.minRadius, padding: arc.padding }))),
            ticks.show && (React.createElement(RadialAxisTickSeries, Object.assign({}, ticks, { scale: xScale, outerRadius: outerRadius }))),
            arc.show && React.createElement(RadialAxisArcSeries, Object.assign({}, arc, { arcWidth: arcWidth }))));
    }
}
RadialAxis.defaultProps = {
    ticks: {
        show: true,
        count: 12,
        line: {
            show: true,
            stroke: '#054856',
            size: 10
        },
        label: {
            show: true,
            fill: '#3B5F6A',
            fontSize: 11,
            fontFamily: 'sans-serif'
        }
    },
    arc: {
        show: true,
        padding: 50,
        minRadius: 10,
        stroke: '#054856',
        count: 13,
        strokeDasharray: '1,4'
    },
    line: {
        show: true,
        count: 4,
        stroke: '#054856',
        innerRadius: 25
    }
};

var rounded = "Bar-module_rounded__1vgiX";

const PosedBar = posed.rect({
    enter: {
        delay: ({ animated, index, barCount }) => animated ? (index / barCount) * 500 : 0,
        transition: ({ animated }) => (animated ? transition : { duration: 0 }),
        x: ({ enterProps }) => enterProps.x,
        y: ({ enterProps }) => enterProps.y,
        height: ({ enterProps }) => enterProps.height,
        width: ({ enterProps }) => enterProps.width
    },
    exit: {
        x: ({ exitProps }) => exitProps.x,
        y: ({ exitProps }) => exitProps.y,
        height: ({ exitProps }) => exitProps.height,
        width: ({ exitProps }) => exitProps.width
    }
});

// Set padding modifier for the tooltips
const modifiers = {
    offset: {
        offset: '0, 5px'
    }
};
class Bar extends Component {
    constructor() {
        super(...arguments);
        this.rect = createRef();
        this.state = {};
    }
    getXAttribute() {
        return this.props.isCategorical ? 'x' : 'x0';
    }
    getExit({ x, width }) {
        const { yScale } = this.props;
        return {
            x,
            y: Math.max(...yScale.range()),
            height: 0,
            width
        };
    }
    getCoords() {
        const { yScale, isCategorical, data, width, padding } = this.props;
        const xScale = this.props.xScale1 || this.props.xScale;
        let x;
        let barWidth;
        const y0 = yScale(data.y0);
        const y1 = yScale(data.y1);
        const barHeight = y0 - y1;
        if (isCategorical) {
            if (xScale.bandwidth) {
                x = xScale(data.x);
                barWidth = xScale.bandwidth();
                if (width) {
                    x = x + barWidth / 2 - width / 2;
                    barWidth = width;
                }
            }
            else {
                if (width) {
                    throw new Error('Not a valid option for this scale type');
                }
                x = xScale(data.x0);
                barWidth = xScale(data.x1 - data.x0);
                if (padding) {
                    const calc = this.calculateLinearScalePadding(x, barWidth);
                    x = calc.x;
                    barWidth = calc.width;
                }
            }
        }
        else {
            if (width) {
                throw new Error('Not a valid option for this scale type');
            }
            const x0 = xScale(data.x0);
            const x1 = xScale(data.x1);
            const delta = x1 - x0;
            x = x0;
            barWidth = Math.max(delta - 1, 0);
        }
        return {
            height: barHeight,
            width: barWidth,
            x,
            y: y1
        };
    }
    /**
     * This function calculates the padding on a linear scale used by the marimekko chart.
     */
    calculateLinearScalePadding(x, width) {
        const { xScale, barCount, groupIndex, padding } = this.props;
        const totalWidth = xScale.range()[1];
        const widthMinusPadding = totalWidth - padding * (barCount - 1);
        const xMultiplier = widthMinusPadding / totalWidth;
        x = x * xMultiplier + groupIndex * padding;
        width = width * xMultiplier;
        return { width, x };
    }
    onMouseEnter(event) {
        this.setState({ active: true });
        const { onMouseEnter, data } = this.props;
        onMouseEnter({
            value: data,
            nativeEvent: event
        });
    }
    onMouseLeave(event) {
        this.setState({ active: false });
        const { onMouseLeave, data } = this.props;
        onMouseLeave({
            value: data,
            nativeEvent: event
        });
    }
    onMouseClick(event) {
        const { onClick, data } = this.props;
        onClick({
            value: data,
            nativeEvent: event
        });
    }
    getFill(color) {
        const { id, gradient } = this.props;
        if (!gradient) {
            return color;
        }
        return `url(#${id}-gradient)`;
    }
    getTooltipData() {
        const { data } = this.props;
        const xAttr = this.getXAttribute();
        let x = data[xAttr];
        if (data.key && data.key !== x) {
            x = `${data.key} ∙ ${x}`;
        }
        return { y: data.y, x };
    }
    renderBar(currentColorShade, coords, index) {
        const { rounded: rounded$1, cursor, barCount, animated } = this.props;
        const fill = this.getFill(currentColorShade);
        const enterProps = coords;
        const exitProps = this.getExit(coords);
        return (React.createElement(PosedBar, { pose: "enter", poseKey: `${coords.x}-${coords.y}-${coords.height}-${coords.width}`, ref: this.rect, style: { cursor }, fill: fill, onMouseEnter: bind(this.onMouseEnter, this), onMouseLeave: bind(this.onMouseLeave, this), onClick: bind(this.onMouseClick, this), className: classNames({ [rounded]: rounded$1 }), enterProps: enterProps, exitProps: exitProps, index: index, barCount: barCount, animated: animated }));
    }
    render() {
        const { id, gradient, data, barIndex, color, yScale, barCount, tooltip, groupIndex, rangeLines, animated } = this.props;
        const { active } = this.state;
        const stroke = color(data, barIndex);
        const coords = this.getCoords();
        const currentColorShade = active ? chroma(stroke).brighten(0.5) : stroke;
        const gradientOffsets = Array.isArray(gradient) ? gradient : undefined;
        const index = groupIndex !== undefined ? groupIndex : barIndex;
        return (React.createElement(Fragment, null,
            this.renderBar(currentColorShade, coords, index),
            rangeLines && (React.createElement(CloneElement, Object.assign({ element: rangeLines }, coords, { index: index, data: data, yScale: yScale, color: currentColorShade, barCount: barCount, animated: animated }))),
            !tooltip.props.disabled && (React.createElement(CloneElement, { element: tooltip, visible: !!active, modifiers: modifiers, reference: this.rect, color: color, value: this.getTooltipData(), metadata: data })),
            gradient && (React.createElement(Gradient, { id: `${id}-gradient`, color: currentColorShade, offsets: gradientOffsets }))));
    }
}
Bar.defaultProps = {
    rounded: true,
    gradient: true,
    cursor: 'auto',
    tooltip: React.createElement(ChartTooltip, null),
    rangeLines: null,
    onClick: () => undefined,
    onMouseEnter: () => undefined,
    onMouseLeave: () => undefined
};

class BarSeries extends Component {
    /**
     * Get the translation for the bar group.
     */
    getTransform(data) {
        const { xScale, type } = this.props;
        let pos = 0;
        if (type !== 'marimekko') {
            pos = xScale(data.key);
        }
        return `translate(${pos}, 0)`;
    }
    getColor(point, index) {
        const { colorScheme, data } = this.props;
        return Array.isArray(colorScheme)
            ? getColor(colorScheme, data)(index)
            : colorScheme(point, index);
    }
    renderBar(data, barIndex, barCount, groupIndex) {
        const { xScale1, yScale, bar, padding, animated, isCategorical } = this.props;
        const xScale = xScale1 || this.props.xScale;
        // Histograms dont have keys
        let key = barIndex.toString();
        if (data.key) {
            key = `${data.key.toString()}-${data.x.toString()}`;
        }
        return (React.createElement(PoseSVGGElement, { key: key },
            React.createElement(CloneElement, { element: bar, id: `bar-${groupIndex}-${barIndex}`, animated: animated, xScale: xScale, xScale1: xScale1, yScale: yScale, padding: padding, barCount: barCount, groupIndex: groupIndex, barIndex: barIndex, data: data, isCategorical: isCategorical, color: this.getColor.bind(this) })));
    }
    /**
     * Get the bar group.
     */
    renderBarGroup(data, barCount, groupIndex) {
        return (React.createElement(PoseGroup, { animateOnMount: this.props.animated }, data.map((barData, barIndex) => this.renderBar(barData, barIndex, barCount, groupIndex))));
    }
    render() {
        const { data } = this.props;
        const isMulti = isMultiSeries(data);
        return (React.createElement(Fragment, null,
            isMulti &&
                data.map((groupData, index) => (React.createElement("g", { transform: this.getTransform(groupData), key: `bar-group-${index}` }, this.renderBarGroup(groupData.data, data.length, index)))),
            !isMulti &&
                this.renderBarGroup(data, data.length)));
    }
}
BarSeries.defaultProps = {
    type: 'standard',
    padding: 0.1,
    groupPadding: 16,
    animated: true,
    colorScheme: [...sequentialScheme],
    bar: React.createElement(Bar, null)
};

const PosedRangeLine = posed.rect({
    enter: {
        opacity: 1,
        x: ({ enterProps }) => enterProps.x,
        y: ({ enterProps }) => enterProps.y,
        delay: ({ animated, index, barCount }) => animated ? (index / barCount) * 500 : 0,
        transition: ({ animated }) => (animated ? transition : { duration: 0 })
    },
    exit: {
        opacity: 0,
        x: ({ exitProps }) => exitProps.x,
        y: ({ exitProps }) => exitProps.y
    }
});

class RangeLines extends Component {
    getEnter(rangeLineHeight) {
        const { x, y, height, type } = this.props;
        let newY;
        if (type !== 'bottom') {
            newY = y;
        }
        else {
            newY = y + height - rangeLineHeight;
        }
        return {
            x,
            y: newY
        };
    }
    getExit(rangeLineHeight) {
        const { x, yScale, height, type } = this.props;
        let y;
        const maxY = Math.max(...yScale.range());
        if (type !== 'bottom') {
            y = maxY;
        }
        else {
            y = maxY + height - rangeLineHeight;
        }
        return {
            y,
            x
        };
    }
    getLineHeight() {
        return Math.min(this.props.strokeWidth, this.props.height);
    }
    render() {
        const { color, data, width, animated, index, barCount } = this.props;
        const rangeLineHeight = this.getLineHeight();
        const enterProps = this.getEnter(rangeLineHeight);
        const exitProps = this.getExit(rangeLineHeight);
        return (React.createElement(PosedRangeLine, { pose: "enter", poseKey: data, fill: color, enterProps: enterProps, exitProps: exitProps, height: rangeLineHeight, barCount: barCount, width: width, index: index, animated: animated }));
    }
}
RangeLines.defaultProps = {
    type: 'top',
    strokeWidth: 1
};

class StackedBarSeries extends Component {
    render() {
        const _a = this.props, rest = __rest(_a, ["type"]);
        return React.createElement(BarSeries, Object.assign({ type: "stacked" }, rest));
    }
}
StackedBarSeries.defaultProps = Object.assign({}, BarSeries.defaultProps, { type: 'stacked', bar: (React.createElement(Bar, { rounded: false, gradient: [
            { offset: '5%', stopOpacity: 0.1 },
            { offset: '90%', stopOpacity: 0.7 }
        ], rangeLines: React.createElement(RangeLines, { type: "top", strokeWidth: 3 }) })) });

class StackedNormalizedBarSeries extends Component {
    render() {
        const _a = this.props, rest = __rest(_a, ["type"]);
        return React.createElement(BarSeries, Object.assign({ type: "stackedNormalized" }, rest));
    }
}
StackedNormalizedBarSeries.defaultProps = Object.assign({}, BarSeries.defaultProps, { type: 'stackedNormalized', bar: (React.createElement(Bar, { rounded: false, gradient: [
            { offset: '5%', stopOpacity: 0.1 },
            { offset: '90%', stopOpacity: 0.7 }
        ], rangeLines: React.createElement(RangeLines, { type: "top", strokeWidth: 3 }), tooltip: React.createElement(ChartTooltip, { content: data => {
                const x = `${data.key} ∙ ${formatValue(data.x)}`;
                const y = `${formatValue(data.value)} ∙ ${formatValue(Math.floor((data.y1 - data.y0) * 100))}%`;
                return React.createElement(TooltipTemplate, { value: { y, x } });
            } }) })) });

class MarimekkoBarSeries extends Component {
    render() {
        const _a = this.props, rest = __rest(_a, ["type"]);
        return React.createElement(BarSeries, Object.assign({ type: "marimekko" }, rest));
    }
}
MarimekkoBarSeries.defaultProps = Object.assign({}, BarSeries.defaultProps, { type: 'marimekko', padding: 10, bar: (React.createElement(Bar, { rounded: false, padding: 10, gradient: [
            { offset: '5%', stopOpacity: 0.1 },
            { offset: '90%', stopOpacity: 0.7 }
        ], tooltip: React.createElement(ChartTooltip, { content: data => {
                const x = `${data.key} ∙ ${formatValue(data.x)}`;
                const y = `${formatValue(data.value)} ∙ ${formatValue(Math.floor((data.y1 - data.y0) * 100))}%`;
                return React.createElement(TooltipTemplate, { value: { y, x } });
            } }), rangeLines: React.createElement(RangeLines, { type: "top", strokeWidth: 3 }) })) });

/**
 * Toggle the text selection of the body.
 */
function toggleTextSelection(allowSelection) {
    const style = allowSelection ? '' : 'none';
    [
        '-webkit-touch-callout',
        '-webkit-user-select',
        '-khtml-user-select',
        '-moz-user-select',
        '-ms-user-select',
        'user-select'
    ].forEach(prop => (document.body.style[prop] = style));
}

class Pan extends Component {
    constructor() {
        super(...arguments);
        this.prevPosition = 0;
        this.started = false;
        this.delta = 0;
        this.onMouseMove = (event) => {
            event.preventDefault();
            event.stopPropagation();
            this.delta = this.delta + event.movementX;
            if (this.checkThreshold()) {
                if (this.props.cursor) {
                    document.body.style['cursor'] = this.props.cursor;
                }
                this.delta = 0;
                this.started = true;
                this.props.onPanStart({
                    nativeEvent: event,
                    source: 'mouse'
                });
            }
            else {
                this.props.onPanMove({
                    source: 'mouse',
                    nativeEvent: event,
                    delta: event.movementX
                });
            }
        };
        this.onMouseUp = (event) => {
            event.preventDefault();
            event.stopPropagation();
            this.disposeHandlers();
            toggleTextSelection(true);
            if (this.started) {
                this.props.onPanEnd({
                    nativeEvent: event,
                    source: 'mouse'
                });
            }
            else {
                this.props.onPanCancel({
                    nativeEvent: event,
                    source: 'mouse'
                });
            }
        };
        this.onTouchMove = (event) => {
            event.preventDefault();
            event.stopPropagation();
            // Calculate delta from previous position and current
            const clientX = event.touches[0].clientX;
            const delta = clientX - this.prevPosition;
            this.delta = this.delta + delta;
            if (this.checkThreshold()) {
                this.delta = 0;
                this.started = true;
                this.props.onPanStart({
                    nativeEvent: event,
                    source: 'touch'
                });
            }
            else {
                this.props.onPanMove({
                    source: 'touch',
                    nativeEvent: event,
                    delta
                });
            }
            this.prevPosition = clientX;
        };
        this.onTouchEnd = (event) => {
            event.preventDefault();
            event.stopPropagation();
            this.disposeHandlers();
            toggleTextSelection(true);
            if (this.started) {
                this.props.onPanEnd({
                    nativeEvent: event,
                    source: 'touch'
                });
            }
            else {
                this.props.onPanCancel({
                    nativeEvent: event,
                    source: 'touch'
                });
            }
        };
    }
    componentWillUnmount() {
        this.disposeHandlers();
    }
    checkThreshold() {
        return !this.started && Math.abs(this.delta) > this.props.threshold;
    }
    disposeHandlers() {
        clearTimeout(this.timeout);
        window.removeEventListener('mousemove', this.onMouseMove);
        window.removeEventListener('mouseup', this.onMouseUp);
        window.removeEventListener('touchmove', this.onTouchMove);
        window.removeEventListener('touchend', this.onTouchEnd);
        // Reset cursor on body back to original
        document.body.style['cursor'] = 'inherit';
        toggleTextSelection(true);
    }
    onMouseDown(event) {
        // Ignore right click
        if (event.nativeEvent.which === 3 || this.props.disabled) {
            return;
        }
        event.preventDefault();
        event.stopPropagation();
        event.persist();
        toggleTextSelection(false);
        this.started = false;
        // Always bind event so we cancel movement even if no action was taken
        window.addEventListener('mousemove', this.onMouseMove);
        window.addEventListener('mouseup', this.onMouseUp);
    }
    onTouchStart(event) {
        if (this.props.disabled || event.touches.length !== 1) {
            return;
        }
        event.preventDefault();
        event.stopPropagation();
        event.persist();
        toggleTextSelection(false);
        this.started = false;
        this.prevPosition = event.touches[0].clientX;
        // Always bind event so we cancel movement even if no action was taken
        window.addEventListener('touchmove', this.onTouchMove);
        window.addEventListener('touchend', this.onTouchEnd);
    }
    render() {
        return React.Children.map(this.props.children, (child) => React.cloneElement(child, Object.assign({}, child.props, { onMouseDown: e => {
                this.onMouseDown(e);
                if (child.props.onMouseDown) {
                    child.props.onMouseDown(e);
                }
            }, onTouchStart: e => {
                this.onTouchStart(e);
                if (child.props.onTouchStart) {
                    child.props.onTouchStart(e);
                }
            } })));
    }
}
Pan.defaultProps = {
    onPanStart: () => undefined,
    onPanMove: () => undefined,
    onPanEnd: () => undefined,
    onPanCancel: () => undefined,
    disabled: false,
    threshold: 10
};

var handle = "BrushHandle-module_handle__1sUPw";
var dragging = "BrushHandle-module_dragging__MOc92";
var dot = "BrushHandle-module_dot__1tWYP";
var line = "BrushHandle-module_line__Tqtk3";

class BrushHandle extends Component {
    constructor() {
        super(...arguments);
        this.state = {
            isDragging: false
        };
    }
    onPanStart() {
        this.setState({
            isDragging: true
        });
    }
    onPanMove(event) {
        this.props.onHandleDrag(event.delta);
    }
    onPanEnd() {
        this.setState({
            isDragging: false
        });
    }
    render() {
        const { height } = this.props;
        const { isDragging } = this.state;
        return (React.createElement(Pan, { onPanStart: bind(this.onPanStart, this), onPanMove: bind(this.onPanMove, this), onPanEnd: bind(this.onPanEnd, this), cursor: "ew-resize" },
            React.createElement("g", null,
                React.createElement("line", { className: line, y1: "0", y2: height, x1: "5", x2: "5" }),
                React.createElement("rect", { className: classNames(handle, { [dragging]: isDragging }), height: height - 10, style: { cursor: 'ew-resize' }, width: 8, y: "5", y1: height - 5 }),
                React.createElement("g", { transform: `translate(-1, ${height / 2 - 10})`, style: { pointerEvents: 'none' } }, range(5).map(i => (React.createElement("circle", { cy: i * 5, cx: "5", r: ".5", key: i, className: dot })))))));
    }
}

var slice = "BrushSlice-module_slice__25s30";
var unsliced = "BrushSlice-module_unsliced__2a0pj";

class BrushSlice extends Component {
    constructor() {
        super(...arguments);
        this.state = {
            isDragging: false
        };
    }
    onPanStart() {
        this.setState({
            isDragging: true
        });
    }
    onPanMove(event) {
        const start = this.props.start + event.delta;
        const end = this.props.end + event.delta;
        if (start >= 0 && end <= this.props.width) {
            this.props.onBrushChange({
                start,
                end
            });
        }
    }
    onPanEnd() {
        this.setState({
            isDragging: false
        });
    }
    onHandleDrag(direction, deltaX) {
        const start = direction === 'start' ? this.props.start + deltaX : this.props.start;
        const end = direction !== 'start' ? this.props.end + deltaX : this.props.end;
        this.props.onBrushChange({
            start,
            end
        });
    }
    render() {
        const { height, start, end, width } = this.props;
        const { isDragging } = this.state;
        const sliceWidth = Math.max(end - start, 0);
        const endSliceWidth = Math.max(width - end, 0);
        const hasNoSlice = start === 0 && end === width;
        return (React.createElement(Fragment, null,
            React.createElement("rect", { className: unsliced, height: height, width: start }),
            React.createElement("rect", { transform: `translate(${end}, 0)`, className: unsliced, height: height, width: endSliceWidth }),
            React.createElement("g", { transform: `translate(${start}, 0)` },
                React.createElement(Pan, { disabled: hasNoSlice, onPanStart: bind(this.onPanStart, this), onPanMove: bind(this.onPanMove, this), onPanEnd: bind(this.onPanEnd, this), cursor: "grabbing" },
                    React.createElement("rect", { className: slice, height: height, style: {
                            cursor: isDragging ? 'grabbing' : 'grab',
                            opacity: hasNoSlice ? 0 : 0.1,
                            pointerEvents: !hasNoSlice ? 'initial' : 'none'
                        }, width: sliceWidth })),
                React.createElement("g", { transform: `translate(-4, 0)` },
                    React.createElement(BrushHandle, { height: height, onHandleDrag: bind(this.onHandleDrag, this, 'start') })),
                React.createElement("g", { transform: `translate(${sliceWidth - 5}, 0)` },
                    React.createElement(BrushHandle, { height: height, onHandleDrag: bind(this.onHandleDrag, this, 'end') })))));
    }
}

class Brush extends Component {
    constructor(props) {
        super(props);
        this.state = {
            isSlicing: false,
            isPanning: false,
            start: props.start || 0,
            end: props.end || props.width
        };
    }
    componentDidUpdate(prevProps) {
        // If no brush is defined and width updates, update the offset of the end handle.
        if (prevProps.width !== this.props.width &&
            this.state.end === prevProps.width) {
            this.setState({ end: this.props.width });
        }
        // Don't update if we are doing the slicing
        if (!this.state.isSlicing && !this.state.isPanning) {
            const { start, end } = this.props;
            const startUpdated = start !== prevProps.start && start !== this.state.start;
            const endUpdated = end !== prevProps.end && end !== this.state.end;
            if (startUpdated || endUpdated) {
                this.setState(Object.assign({}, this.ensurePositionInBounds(start, end)));
            }
        }
    }
    getStartEnd(event, state = this.state) {
        const { x } = this.getPositionsForPanEvent(event);
        let start;
        let end;
        if (x < state.initial) {
            start = x;
            end = state.initial;
        }
        else {
            start = state.initial;
            end = x;
        }
        return this.ensurePositionInBounds(start, end, state);
    }
    getPositionsForPanEvent(event) {
        let eventObj;
        if (event.source === 'mouse') {
            const nativeEvent = event.nativeEvent;
            eventObj = {
                target: this.ref,
                clientX: nativeEvent.clientX,
                clientY: nativeEvent.clientY
            };
        }
        else {
            const touchEvent = event.nativeEvent;
            eventObj = {
                target: this.ref,
                clientX: touchEvent.touches[0].clientX,
                clientY: touchEvent.touches[0].clientY
            };
        }
        return getPositionForTarget(eventObj);
    }
    ensurePositionInBounds(newStart, newEnd, state = this.state) {
        const { width } = this.props;
        let start = newStart;
        let end = newEnd;
        if (start === undefined || start <= 0) {
            start = 0;
        }
        if (end === undefined) {
            end = width;
        }
        if (start > end) {
            start = state.start;
        }
        if (end < start) {
            end = state.end;
        }
        if (end >= width) {
            end = width;
        }
        return { start, end };
    }
    onPanStart(event) {
        const positions = this.getPositionsForPanEvent(event);
        this.setState({
            isSlicing: true,
            initial: positions.x
        });
    }
    onPanMove(event) {
        this.setState(prev => {
            const { onBrushChange } = this.props;
            // Use setState callback so we can get the true previous value
            // rather than the bulk updated value react will trigger
            const { start, end } = this.getStartEnd(event, prev);
            if (onBrushChange) {
                onBrushChange({
                    start,
                    end
                });
            }
            return {
                start,
                end
            };
        });
    }
    onPanEnd() {
        this.setState({
            isSlicing: false
        });
    }
    onPanCancel() {
        const val = {
            start: 0,
            end: this.props.width
        };
        this.setState(val);
        if (this.props.onBrushChange) {
            this.props.onBrushChange(val);
        }
    }
    onSliceChange(event) {
        const val = this.ensurePositionInBounds(event.start, event.end);
        this.setState(val);
        if (this.props.onBrushChange) {
            this.props.onBrushChange(val);
        }
    }
    render() {
        const { children, disabled, height, width } = this.props;
        const { isSlicing, start, end } = this.state;
        return (React.createElement(Pan, { disabled: disabled, onPanStart: bind(this.onPanStart, this), onPanMove: bind(this.onPanMove, this), onPanEnd: bind(this.onPanEnd, this), onPanCancel: bind(this.onPanCancel, this), cursor: "crosshair" },
            React.createElement("g", { style: {
                    pointerEvents: isSlicing ? 'none' : 'auto',
                    cursor: disabled ? '' : 'crosshair'
                } },
                children,
                !disabled && (React.createElement(Fragment, null,
                    React.createElement("rect", { ref: ref => (this.ref = ref), height: height, width: width, opacity: 0 }),
                    start !== undefined && end !== undefined && (React.createElement(BrushSlice, { start: start, end: end, height: height, width: width, onBrushChange: bind(this.onSliceChange, this) })))))));
    }
}
Brush.defaultProps = {
    disabled: false,
    height: 0,
    width: 0,
    onBrushChange: () => undefined
};

class ChartBrush extends Component {
    getBrushOffset() {
        let start;
        let end;
        const { disabled, domain, scale } = this.props;
        if (!disabled && domain) {
            start = scale(domain[0]);
            end = scale(domain[1]);
        }
        return { start, end };
    }
    onBrushChange(event) {
        const { onBrushChange, scale, width } = this.props;
        if (onBrushChange) {
            let domain;
            if (event.start !== undefined &&
                event.end !== undefined &&
                (event.start !== 0 || event.end !== width)) {
                const start = scale.invert(event.start);
                const end = scale.invert(event.end);
                domain = [start, end];
            }
            onBrushChange({
                domain
            });
        }
    }
    render() {
        const _a = this.props, { scale, height, width, children } = _a, rest = __rest(_a, ["scale", "height", "width", "children"]);
        return (React.createElement(Brush, Object.assign({}, rest, this.getBrushOffset(), { height: height, width: width, onBrushChange: bind(this.onBrushChange, this) }), children));
    }
}
ChartBrush.defaultProps = {};

var barChart = "BarChart-module_barChart__1TypA";
var stackedNormalized = "BarChart-module_stackedNormalized__2uegt";
var stacked = "BarChart-module_stacked__3ZLYq";
var marimekko = "BarChart-module_marimekko__-hOhA";
var BarChart_module = {"barChart":"BarChart-module_barChart__1TypA","stackedNormalized":"BarChart-module_stackedNormalized__2uegt","stacked":"BarChart-module_stacked__3ZLYq","marimekko":"BarChart-module_marimekko__-hOhA"};

var css = /*#__PURE__*/Object.freeze({
    barChart: barChart,
    stackedNormalized: stackedNormalized,
    stacked: stacked,
    marimekko: marimekko,
    default: BarChart_module
});

class BarChart extends React.Component {
    getScalesAndData(chartHeight, chartWidth) {
        const { yAxis, xAxis, series } = this.props;
        const seriesType = series.props.type;
        let data;
        if (seriesType === 'stacked' || seriesType === 'stackedNormalized') {
            data = buildBarStackData(this.props.data, seriesType === 'stackedNormalized');
        }
        else if (seriesType === 'marimekko') {
            data = buildMarimekkoData(this.props.data);
        }
        else {
            data = buildChartData(this.props.data);
        }
        const isMulti = isMultiSeries(data);
        const xAxisType = xAxis.props.type;
        let xScale;
        let xScale1;
        if (seriesType === 'standard' && isMulti) {
            xScale = getGroupScale({
                height: chartHeight,
                width: chartWidth,
                padding: series.props.groupPadding,
                data
            });
            xScale1 = getInnerScale({
                groupScale: xScale,
                padding: series.props.padding,
                data
            });
        }
        else if (seriesType === 'marimekko') {
            xScale1 = getMarimekkoScale(chartWidth, xAxis.props.roundDomains);
            xScale = getMarimekkoGroupScale({
                width: chartWidth,
                padding: series.props.padding,
                data,
                valueScale: xScale1
            });
        }
        else {
            xScale = getXScale({
                width: chartWidth,
                type: xAxisType,
                roundDomains: xAxis.props.roundDomains,
                data,
                padding: series.props.padding,
                domain: xAxis.props.domain
            });
            if (xAxisType === 'time' || xAxisType === 'value') {
                data = buildBins(xScale, series.props.binThreshold || xAxis.props.interval, data);
            }
        }
        const yScale = getYScale({
            roundDomains: yAxis.props.roundDomains,
            type: yAxis.props.type,
            height: chartHeight,
            data,
            domain: yAxis.props.domain
        });
        return { xScale, xScale1, yScale, data };
    }
    renderChart(containerProps) {
        const { chartHeight, chartWidth, id, updateAxes } = containerProps;
        const { series, xAxis, yAxis, brush, gridlines } = this.props;
        const { xScale, xScale1, yScale, data } = this.getScalesAndData(chartHeight, chartWidth);
        return (React.createElement(Fragment, null,
            containerProps.chartSized && gridlines && (React.createElement(CloneElement, { element: gridlines, height: chartHeight, width: chartWidth, yScale: yScale, xScale: xScale, yAxis: yAxis.props, xAxis: xAxis.props })),
            React.createElement(CloneElement, { element: xAxis, height: chartHeight, width: chartWidth, scale: xScale, onDimensionsChange: bind(updateAxes, this, 'horizontal') }),
            React.createElement(CloneElement, { element: yAxis, height: chartHeight, width: chartWidth, scale: yScale, onDimensionsChange: bind(updateAxes, this, 'vertical') }),
            containerProps.chartSized && (React.createElement(CloneElement, { element: brush, height: chartHeight, width: chartWidth, scale: xScale },
                React.createElement(CloneElement, { element: series, id: `bar-series-${id}`, data: data, isCategorical: xAxis.props.type === 'category', xScale: xScale, xScale1: xScale1, yScale: yScale })))));
    }
    render() {
        const { id, width, height, margins, className, series, xAxis, yAxis } = this.props;
        return (React.createElement(ChartContainer, { id: id, width: width, height: height, margins: margins, xAxisVisible: isAxisVisible(xAxis.props), yAxisVisible: isAxisVisible(yAxis.props), className: classNames(barChart, className, css[series.props.type]) }, props => this.renderChart(props)));
    }
}
BarChart.defaultProps = {
    data: [],
    xAxis: (React.createElement(LinearXAxis, { type: "category", tickSeries: React.createElement(LinearXAxisTickSeries, { tickSize: 20 }) })),
    yAxis: React.createElement(LinearYAxis, { type: "value" }),
    series: React.createElement(BarSeries, null),
    gridlines: React.createElement(GridlineSeries, null),
    brush: React.createElement(ChartBrush, { disabled: true })
};

class MarimekkoChart extends Component {
    render() {
        return React.createElement(BarChart, Object.assign({}, this.props));
    }
}
MarimekkoChart.defaultProps = {
    series: React.createElement(MarimekkoBarSeries, null),
    xAxis: (React.createElement(LinearXAxis, { type: "category", tickSeries: React.createElement(LinearXAxisTickSeries, { tickSize: 15 }) })),
    yAxis: (React.createElement(LinearYAxis, { type: "value", tickSeries: React.createElement(LinearYAxisTickSeries, { label: React.createElement(LinearYAxisTickLabel, { rotation: false, format: data => `${data * 100}%` }) }) }))
};

class StackedBarChart extends Component {
    render() {
        return React.createElement(BarChart, Object.assign({}, this.props));
    }
}
StackedBarChart.defaultProps = {
    series: React.createElement(StackedBarSeries, null)
};

class StackedNormalizedBarChart extends Component {
    render() {
        return React.createElement(BarChart, Object.assign({}, this.props));
    }
}
StackedNormalizedBarChart.defaultProps = {
    series: React.createElement(StackedNormalizedBarSeries, null),
    yAxis: (React.createElement(LinearYAxis, { type: "value", tickSeries: React.createElement(LinearYAxisTickSeries, { label: React.createElement(LinearYAxisTickLabel, { rotation: false, format: data => `${data * 100}%` }) }) }))
};

/**
 * Convert radians into degrees.
 */
const degrees$2 = (radians) => (radians / Math.PI) * 180 - 90;

var node = "HiveNode-module_node__3erj2";
var inactive$1 = "HiveNode-module_inactive__3qXzC";

class HiveNode extends React.Component {
    render() {
        const { angle, radius, node: node$1, color, onClick, onMouseOver, onMouseOut, active, disabled } = this.props;
        // If the size exists on the node, use it to specify the node size.
        // Otherwise, calculate a relative size using the node count.
        let size = node$1.size;
        if (size === undefined) {
            size = node$1.count || 0;
        }
        return (React.createElement("circle", { className: classNames(node, {
                [inactive$1]: !active
            }), transform: `rotate(${degrees$2(angle(node$1.x))})`, cx: radius(node$1.y), r: size, style: { cursor: disabled ? 'initial' : 'cursor' }, fill: color(node$1.x), onClick: onClick, onMouseOver: onMouseOver, onMouseOut: onMouseOut }));
    }
}

var axis = "HiveAxis-module_axis__30gBf";

class HiveAxis extends React.Component {
    render() {
        const { radius, index, angle, color } = this.props;
        const [axisStart, axisEnd] = radius.range();
        const axisLength = axisEnd - axisStart;
        return (React.createElement(React.Fragment, null,
            React.createElement("line", { className: axis, style: { stroke: color(index) }, transform: `rotate(${degrees$2(angle(index))})`, x1: axisStart, x2: axisEnd }),
            React.createElement("line", { className: axis, style: { stroke: color(index) }, transform: `rotate(${degrees$2(angle(index)) + 90})`, x1: -axisLength / 20, x2: axisLength / 20, y1: -axisEnd, y2: -axisEnd }),
            React.createElement("line", { className: axis, style: { stroke: color(index) }, transform: `rotate(${degrees$2(angle(index)) + 90})`, x1: -axisStart / 3, x2: 0, y1: axisStart * -0.8, y2: axisStart * -1 }),
            React.createElement("line", { className: axis, style: { stroke: color(index) }, transform: `rotate(${degrees$2(angle(index)) + 90})`, x1: 0, x2: axisStart / 3, y1: -axisStart, y2: axisStart * -0.8 })));
    }
}

/**
 * Hive layout
 * Original: https://github.com/d3/d3-plugins/tree/master/hive
 */
function hiveLayout() {
    let source = d => d.source;
    let target = d => d.target;
    let angle = d => d.angle;
    let startRadius = d => d.radius;
    let endRadius = startRadius;
    const arcOffset = -Math.PI / 2;
    const link = (d, i) => {
        let s = node(source, this, d, i);
        let t = node(target, this, d, i);
        let x;
        if (t.a < s.a) {
            x = t;
            t = s;
            s = x;
        }
        if (t.a - s.a > Math.PI) {
            s.a += 2 * Math.PI;
        }
        const a1 = s.a + (t.a - s.a) / 3;
        const a2 = t.a - (t.a - s.a) / 3;
        return s.r0 - s.r1 || t.r0 - t.r1
            ? 'M' +
                Math.cos(s.a) * s.r0 +
                ',' +
                Math.sin(s.a) * s.r0 +
                'L' +
                Math.cos(s.a) * s.r1 +
                ',' +
                Math.sin(s.a) * s.r1 +
                'C' +
                Math.cos(a1) * s.r1 +
                ',' +
                Math.sin(a1) * s.r1 +
                ' ' +
                Math.cos(a2) * t.r1 +
                ',' +
                Math.sin(a2) * t.r1 +
                ' ' +
                Math.cos(t.a) * t.r1 +
                ',' +
                Math.sin(t.a) * t.r1 +
                'L' +
                Math.cos(t.a) * t.r0 +
                ',' +
                Math.sin(t.a) * t.r0 +
                'C' +
                Math.cos(a2) * t.r0 +
                ',' +
                Math.sin(a2) * t.r0 +
                ' ' +
                Math.cos(a1) * s.r0 +
                ',' +
                Math.sin(a1) * s.r0 +
                ' ' +
                Math.cos(s.a) * s.r0 +
                ',' +
                Math.sin(s.a) * s.r0
            : 'M' +
                Math.cos(s.a) * s.r0 +
                ',' +
                Math.sin(s.a) * s.r0 +
                'C' +
                Math.cos(a1) * s.r1 +
                ',' +
                Math.sin(a1) * s.r1 +
                ' ' +
                Math.cos(a2) * t.r1 +
                ',' +
                Math.sin(a2) * t.r1 +
                ' ' +
                Math.cos(t.a) * t.r1 +
                ',' +
                Math.sin(t.a) * t.r1;
    };
    const node = (method, thiz, d, i) => {
        const n = method.call(thiz, d, i);
        const a = +(typeof angle === 'function' ? angle.call(thiz, n, i) : angle) +
            arcOffset;
        const r0 = +(typeof startRadius === 'function'
            ? startRadius.call(thiz, n, i)
            : startRadius);
        const r1 = startRadius === endRadius
            ? r0
            : +(typeof endRadius === 'function'
                ? endRadius.call(thiz, n, i)
                : endRadius);
        return { r0, r1, a };
    };
    link.source = s => {
        if (!s) {
            return source;
        }
        source = s;
        return link;
    };
    link.target = t => {
        if (!t) {
            return target;
        }
        target = t;
        return link;
    };
    link.angle = a => {
        if (!a) {
            return angle;
        }
        angle = a;
        return link;
    };
    link.radius = r => {
        if (!r) {
            return startRadius;
        }
        startRadius = endRadius = r;
        return link;
    };
    link.startRadius = r => {
        if (!r) {
            return startRadius;
        }
        startRadius = r;
        return link;
    };
    link.endRadius = r => {
        if (!r) {
            return endRadius;
        }
        endRadius = r;
        return link;
    };
    return link;
}

var link = "HiveLink-module_link__3c55e";
var inactive$2 = "HiveLink-module_inactive__3ZmVV";

class HiveLink extends React.Component {
    prepareData() {
        const { angle, radius } = this.props;
        const hive = hiveLayout();
        return {
            angle: hive.angle(d => angle(d.x)),
            radius: hive.radius(d => radius(d.y))
        };
    }
    render() {
        const { link: link$1, color, active, onMouseOver, onMouseOut } = this.props;
        const { angle, radius } = this.prepareData();
        return (React.createElement("path", { className: classNames(link, {
                [inactive$2]: !active
            }), d: `${angle(link$1)} ${radius(link$1)}`, stroke: isString(color) ? color : color(link$1.source.x), onMouseOver: onMouseOver, onMouseOut: onMouseOut }));
    }
}

var label$1 = "HiveLabel-module_label__1tbC6";

const degrees$3 = radians => {
    const res = (radians / Math.PI) * 180;
    return res > 90 ? res + 180 : res;
};
const translate = (d, outerRadius, padding) => d > 90 ? outerRadius + 8 + padding : -(outerRadius + padding);
class HiveLabel extends React.Component {
    render() {
        const { index, text, angle, outerRadius, label } = this.props;
        const transform = degrees$3(angle(index));
        return (React.createElement("text", { dy: translate(transform, outerRadius, label.padding), className: label$1, strokeWidth: "0.01", textAnchor: "middle", transform: `rotate(${transform})` }, text));
    }
}

var label$2 = "HiveTooltip-module_label__1gfVp";
var value$2 = "HiveTooltip-module_value__36Qwn";

class HiveTooltip extends Component {
    render() {
        const { axis, nodes, node: { x, value } } = this.props;
        const { label } = axis[x];
        const count = nodes.filter(n => n.value === value).length;
        return (React.createElement("div", null,
            React.createElement("div", { className: label$2 },
                label,
                " - ",
                formatValue(value)),
            React.createElement("div", { className: value$2 },
                formatValue(count),
                " Total")));
    }
}

class HivePlot extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {};
    }
    onNodeMouseOver(node, event) {
        const { links, nodes, onNodeMouseOver, disabled } = this.props;
        if (!disabled) {
            const activeNodeIndex = nodes.indexOf(node);
            const activeNodes = {};
            for (const link of links) {
                const { source, target } = link;
                if (source.value === node.value || target.value === node.value) {
                    const next = target.value === node.value ? source : target;
                    const idx = nodes.indexOf(next);
                    activeNodes[`node-${idx}`] = true;
                }
            }
            this.setState({
                tooltipReference: event.target,
                nodeTooltipData: node,
                active: Object.assign({ [`node-${activeNodeIndex}`]: true }, activeNodes, links.reduce((accumulator, link, i) => {
                    if (link.source.value === node.value ||
                        link.target.value === node.value) {
                        accumulator[`link-${i}`] = true;
                    }
                    return accumulator;
                }, {}))
            });
        }
        onNodeMouseOver({
            nativeEvent: event,
            node,
            links: this.getLinksForNode(node)
        });
    }
    onLinkMouseOver(link, event) {
        const { onLinkMouseOver, disabled } = this.props;
        if (!disabled) {
            this.setState({
                tooltipReference: event.target,
                linkTooltipData: link
            });
            this.activateLink(link);
        }
        onLinkMouseOver({
            nativeEvent: event,
            link
        });
    }
    activateLink(link) {
        const { nodes, links } = this.props;
        const activeLinkIndex = links.indexOf(link);
        const activeLinksMap = {
            [`link-${activeLinkIndex}`]: true
        };
        const activeLinks = [
            link,
            ...this.activateAdjacentLinks(links, link.target, activeLinksMap)
        ];
        this.setState({
            active: Object.assign({}, activeLinksMap, nodes.reduce((accumulator, node, i) => {
                for (const activeLink of activeLinks) {
                    const { source, target } = activeLink;
                    if (node === source || node === target) {
                        accumulator[`node-${i}`] = true;
                    }
                }
                return accumulator;
            }, {}))
        });
    }
    activateAdjacentLinks(links, target, accumulator) {
        const activeLinks = [];
        links.forEach((childLink, index) => {
            if (target === childLink.source) {
                if (!accumulator[`link-${index}`]) {
                    accumulator[`link-${index}`] = true;
                    activeLinks.push(childLink, ...this.activateAdjacentLinks(links, childLink.target, accumulator));
                }
            }
        });
        return activeLinks;
    }
    onNodeMouseOut(node, event) {
        const { onNodeMouseOut } = this.props;
        this.resetActive();
        onNodeMouseOut({
            nativeEvent: event,
            node,
            links: this.getLinksForNode(node)
        });
    }
    onLinkMouseOut(link, event) {
        const { onLinkMouseOut } = this.props;
        this.resetActive();
        onLinkMouseOut({
            nativeEvent: event,
            link
        });
    }
    onNodeClick(node, event) {
        const { disabled } = this.props;
        if (!disabled) {
            const { onNodeClick } = this.props;
            onNodeClick({
                nativeEvent: event,
                node,
                links: this.getLinksForNode(node)
            });
        }
    }
    getLinksForNode(node) {
        const { links } = this.props;
        return links.filter(link => link.source.value === node.value || link.target.value === node.value);
    }
    resetActive() {
        this.setState({
            active: undefined,
            linkTooltipData: undefined,
            nodeTooltipData: undefined,
            tooltipReference: undefined
        });
    }
    prepareData({ dimension, innerRadius, colorScheme, axis, label }) {
        let outerRadius = dimension / 2;
        if (label.show) {
            outerRadius = outerRadius - (10 + label.padding);
        }
        return {
            angle: scalePoint()
                .domain(range(axis.length + 1))
                .range([0, 2 * Math.PI]),
            radius: scaleLinear().range([innerRadius, outerRadius]),
            axisColor: scaleOrdinal(colorScheme.axis).domain(range(20)),
            domainColor: scaleOrdinal(colorScheme.domain).domain(range(20)),
            outerRadius
        };
    }
    onSize({ height, width }) {
        this.setState(prev => ({
            height: height || prev.height,
            width: width || prev.width
        }));
    }
    getDimensions() {
        const height = this.props.height || this.state.height || 0;
        const width = this.props.width || this.state.width || 0;
        return {
            height,
            width
        };
    }
    renderAxis({ angle, radius, axisColor, outerRadius }) {
        const { axis, label } = this.props;
        return (React.createElement(Fragment, null, axis.map((a, i) => (React.createElement("g", { key: `axis-${a.attribute}` },
            React.createElement(HiveAxis, { angle: angle, index: i, color: axisColor, radius: radius }),
            label.show && (React.createElement(HiveLabel, { index: i, text: a.label, label: label, outerRadius: outerRadius, angle: angle })))))));
    }
    isActive(nodeOrLink, index, type) {
        const { activeIds } = this.props;
        const { active } = this.state;
        // If no there is nothing active, then everything is active.
        if (!active && !activeIds.length) {
            return true;
        }
        // If this node is active because it is being hovered
        if (active && active[`${type}-${index}`]) {
            return true;
        }
        // If the ID matches one of the active IDs passed in the props
        if (!!activeIds.length &&
            !!nodeOrLink.id &&
            activeIds.includes(nodeOrLink.id)) {
            return true;
        }
        return false;
    }
    renderLinks({ angle, radius, domainColor }) {
        const { links } = this.props;
        return (React.createElement(Fragment, null, links.map((link, i) => {
            return (React.createElement(HiveLink, { key: `${link.value}-${i}`, color: link.color || domainColor, active: this.isActive(link, i, 'link'), angle: angle, radius: radius, link: link, onMouseOver: bind(this.onLinkMouseOver, this, link), onMouseOut: bind(this.onLinkMouseOut, this, link) }));
        })));
    }
    renderNodes({ angle, radius, domainColor }) {
        const { nodes, disabled } = this.props;
        return (React.createElement(Fragment, null, nodes.map((node, i) => (React.createElement(HiveNode, { node: node, key: `${node.value}-${i}`, active: this.isActive(node, i, 'node'), color: domainColor, radius: radius, angle: angle, disabled: disabled, onMouseOver: bind(this.onNodeMouseOver, this, node), onMouseOut: bind(this.onNodeMouseOut, this, node), onClick: bind(this.onNodeClick, this, node) })))));
    }
    renderTooltip() {
        const { tooltip, disabled, axis, nodes } = this.props;
        const { active, tooltipReference, linkTooltipData: link, nodeTooltipData: node } = this.state;
        const { formatter, placement, show } = tooltip;
        return (React.createElement(Fragment, null, !disabled && show && (React.createElement(Tooltip, { visible: !!active, reference: tooltipReference, placement: placement, content: () => formatter(axis, nodes, link, node) ||
                (node ? (React.createElement(HiveTooltip, { node: node, nodes: nodes, axis: axis })) : null) }))));
    }
    render() {
        const { innerRadius, axis, colorScheme, label, className } = this.props;
        const { height, width } = this.getDimensions();
        const data = this.prepareData({
            dimension: Math.min(height, width),
            innerRadius,
            colorScheme,
            axis,
            label
        });
        return (React.createElement(ResizeContainer, { onSize: bind(this.onSize, this), height: this.props.height, width: this.props.width }, height && width && (React.createElement(Fragment, null,
            React.createElement("svg", { width: width, height: height, className: classNames(className) },
                React.createElement("g", { transform: `translate(${width / 2}, ${height / 2 +
                        innerRadius})` },
                    this.renderAxis(data),
                    this.renderLinks(data),
                    this.renderNodes(data))),
            this.renderTooltip()))));
    }
}
HivePlot.defaultProps = {
    innerRadius: 20,
    disabled: false,
    axis: [],
    nodes: [],
    links: [],
    label: {
        show: true,
        padding: 10
    },
    activeIds: [],
    onNodeClick: () => undefined,
    onNodeMouseOver: () => undefined,
    onNodeMouseOut: () => undefined,
    onLinkMouseOver: () => undefined,
    onLinkMouseOut: () => undefined,
    tooltip: {
        show: true,
        placement: 'top',
        formatter: attr => attr.value
    },
    colorScheme: {
        axis: ['#b1b2b6'],
        domain: ['#b1b2b6']
    }
};

class LineSeries extends Component {
    render() {
        return React.createElement(AreaSeries, Object.assign({}, this.props));
    }
}
LineSeries.defaultProps = Object.assign({}, AreaSeries.defaultProps, { area: null, line: React.createElement(Line, { strokeWidth: 3 }) });
class LineChart extends Component {
    render() {
        return React.createElement(AreaChart, Object.assign({}, this.props));
    }
}
LineChart.defaultProps = Object.assign({}, AreaChart.defaultProps, { series: React.createElement(LineSeries, null) });

var country = "Map-module_country__17bat";

const PosedSVGG = posed.g({
    enter: {
        opacity: 1,
        transition: {
            opacity: {
                type: 'tween',
                ease: 'linear',
                duration: 500
            }
        }
    },
    exit: {
        opacity: 0
    }
});
class Map extends Component {
    constructor() {
        super(...arguments);
        this.state = {};
    }
    componentDidMount() {
        import('world-atlas/world/110m.json').then(geojson => {
            // Using 'countries' is less performant than 'land' but we want to be able
            // to filter and disect on specific shapes
            const worldData = feature(geojson, geojson.objects.countries);
            this.setState({
                worldData
            });
        });
    }
    getProjection({ chartWidth, chartHeight }) {
        return geoMercator()
            .fitSize([chartWidth, chartHeight], this.state.worldData)
            .center([0, 35]);
    }
    renderMarker(marker, index, projection) {
        const position = projection(marker.props.coordinates);
        if (!position) {
            console.warn(`Position for ${marker.props.coordinates.toString()} not found.`);
            return null;
        }
        return (React.createElement(CloneElement, { element: marker, cx: position[0], cy: position[1], index: index }));
    }
    renderCountry(point, index, path) {
        // Exclude ATA
        if (point.id === '010') {
            return null;
        }
        return (React.createElement("path", { key: `path-${index}`, d: path(point), className: country }));
    }
    renderChart(containerProps) {
        const { markers } = this.props;
        const { worldData } = this.state;
        if (!worldData) {
            return null;
        }
        const projection = this.getProjection(containerProps);
        const path = geoPath().projection(projection);
        return (React.createElement(PoseGroup, { animateOnMount: true },
            React.createElement(PosedSVGG, { key: "countries" },
                worldData.features.map((point, index) => this.renderCountry(point, index, path)),
                markers &&
                    markers.map((marker, index) => (React.createElement(Fragment, { key: `marker-${index}` }, this.renderMarker(marker, index, projection)))))));
    }
    render() {
        const { id, width, height, margins, className } = this.props;
        return (React.createElement(ChartContainer, { id: id, width: width, height: height, margins: margins, xAxisVisible: false, yAxisVisible: false, className: classNames(className) }, props => this.renderChart(props)));
    }
}

var marker = "MapMarker-module_marker__1OAhA";

const PosedCircle$1 = posed.circle({
    enter: {
        opacity: 1,
        scale: 1,
        delay: ({ index }) => index * 500,
        transition: {
            opacity: {
                type: 'tween',
                ease: 'linear',
                duration: 1000
            }
        }
    },
    exit: {
        opacity: 0,
        scale: 0.2
    }
});
// Set padding modifier for the tooltips
const modifiers$1 = {
    offset: {
        offset: '0, 3px'
    }
};
class MapMarker extends Component {
    constructor() {
        super(...arguments);
        this.ref = createRef();
        this.state = {};
    }
    onMouseEnter() {
        this.setState({ active: true });
    }
    onMouseLeave() {
        this.setState({ active: false });
    }
    render() {
        const { cx, cy, index, tooltip, size, onClick } = this.props;
        const { active } = this.state;
        return (React.createElement(Fragment, null,
            React.createElement(PosedCircle$1, { ref: this.ref, className: marker, index: index, cx: cx, cy: cy, r: size, onMouseEnter: bind(this.onMouseEnter, this), onMouseLeave: bind(this.onMouseLeave, this), onClick: onClick }),
            tooltip && (React.createElement(Tooltip, { visible: !!active, reference: this.ref, modifiers: modifiers$1, content: tooltip }))));
    }
}
MapMarker.defaultProps = {
    size: 3,
    onClick: () => undefined
};

const pathTransition$1 = props => {
    const from = props.previousEnter || props.from;
    const interpolater = interpolate$1(from, props.to);
    return vectorSpring({
        from: 0,
        to: 1,
        velocity: VELOCITY,
        damping: DAMPING
    }).pipe(t => props.arc(interpolater(t)));
};
const PosedArc = posed.path({
    enter: {
        d: ({ enterProps }) => enterProps,
        transition: Object.assign({}, transition, { d: pathTransition$1 })
    },
    exit: {
        d: ({ exitProps }) => exitProps
    }
});

class PieArc extends Component {
    constructor() {
        super(...arguments);
        this.arc = createRef();
        this.state = {
            active: false
        };
    }
    getExitProps() {
        const { data } = this.props;
        const startAngle = data.startAngle;
        const endAngle = data.startAngle;
        return Object.assign({}, data, { startAngle,
            endAngle });
    }
    onMouseEnter(event) {
        const { onMouseEnter, data } = this.props;
        this.setState({ active: true });
        onMouseEnter({
            value: data.data,
            nativeEvent: event
        });
    }
    onMouseLeave(event) {
        const { onMouseLeave, data } = this.props;
        this.setState({ active: false });
        onMouseLeave({
            value: data.data,
            nativeEvent: event
        });
    }
    onMouseClick(event) {
        const { onClick, data } = this.props;
        onClick({
            value: data.data,
            nativeEvent: event
        });
    }
    render() {
        const { animated, color, data, tooltip, cursor, innerArc } = this.props;
        const { active } = this.state;
        const exitProps = this.getExitProps();
        const key = innerArc(data);
        const fill = active ? chroma(color).brighten(0.5) : color;
        // Cache the previous for transition use later
        const previousEnter = this.previousEnter
            ? Object.assign({}, this.previousEnter) : undefined;
        this.previousEnter = Object.assign({}, data);
        return (React.createElement(Fragment, null,
            React.createElement(PosedArc, { pose: "enter", poseKey: key, style: { cursor }, ref: this.arc, animated: animated, previousEnter: previousEnter, onMouseEnter: bind(this.onMouseEnter, this), onMouseLeave: bind(this.onMouseLeave, this), onClick: bind(this.onMouseClick, this), arc: innerArc, enterProps: data, exitProps: exitProps, fill: fill }),
            !tooltip.props.disabled && (React.createElement(CloneElement, { element: tooltip, visible: !!active, reference: this.arc, value: { y: data.data.data, x: data.data.key } }))));
    }
}
PieArc.defaultProps = {
    cursor: 'initial',
    onClick: () => undefined,
    onMouseEnter: () => undefined,
    onMouseLeave: () => undefined,
    tooltip: React.createElement(ChartTooltip, null)
};

const PosedArcLabelGroup = posed.g({
    enter: {
        opacity: 1,
        transition: {
            opacity: {
                type: 'tween',
                ease: 'linear',
                duration: 500
            }
        }
    },
    exit: {
        opacity: 0
    }
});

const mid = ({ startAngle, endAngle }) => Math.PI > startAngle + (endAngle - startAngle) / 2;
class PieArcLabel extends Component {
    render() {
        const { outerArc, innerArc, outerRadius, data, lineStroke, padding, fontSize, fontFill, format, fontFamily } = this.props;
        const text = format ? format(data.data) : formatValue(data.data.key);
        const midPoint = mid(data);
        const textAnchor = midPoint ? 'start' : 'end';
        const linePosition = outerArc.centroid(data);
        const textPosition = midPoint
            ? `${linePosition[0] + outerRadius * 0.5},${linePosition[1]}`
            : `${linePosition[0] - outerRadius * 0.5},${linePosition[1]}`;
        return (React.createElement(PosedArcLabelGroup, null,
            React.createElement("text", { dy: padding, fill: fontFill, fontSize: fontSize, fontFamily: fontFamily, transform: `translate(${textPosition})`, textAnchor: textAnchor, style: { shapeRendering: 'crispEdges' } }, text),
            React.createElement("polyline", { fill: "none", stroke: lineStroke, points: `${innerArc.centroid(data)},${linePosition},${textPosition}` })));
    }
}
PieArcLabel.defaultProps = {
    show: false,
    format: undefined,
    lineStroke: 'rgba(127,127,127,0.5)',
    fontFill: '#8F979F',
    fontSize: 11,
    fontFamily: 'sans-serif',
    padding: '.35em'
};

class PieArcSeries extends Component {
    calculateRadius() {
        const { doughnut, arcWidth, label, width, height } = this.props;
        const outerRadius = Math.min(width, height) / (label.props.show ? 3 : 2);
        const innerRadius = doughnut ? outerRadius * (1 - arcWidth) : 0;
        return {
            outerRadius,
            innerRadius
        };
    }
    getColor(point, index) {
        const { colorScheme, data } = this.props;
        return Array.isArray(colorScheme)
            ? getColor(colorScheme, data)(index)
            : colorScheme(point, index);
    }
    innerArc(innerRadius, outerRadius) {
        return arc()
            .innerRadius(innerRadius)
            .outerRadius(outerRadius);
    }
    outerArc(outerRadius) {
        const factor = 1.2;
        return arc()
            .innerRadius(outerRadius * factor)
            .outerRadius(outerRadius * factor);
    }
    render() {
        const { animated, data, label, arc } = this.props;
        const { outerRadius, innerRadius } = this.calculateRadius();
        const innerArc = this.innerArc(innerRadius, outerRadius);
        const outerArc = this.outerArc(outerRadius);
        return (React.createElement(PoseGroup, { animateOnMount: animated }, data.map((arcData, index) => (React.createElement(PoseSVGGElement, { key: arcData.data.key.toString() },
            React.createElement(CloneElement, { element: arc, data: arcData, animated: animated, innerArc: innerArc, color: this.getColor(arcData, index) }),
            label.props.show && (React.createElement(CloneElement, { element: label, data: arcData, innerArc: innerArc, outerArc: outerArc, outerRadius: outerRadius })))))));
    }
}
PieArcSeries.defaultProps = {
    animated: true,
    colorScheme: sequentialScheme,
    innerRadius: 0,
    arcWidth: 0.25,
    label: React.createElement(PieArcLabel, null),
    arc: React.createElement(PieArc, null)
};

class PieChart extends Component {
    constructor() {
        super(...arguments);
        this.getData = memoize((data) => {
            const pieLayout = pie()
                .value((d) => d.data)
                .sort(null);
            return pieLayout(data);
        });
    }
    renderChart(containerProps) {
        const { chartWidth, chartHeight } = containerProps;
        const { series } = this.props;
        const data = this.getData(this.props.data);
        return (React.createElement(CloneElement, { element: series, data: data, height: chartHeight, width: chartWidth }));
    }
    render() {
        const { id, width, height, margins, className } = this.props;
        return (React.createElement(ChartContainer, { id: id, width: width, height: height, margins: margins, xAxisVisible: false, yAxisVisible: false, center: true, className: classNames(className) }, props => this.renderChart(props)));
    }
}
PieChart.defaultProps = {
    disabled: false,
    data: [],
    margins: 10,
    series: (React.createElement(PieArcSeries, { animated: true, doughnut: false, innerRadius: 0, arcWidth: 0.25 }))
};

const JUSTIFICATION = {
    justify: sankeyJustify,
    center: sankeyCenter,
    left: sankeyLeft,
    right: sankeyRight
};
class Sankey extends Component {
    constructor() {
        super(...arguments);
        this.state = { activeNodes: [], activeLinks: [] };
    }
    getColor(node, index) {
        const { colorScheme, nodes } = this.props;
        if (colorScheme) {
            return Array.isArray(colorScheme)
                ? getColor(colorScheme, nodes)(index)
                : colorScheme(node, index);
        }
        else {
            return node.props.color;
        }
    }
    onNodeActive(node) {
        const activeNodes = [node];
        const activeLinks = [];
        if (node.sourceLinks) {
            activeLinks.push(...node.sourceLinks);
            node.sourceLinks.forEach(sourceLink => {
                const sourceLinkTarget = sourceLink.target;
                if (sourceLinkTarget.index !== node.index) {
                    activeNodes.push(sourceLinkTarget);
                }
            });
        }
        if (node.targetLinks) {
            activeLinks.push(...node.targetLinks);
            node.targetLinks.forEach(targetLink => {
                const targetLinkSource = targetLink.source;
                if (targetLinkSource.index !== node.index) {
                    activeNodes.push(targetLinkSource);
                }
            });
        }
        this.setState({ activeNodes, activeLinks });
    }
    onLinkActive(link) {
        const activeNodes = [link.source, link.target];
        const activeLinks = [link];
        this.setState({ activeNodes, activeLinks });
    }
    onInactive() {
        this.setState({ activeNodes: [], activeLinks: [] });
    }
    renderNode(computedNode, index, chartWidth) {
        const { animated, nodes } = this.props;
        const { activeNodes } = this.state;
        const active = activeNodes.some(node => node.index === computedNode.index);
        const disabled = activeNodes.length > 0 && !active;
        return (React.createElement(CloneElement, Object.assign({ element: nodes[index], key: `node-${index}`, active: active, animated: animated, disabled: disabled, chartWidth: chartWidth, onMouseEnter: bind(this.onNodeActive, this, computedNode), onMouseLeave: bind(this.onInactive, this, computedNode) }, computedNode)));
    }
    renderNodes(nodes, chartWidth) {
        nodes.sort((a, b) => {
            const aX0 = a && a.x0 ? a.x0 : 0;
            const aY0 = a && a.y0 ? a.y0 : 0;
            const bX0 = b && b.x0 ? b.x0 : 0;
            const bY0 = b && b.y0 ? b.y0 : 0;
            return aX0 - bX0 || aY0 - bY0;
        });
        return (React.createElement(Fragment, null, nodes.map((node, index) => this.renderNode(node, index, chartWidth))));
    }
    renderLink(computedLink, index) {
        const { animated, links, id } = this.props;
        const { activeLinks } = this.state;
        const active = activeLinks.some(link => link.index === computedLink.index);
        const disabled = activeLinks.length > 0 && !active;
        return (React.createElement(CloneElement, Object.assign({ element: links[index], active: active, animated: animated, key: `link-${index}`, chartId: id, disabled: disabled }, computedLink, { onMouseEnter: bind(this.onLinkActive, this, computedLink), onMouseLeave: bind(this.onInactive, this, computedLink) })));
    }
    renderChart(containerProps) {
        const { chartWidth, chartHeight } = containerProps;
        const { justification, nodeWidth, nodePadding } = this.props;
        const nodesCopy = this.props.nodes.map((node, index) => ({
            id: node.props.id,
            title: node.props.title,
            color: this.getColor(node, index)
        }));
        const linksCopy = this.props.links.map(link => ({
            source: link.props.source,
            target: link.props.target,
            value: link.props.value
        }));
        const sankeyChart = sankey()
            .extent([[1, 1], [chartWidth, chartHeight]])
            .nodeWidth(nodeWidth)
            .nodePadding(nodePadding)
            .nodeAlign(JUSTIFICATION[justification])
            .nodeId((node) => node.id || node.index);
        const { nodes, links } = sankeyChart({
            nodes: nodesCopy,
            links: linksCopy
        });
        return (containerProps.chartSized && (React.createElement(PoseGroup, { animateOnMount: this.props.animated },
            React.createElement(PoseSVGGElement, { key: "group" },
                links.map((link, index) => this.renderLink(link, index)),
                this.renderNodes(nodes, chartWidth)))));
    }
    render() {
        const { id, width, height, margins, className } = this.props;
        return (React.createElement(ChartContainer, { id: id, width: width, height: height, margins: margins, className: className }, props => this.renderChart(props)));
    }
}
Sankey.defaultProps = {
    animated: true,
    justification: 'justify',
    nodeWidth: 15,
    nodePadding: 10
};

const PosedCircle$2 = posed.circle({
    enter: {
        opacity: 1,
        cx: ({ enterProps }) => enterProps.cx,
        cy: ({ enterProps }) => enterProps.cy,
        delay: ({ animated, index }) => (animated ? index * 10 : 0),
        transition: ({ animated }) => (animated ? transition : { duration: 0 })
    },
    exit: {
        opacity: 0,
        cx: ({ exitProps }) => exitProps.cx,
        cy: ({ exitProps }) => exitProps.cy
    }
});

const PosedSymbol = posed.g({
    enter: {
        opacity: 1,
        transform: ({ enterProps }) => enterProps.transform,
        delay: ({ animated, index }) => (animated ? index * 10 : 0),
        transition: ({ animated }) => (animated ? transition : { duration: 0 })
    },
    exit: {
        opacity: 0,
        transform: ({ exitProps }) => exitProps.transform
    }
});

var inactive$3 = "ScatterPoint-module_inactive__2qwES";

class ScatterPoint extends Component {
    constructor() {
        super(...arguments);
        this.rect = React.createRef();
        this.state = {
            active: false
        };
    }
    onMouseEnter() {
        this.setState({ active: true });
        this.props.onMouseEnter(this.props.data);
    }
    onMouseLeave() {
        this.setState({ active: false });
        this.props.onMouseLeave(this.props.data);
    }
    onClick() {
        this.props.onClick(this.props.data);
    }
    getYPosition() {
        const { yScale, data } = this.props;
        let cy = yScale(data.y);
        if (yScale.bandwidth) {
            const width = yScale.bandwidth();
            cy = cy + width / 2;
        }
        return cy;
    }
    getCircleEnter() {
        const { xScale, data } = this.props;
        return {
            cy: this.getYPosition(),
            cx: xScale(data.x)
        };
    }
    getCircleExit() {
        const { xScale, data, height } = this.props;
        return {
            cy: height,
            cx: xScale(data.x)
        };
    }
    getSymbolEnter() {
        const { data, xScale } = this.props;
        const y = this.getYPosition();
        const x = xScale(data.x);
        const transform = `translate(${x}, ${y})`;
        return {
            transform,
            x,
            y
        };
    }
    getSymbolExit() {
        const { data, height, xScale } = this.props;
        const x = xScale(data.x);
        const transform = `translate(${x}, ${height})`;
        return {
            transform
        };
    }
    renderCircle() {
        const { data, animated, index, size, fill, cursor } = this.props;
        const sizeVal = typeof size === 'function' ? size(data) : size;
        const enterProps = this.getCircleEnter();
        const exitProps = this.getCircleExit();
        return (React.createElement(PosedCircle$2, { pose: "enter", poseKey: `${enterProps.cy}-${enterProps.cx}`, enterProps: enterProps, exitProps: exitProps, r: sizeVal, index: index, animated: animated, cursor: cursor, fill: fill }));
    }
    renderSymbol() {
        const { data, animated, index, symbol } = this.props;
        const enterProps = this.getSymbolEnter();
        const exitProps = this.getSymbolExit();
        const renderedSymbol = symbol(data);
        return (React.createElement(PosedSymbol, { pose: "enter", poseKey: `${enterProps.y}-${enterProps.x}`, enterProps: enterProps, exitProps: exitProps, animated: animated, index: index }, renderedSymbol));
    }
    render() {
        const { symbol, tooltip, data } = this.props;
        const { active } = this.state;
        return (React.createElement(Fragment, null,
            React.createElement("g", { ref: this.rect, onMouseEnter: bind(this.onMouseEnter, this), onMouseLeave: bind(this.onMouseLeave, this), onClick: bind(this.onClick, this), className: classNames({
                    [inactive$3]: !this.props.active
                }) },
                symbol && this.renderSymbol(),
                !symbol && this.renderCircle()),
            !tooltip.props.disabled && (React.createElement(CloneElement, { element: tooltip, visible: active, reference: this.rect, value: data }))));
    }
}
ScatterPoint.defaultProps = {
    active: true,
    tooltip: React.createElement(ChartTooltip, null),
    cursor: 'pointer',
    size: 4,
    fill: '#AE34FF',
    onClick: () => undefined,
    onMouseEnter: () => undefined,
    onMouseLeave: () => undefined
};

// For bubble charts, often symbols exceed the area
// and we want to add a little bit of padding to prevent clipping
const PADDING$1 = 25;
const HALF_PADDING$1 = PADDING$1 / 2;
class ScatterSeries extends Component {
    renderPoint(pointData, index) {
        const _a = this.props, { data, width, id, isZoomed, point, activeIds } = _a, rest = __rest(_a, ["data", "width", "id", "isZoomed", "point", "activeIds"]);
        let pointId;
        if (pointData.id) {
            pointId = pointData.id;
        }
        else {
            console.warn(`No 'id' property provided for scatter point; provide one via 'id'.`);
        }
        const key = pointId || index;
        const active = !(activeIds && activeIds.length) || activeIds.includes(pointId);
        return (React.createElement(PoseSVGGElement, { key: key },
            React.createElement(CloneElement, Object.assign({ element: point }, rest, { data: pointData, index: index, active: active }))));
    }
    render() {
        const { data, height, width, id, isZoomed } = this.props;
        return (React.createElement(Fragment, null,
            React.createElement("defs", null,
                React.createElement("clipPath", { id: `${id}-path` },
                    React.createElement("rect", { width: isZoomed ? width : width + PADDING$1, height: height + PADDING$1, x: isZoomed ? 0 : -HALF_PADDING$1, y: -HALF_PADDING$1 }))),
            React.createElement("g", { clipPath: `url(#${id}-path)` },
                React.createElement(PoseGroup, { animateOnMount: this.props.animated }, data.map((data, index) => this.renderPoint(data, index))))));
    }
}
ScatterSeries.defaultProps = {
    animated: true,
    point: React.createElement(ScatterPoint, null)
};

var scatterPlot = "ScatterPlot-module_scatterPlot__gOR7J";

class ScatterPlot extends Component {
    constructor(props) {
        super(props);
        this.getData = memoize(data => {
            return buildChartData(data);
        });
        const zoom = props.zoomPan ? props.zoomPan.props : {};
        const zoomControlled = !zoom.hasOwnProperty('domain');
        this.state = {
            isZoomed: !!zoom.domain,
            zoomDomain: zoom.domain,
            zoomControlled
        };
    }
    static getDerivedStateFromProps(props, state) {
        if (props.zoomPan) {
            const zoom = props.zoomPan.props;
            if (!state.zoomControlled && zoom.domain !== state.zoomDomain) {
                return {
                    zoomDomain: zoom.domain,
                    isZoomed: !!zoom.domain
                };
            }
        }
        return null;
    }
    getScales(data, chartHeight, chartWidth) {
        const { xAxis, yAxis } = this.props;
        const { zoomDomain } = this.state;
        const yScale = getYScale({
            roundDomains: yAxis.props.roundDomains,
            type: yAxis.props.type,
            height: chartHeight,
            data,
            domain: yAxis.props.domain
        });
        const xScale = getXScale({
            width: chartWidth,
            type: xAxis.props.type,
            roundDomains: xAxis.props.roundDomains,
            data,
            domain: zoomDomain || xAxis.props.domain
        });
        return {
            data,
            yScale,
            xScale
        };
    }
    onZoomPan(event) {
        if (this.state.zoomControlled) {
            this.setState({
                zoomDomain: event.domain,
                isZoomed: event.isZoomed,
                preventAnimation: true
            });
            clearTimeout(this.timeout);
            this.timeout = setTimeout(() => this.setState({ preventAnimation: false }), 500);
        }
    }
    renderChart(containerProps) {
        const { chartHeight, chartWidth, id, updateAxes } = containerProps;
        const { series, xAxis, yAxis, gridlines, brush, zoomPan } = this.props;
        const { isZoomed, zoomDomain, preventAnimation } = this.state;
        const data = this.getData(this.props.data);
        const { yScale, xScale } = this.getScales(data, chartHeight, chartWidth);
        const animated = preventAnimation === true ? false : series.props.animated;
        return (React.createElement(Fragment, null,
            containerProps.chartSized && gridlines && (React.createElement(CloneElement, { element: gridlines, height: chartHeight, width: chartWidth, yScale: yScale, xScale: xScale, yAxis: yAxis.props, xAxis: xAxis.props })),
            React.createElement(CloneElement, { element: xAxis, height: chartHeight, width: chartWidth, scale: xScale, onDimensionsChange: bind(updateAxes, this, 'horizontal') }),
            React.createElement(CloneElement, { element: yAxis, height: chartHeight, width: chartWidth, scale: yScale, onDimensionsChange: bind(updateAxes, this, 'vertical') }),
            containerProps.chartSized && (React.createElement(CloneElement, { element: brush, height: chartHeight, width: chartWidth, scale: xScale },
                React.createElement(CloneElement, { element: zoomPan, onZoomPan: bind(this.onZoomPan, this), height: chartHeight, width: chartWidth, axisType: xAxis.props.type, roundDomains: xAxis.props.roundDomains, data: data, domain: zoomDomain },
                    React.createElement(CloneElement, { element: series, id: `area-series-${id}`, data: data, height: chartHeight, width: chartWidth, yScale: yScale, xScale: xScale, isZoomed: isZoomed, animated: animated }))))));
    }
    render() {
        const { xAxis, yAxis, id, width, height, margins, className } = this.props;
        return (React.createElement(ChartContainer, { id: id, width: width, height: height, margins: margins, xAxisVisible: isAxisVisible(xAxis.props), yAxisVisible: isAxisVisible(yAxis.props), className: classNames(scatterPlot, className) }, props => this.renderChart(props)));
    }
}
ScatterPlot.defaultProps = {
    data: [],
    xAxis: React.createElement(LinearXAxis, { type: "time" }),
    yAxis: React.createElement(LinearYAxis, { type: "value" }),
    series: React.createElement(ScatterSeries, null),
    gridlines: React.createElement(GridlineSeries, null),
    brush: null,
    zoomPan: null
};

class SparklineChart extends Component {
    render() {
        return React.createElement(LineChart, Object.assign({}, this.props));
    }
}
SparklineChart.defaultProps = {
    gridlines: null,
    series: (React.createElement(AreaSeries, { symbols: React.createElement(CircleSeries, { show: "hover" }), interpolation: "smooth", markLine: null, area: null, line: React.createElement(Line, { strokeWidth: 2 }) })),
    yAxis: (React.createElement(LinearYAxis, { scaled: true, type: "value", axisLine: null, tickSeries: React.createElement(LinearYAxisTickSeries, { line: null, label: null }) })),
    xAxis: (React.createElement(LinearXAxis, { type: "time", scaled: true, axisLine: null, tickSeries: React.createElement(LinearXAxisTickSeries, { line: null, label: null }) }))
};

class AreaSparklineChart extends Component {
    render() {
        return React.createElement(AreaChart, Object.assign({}, this.props));
    }
}
AreaSparklineChart.defaultProps = {
    gridlines: null,
    series: (React.createElement(AreaSeries, { symbols: React.createElement(CircleSeries, { show: "hover" }), interpolation: "smooth", markLine: null, area: React.createElement(Area, { pattern: true, gradient: [
                { offset: '10%', stopOpacity: 0 },
                { offset: '80%', stopOpacity: 1 }
            ] }), line: React.createElement(Line, { strokeWidth: 3 }) })),
    yAxis: (React.createElement(LinearYAxis, { type: "value", scaled: true, axisLine: null, tickSeries: React.createElement(LinearYAxisTickSeries, { line: null, label: null }) })),
    xAxis: (React.createElement(LinearXAxis, { type: "time", scaled: true, axisLine: null, tickSeries: React.createElement(LinearXAxisTickSeries, { line: null, label: null }) }))
};

class BarSparklineChart extends Component {
    render() {
        return React.createElement(BarChart, Object.assign({}, this.props));
    }
}
BarSparklineChart.defaultProps = {
    gridlines: null,
    yAxis: (React.createElement(LinearYAxis, { type: "value", axisLine: null, tickSeries: React.createElement(LinearYAxisTickSeries, { line: null, label: null }) })),
    xAxis: (React.createElement(LinearXAxis, { type: "category", axisLine: null, tickSeries: React.createElement(LinearXAxisTickSeries, { line: null, label: null }) }))
};

/**
 * Gets the position between a given set of points.
 */
const getMidpoint = (pointA, pointB) => ({
    x: (pointA.x + pointB.x) / 2,
    y: (pointA.y + pointB.y) / 2
});
/**
 * Gets the distance between a given set of points.
 */
const getDistanceBetweenPoints = (pointA, pointB) => Math.sqrt(Math.pow(pointA.y - pointB.y, 2) + Math.pow(pointA.x - pointB.x, 2));
/**
 * Gets the value between a set of numeric values.
 */
const between = (min, max, value) => Math.min(max, Math.max(min, value));

class Zoom extends Component {
    constructor() {
        super(...arguments);
        this.childRef = createRef();
        this.onTouchStart = (event) => {
            if (event.touches.length === 2 && this.childRef.current) {
                event.preventDefault();
                event.stopPropagation();
                toggleTextSelection(false);
                const pointA = getPointFromTouch(event.touches[0], this.childRef.current);
                const pointB = getPointFromTouch(event.touches[1], this.childRef.current);
                this.lastDistance = getDistanceBetweenPoints(pointA, pointB);
                this.firstMidpoint = getMidpoint(pointA, pointB);
                window.addEventListener('touchmove', this.onTouchMove);
                window.addEventListener('touchend', this.onTouchEnd);
            }
        };
        this.onTouchMove = (event) => {
            if (event.touches.length === 2 && this.childRef.current) {
                event.preventDefault();
                event.stopPropagation();
                const pointA = getPointFromTouch(event.touches[0], this.childRef.current);
                const pointB = getPointFromTouch(event.touches[1], this.childRef.current);
                const distance = getDistanceBetweenPoints(pointA, pointB);
                const { maxZoom, zoomStep, offset, scale } = this.props;
                const delta = distance - this.lastDistance;
                const ratio = Math.exp((delta / 30) * zoomStep);
                const newScale = between(1, maxZoom, scale * ratio);
                const newOffset = Math.min((offset - this.firstMidpoint.x) * ratio + this.firstMidpoint.x, 0);
                if (scale < this.props.maxZoom) {
                    this.props.onZoom({
                        scale: newScale,
                        offset: newOffset
                    });
                }
                this.lastDistance = distance;
            }
        };
        this.onTouchEnd = (event) => {
            event.preventDefault();
            event.stopPropagation();
            window.removeEventListener('touchmove', this.onTouchMove);
            window.removeEventListener('touchend', this.onTouchEnd);
            toggleTextSelection(true);
            this.props.onZoomEnd();
        };
    }
    componentDidMount() {
        if (!this.props.disabled) {
            // Manually bind due to pinch issues not being prevented
            // https://github.com/facebook/react/issues/9809
            if (this.childRef.current) {
                this.childRef.current.addEventListener('touchstart', this.onTouchStart);
            }
        }
    }
    componentWillUnmount() {
        window.removeEventListener('touchstart', this.onTouchStart);
        window.removeEventListener('touchmove', this.onTouchMove);
        window.removeEventListener('touchend', this.onTouchEnd);
        toggleTextSelection(true);
    }
    onWheel(event) {
        const { disabled, maxZoom, zoomStep, scale, offset, onZoomEnd, disableMouseWheel } = this.props;
        if (!disabled && !disableMouseWheel) {
            const nativeEvent = event.nativeEvent;
            const positions = getPositionForTarget(nativeEvent);
            const wheel = (nativeEvent.deltaY / 120) * -1;
            const ratio = Math.exp(wheel * zoomStep);
            const roundedScale = Math.ceil(scale * ratio);
            const inBounds = roundedScale <= maxZoom && roundedScale >= 1;
            if (inBounds && roundedScale !== scale) {
                event.preventDefault();
                const newScale = between(1, maxZoom, scale * ratio);
                const newOffset = Math.min((offset - positions.x) * ratio + positions.x, 0);
                this.props.onZoom({
                    scale: newScale,
                    offset: newOffset
                });
                clearTimeout(this.timeout);
                this.timeout = setTimeout(() => {
                    onZoomEnd();
                }, 500);
            }
        }
    }
    render() {
        return React.Children.map(this.props.children, (child) => React.cloneElement(child, Object.assign({}, child.props, { ref: this.childRef, onWheel: e => {
                this.onWheel(e);
                if (child.props.onWheel) {
                    child.props.onWheel(e);
                }
            } })));
    }
}

var container = "DiscreteLegend-module_container__2mEDZ";
var horizontal = "DiscreteLegend-module_horizontal__1X-xR";
var vertical = "DiscreteLegend-module_vertical__2VWFB";

class DiscreteLegend extends Component {
    constructor() {
        super(...arguments);
        this.state = {};
    }
    onEntryMouseEnter(activeEntry) {
        this.setState({
            activeEntry
        });
    }
    onEntryMouseLeave() {
        this.setState({
            activeEntry: undefined
        });
    }
    render() {
        const { entries, orientation, style } = this.props;
        const { activeEntry } = this.state;
        const className = classNames(container, this.props.className, {
            [horizontal]: orientation === 'horizontal',
            [vertical]: orientation === 'vertical'
        });
        return (React.createElement("div", { className: className, style: style }, entries.map((entry, index) => (React.createElement(CloneElement, { element: entry, key: `dle-${index}`, active: activeEntry ? activeEntry === entry.props.label : undefined, onMouseEnter: bind(this.onEntryMouseEnter, this, entry.props.label), onMouseLeave: bind(this.onEntryMouseLeave, this) })))));
    }
}
DiscreteLegend.defaultProps = {
    orientation: 'vertical'
};

var entry = "DiscreteLegendEntry-module_entry__2t_fB";
var inactive$4 = "DiscreteLegendEntry-module_inactive__336LC";
var label$3 = "DiscreteLegendEntry-module_label__1eXDb";

var symbol = "DiscreteLegendSymbol-module_symbol__jSdtc";

class DiscreteLegendSymbol extends Component {
    render() {
        const { className, color } = this.props;
        return (React.createElement("div", { className: classNames(symbol, className), style: { background: color } }));
    }
}
DiscreteLegendSymbol.defaultProps = {};

class DiscreteLegendEntry extends Component {
    render() {
        const { label, symbol, onMouseEnter, onMouseLeave, color, style, onClick, active } = this.props;
        const className = classNames(entry, this.props.className, {
            [inactive$4]: active === false
        });
        return (React.createElement("div", { className: className, onClick: onClick, onMouseEnter: onMouseEnter, onMouseLeave: onMouseLeave, style: style },
            React.createElement(CloneElement, { element: symbol, color: color }),
            React.createElement("span", { className: label$3 }, label)));
    }
}
DiscreteLegendEntry.defaultProps = {
    symbol: React.createElement(DiscreteLegendSymbol, null),
    onMouseEnter: () => undefined,
    onMouseLeave: () => undefined,
    onClick: () => undefined
};

class ZoomPan extends Component {
    constructor(props) {
        super(props);
        this.state = {
            isZooming: false,
            isPanning: false
        };
    }
    componentWillUnmount() {
        this.stopDecay();
    }
    stopDecay() {
        if (this.decay && this.decay.stop) {
            this.decay.stop();
        }
        if (this.observer) {
            this.observer.complete();
        }
    }
    getEndOffset() {
        const { width, scale } = this.props;
        return width * scale - width;
    }
    ensureRange(delta) {
        const prevOffset = this.props.offset;
        let newOffset = delta + prevOffset;
        if (-newOffset <= 0) {
            newOffset = 0;
        }
        else if (-newOffset > this.getEndOffset()) {
            newOffset = prevOffset;
        }
        return newOffset;
    }
    onPanStart() {
        this.setState({
            isPanning: true
        });
        this.stopDecay();
        this.observer = value(this.props.offset);
    }
    onPanMove(event) {
        if (this.props.scale > 1) {
            const offset = this.ensureRange(event.delta);
            this.observer && this.observer.update(offset);
            this.props.onZoomPan({
                scale: this.props.scale,
                offset
            });
        }
    }
    onPanEnd() {
        if (this.observer && this.props.decay) {
            const end = this.getEndOffset();
            this.decay = vectorDecay({
                from: this.observer.get(),
                velocity: this.observer.getVelocity()
            })
                .pipe(clamp$1$1(-end, 0))
                .start({
                update: offset => {
                    cancelAnimationFrame(this.rqf);
                    this.rqf = requestAnimationFrame(() => {
                        this.props.onZoomPan({
                            scale: this.props.scale,
                            offset
                        });
                    });
                },
                complete: () => this.setState({ isPanning: false })
            });
        }
        else {
            this.setState({ isPanning: false });
        }
    }
    onZoom(event) {
        this.stopDecay();
        this.props.onZoomPan(event);
    }
    onZoomEnd() {
        this.setState({
            isZooming: false
        });
    }
    render() {
        const { height, width, children, disabled, pannable, maxZoom, zoomStep, zoomable, scale, offset, disableMouseWheel } = this.props;
        const { isZooming, isPanning } = this.state;
        const canPan = pannable && scale > 1;
        const cursor = canPan ? 'move' : 'auto';
        const selection = isZooming || isPanning ? 'none' : 'auto';
        return (React.createElement(Pan, { disabled: !canPan || disabled, onPanStart: bind(this.onPanStart, this), onPanMove: bind(this.onPanMove, this), onPanEnd: bind(this.onPanEnd, this) },
            React.createElement("g", null,
                React.createElement(Zoom, { disabled: !zoomable || disabled, disableMouseWheel: disableMouseWheel, maxZoom: maxZoom, zoomStep: zoomStep, scale: scale, offset: offset, onZoom: bind(this.onZoom, this), onZoomEnd: bind(this.onZoomEnd, this) },
                    React.createElement("g", { style: { cursor } },
                        !disabled && React.createElement("rect", { height: height, width: width, opacity: 0 }),
                        React.createElement("g", { style: {
                                pointerEvents: selection,
                                userSelect: selection
                            } }, children))))));
    }
}
ZoomPan.defaultProps = {
    maxZoom: 10,
    zoomStep: 0.1,
    pannable: true,
    zoomable: true,
    decay: true,
    height: 0,
    width: 0,
    offset: 0,
    scale: 1,
    onZoomPan: () => undefined
};

class ChartZoomPan extends Component {
    onZoomPan(event) {
        const { width, data, axisType, roundDomains, onZoomPan } = this.props;
        const scale = getXScale({
            width: width,
            type: axisType,
            roundDomains,
            data
        });
        const newScale = scale.copy().domain(scale
            .range()
            .map(x => (x - event.offset) / event.scale)
            .map(scale.invert, event.offset));
        onZoomPan({
            domain: newScale.domain(),
            isZoomed: event.scale !== 1
        });
    }
    getOffset() {
        let zoomOffset = {};
        const { disabled, domain, width, data, axisType, roundDomains } = this.props;
        if (!disabled && domain) {
            const xScale = getXScale({
                width,
                type: axisType,
                roundDomains,
                data
            });
            let offset = xScale(domain[0]);
            const endOffset = xScale(domain[1]);
            const scale = width / (endOffset - offset);
            // Apply the new scale to the offset so its scaled correctly
            offset = offset * scale;
            zoomOffset = {
                scale: scale,
                offset: -offset
            };
        }
        return zoomOffset;
    }
    render() {
        const _a = this.props, { data, height, children, width, onZoomPan } = _a, rest = __rest(_a, ["data", "height", "children", "width", "onZoomPan"]);
        return (React.createElement(ZoomPan, Object.assign({}, rest, this.getOffset(), { onZoomPan: bind(this.onZoomPan, this), height: height, width: width }), children));
    }
}
ChartZoomPan.defaultProps = {
    onZoomPan: () => undefined
};

export { AreaChart, StackedAreaChart, StackedNormalizedAreaChart, AreaSeries, Area, Line, StackedNormalizedAreaSeries, StackedAreaSeries, BarChart, MarimekkoChart, StackedBarChart, StackedNormalizedBarChart, BarSeries, StackedBarSeries, StackedNormalizedBarSeries, MarimekkoBarSeries, Bar, RangeLines, HivePlot, LineSeries, LineChart, PosedSVGG, Map, PosedCircle$1 as PosedCircle, MapMarker, PieChart, PieArcSeries, PieArc, PieArcLabel, Sankey, ScatterPlot, ScatterSeries, ScatterPoint, SparklineChart, AreaSparklineChart, BarSparklineChart, LinearAxis, LinearXAxisTickLabel, LinearXAxisTickLine, LinearXAxisTickSeries, LinearXAxis, LinearYAxisTickLabel, LinearYAxisTickLine, LinearYAxisTickSeries, LinearYAxis, LinearAxisLine, LinearAxisTickLabel, LinearAxisTickLine, LinearAxisTickSeries, isAxisVisible, RadialAxis, Brush, BrushSlice, ChartBrush, Circle, CircleSeries, ChartContainer, ResizeContainer, isNested, buildChartData, buildNestedChartData, buildShallowChartData, buildBins, buildBarStackData, buildMarimekkoData, buildStackData, normalizeValue, normalizeValueForFormatting, getMaxBigInteger, isMultiSeries, Pan, Zoom, DiscreteLegend, DiscreteLegendEntry, DiscreteLegendSymbol, GridlineSeries, GridStripe, Gridline, MarkLine, Gradient, Stripes, Mask, TooltipArea, TooltipTemplate, ChartTooltip, Tooltip, VELOCITY, DAMPING, pathTransition, transition, PoseSVGGElement, humanFormatBigInteger, bigIntegerToLocaleString, CloneElement, sequentialScheme, getColor, getDimension, extent, getYDomain, getXDomain, getGroupDomain, getDeepGroupDomain, formatValue, interpolate, getPositionForTarget, getPointFromTouch, getClosestPoint, toggleTextSelection, calculateShowStroke, getTicks, getTextWidth, ZoomPan, ChartZoomPan };
//# sourceMappingURL=index.js.map
